/* Generated by Cython 0.29.16 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "CYTHON_TRACE", 
                "1"
            ]
        ], 
        "name": "ddb.lexer.lexer", 
        "sources": [
            "./ddb/lexer/lexer.py"
        ]
    }, 
    "module_name": "ddb.lexer.lexer"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_16"
#define CYTHON_HEX_VERSION 0x001D10F0
#define CYTHON_FUTURE_DIVISION 0
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : (Py_INCREF(func), func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif


#define __PYX_ERR(f_index, lineno, Ln_error) \
{ \
  __pyx_filename = __pyx_f[f_index]; __pyx_lineno = lineno; __pyx_clineno = __LINE__; goto Ln_error; \
}

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__ddb__lexer__lexer
#define __PYX_HAVE_API__ddb__lexer__lexer
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "ddb/lexer/lexer.py",
};

/*--- Type declarations ---*/

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* append.proto */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* PyIntCompare.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* StringJoin.proto */
#if PY_MAJOR_VERSION < 3
#define __Pyx_PyString_Join __Pyx_PyBytes_Join
#define __Pyx_PyBaseString_Join(s, v) (PyUnicode_CheckExact(s) ? PyUnicode_Join(s, v) : __Pyx_PyBytes_Join(s, v))
#else
#define __Pyx_PyString_Join PyUnicode_Join
#define __Pyx_PyBaseString_Join PyUnicode_Join
#endif
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION < 3
    #define __Pyx_PyBytes_Join _PyString_Join
    #else
    #define __Pyx_PyBytes_Join _PyBytes_Join
    #endif
#else
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values);
#endif

/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* None.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* SetNameInClass.proto */
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? _PyDict_SetItem_KnownHash(ns, name, value, ((PyASCIIObject *) name)->hash) : PyObject_SetItem(ns, name, value))
#elif CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_SetNameInClass(ns, name, value)\
    (likely(PyDict_CheckExact(ns)) ? PyDict_SetItem(ns, name, value) : PyObject_SetItem(ns, name, value))
#else
#define __Pyx_SetNameInClass(ns, name, value)  PyObject_SetItem(ns, name, value)
#endif

/* FetchCommonType.proto */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

/* CythonFunction.proto */
#define __Pyx_CyFunction_USED 1
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;  // used by FusedFunction for copying defaults
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_Check(obj)  (__Pyx_TypeCheck(obj, __pyx_CyFunctionType))
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

/* CalculateMetaclass.proto */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases);

/* Py3ClassCreate.proto */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name, PyObject *qualname,
                                           PyObject *mkw, PyObject *modname, PyObject *doc);
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases, PyObject *dict,
                                      PyObject *mkw, int calculate_metaclass, int allow_py2_metaclass);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* Print.proto */
static int __Pyx_Print(PyObject*, PyObject *, int);
#if CYTHON_COMPILING_IN_PYPY || PY_MAJOR_VERSION >= 3
static PyObject* __pyx_print = 0;
static PyObject* __pyx_print_kwargs = 0;
#endif

/* PrintOne.proto */
static int __Pyx_PrintOne(PyObject* stream, PyObject *o);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);


/* Module declarations from 'ddb.lexer.lexer' */
#define __Pyx_MODULE_NAME "ddb.lexer.lexer"
extern int __pyx_module_is_main_ddb__lexer__lexer;
int __pyx_module_is_main_ddb__lexer__lexer = 0;

/* Implementation of 'ddb.lexer.lexer' */
static PyObject *__pyx_builtin_BaseException;
static PyObject *__pyx_builtin_range;
static const char __pyx_k_[] = ";";
static const char __pyx_k_0[] = "{0}";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_f[] = "f";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_q[] = "q";
static const char __pyx_k_t[] = "t";
static const char __pyx_k_x[] = "x";
static const char __pyx_k__2[] = "'";
static const char __pyx_k__3[] = "\"";
static const char __pyx_k__4[] = "[";
static const char __pyx_k__5[] = "]";
static const char __pyx_k__6[] = "`";
static const char __pyx_k__8[] = "-----------------------------------";
static const char __pyx_k__9[] = "";
static const char __pyx_k_db[] = "db";
static const char __pyx_k_ts[] = "ts";
static const char __pyx_k_0_1[] = "{0}-{1}";
static const char __pyx_k_0_2[] = "[{0}]";
static const char __pyx_k__11[] = "{";
static const char __pyx_k__12[] = "}";
static const char __pyx_k__13[] = "$";
static const char __pyx_k__18[] = ":";
static const char __pyx_k__20[] = " ";
static const char __pyx_k__21[] = "-----";
static const char __pyx_k__22[] = ",";
static const char __pyx_k__23[] = ".";
static const char __pyx_k__24[] = "----";
static const char __pyx_k__25[] = " >>> ";
static const char __pyx_k__26[] = " <<< ";
static const char __pyx_k_arg[] = "arg";
static const char __pyx_k_bad[] = "bad";
static const char __pyx_k_doc[] = "__doc__";
static const char __pyx_k_end[] = "end";
static const char __pyx_k_int[] = "int";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_msg[] = "msg";
static const char __pyx_k_res[] = "res";
static const char __pyx_k_tsi[] = "tsi";
static const char __pyx_k_var[] = "var";
static const char __pyx_k_JUMP[] = "JUMP";
static const char __pyx_k_arg1[] = "arg1";
static const char __pyx_k_arg2[] = "arg2";
static const char __pyx_k_arg3[] = "arg3";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_char[] = "char";
static const char __pyx_k_data[] = "data";
static const char __pyx_k_file[] = "file";
static const char __pyx_k_find[] = "find";
static const char __pyx_k_info[] = "info";
static const char __pyx_k_init[] = "__init__";
static const char __pyx_k_item[] = "item";
static const char __pyx_k_join[] = "join";
static const char __pyx_k_jump[] = "jump";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_meta[] = "meta";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_node[] = "node";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_true[] = "true";
static const char __pyx_k_type[] = "type";
static const char __pyx_k_vars[] = "vars";
static const char __pyx_k_word[] = "word";
static const char __pyx_k_0_1_2[] = "'{0}'='{1}'";
static const char __pyx_k_0_1_3[] = "{0} {1}";
static const char __pyx_k_array[] = "array";
static const char __pyx_k_block[] = "block";
static const char __pyx_k_chomp[] = "chomp";
static const char __pyx_k_debug[] = "debug";
static const char __pyx_k_false[] = "false";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_lexer[] = "lexer";
static const char __pyx_k_lower[] = "lower";
static const char __pyx_k_match[] = "match";
static const char __pyx_k_parse[] = "parse";
static const char __pyx_k_print[] = "print";
static const char __pyx_k_query[] = "query";
static const char __pyx_k_quote[] = "quote";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_slots[] = "__slots__";
static const char __pyx_k_specs[] = "specs";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_token[] = "token";
static const char __pyx_k_value[] = "value";
static const char __pyx_k_APPEND[] = "APPEND";
static const char __pyx_k_Adding[] = "----------Adding";
static const char __pyx_k_append[] = "append";
static const char __pyx_k_blocks[] = "blocks";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_module[] = "__module__";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_needle[] = "needle";
static const char __pyx_k_parent[] = "parent";
static const char __pyx_k_parsed[] = "parsed";
static const char __pyx_k_querys[] = "querys";
static const char __pyx_k_result[] = "result";
static const char __pyx_k_select[] = "select";
static const char __pyx_k_single[] = "single";
static const char __pyx_k_string[] = "string";
static const char __pyx_k_tokens[] = "tokens";
static const char __pyx_k_0_1_2_2[] = "{0} {1} {2}";
static const char __pyx_k_Missing[] = "Missing";
static const char __pyx_k_Queries[] = "Queries";
static const char __pyx_k_SUCCESS[] = "SUCCESS";
static const char __pyx_k_arg_key[] = "arg_key";
static const char __pyx_k_columns[] = "columns";
static const char __pyx_k_command[] = "command";
static const char __pyx_k_dispose[] = "dispose";
static const char __pyx_k_err_msg[] = "err_msg";
static const char __pyx_k_in_list[] = "in list";
static const char __pyx_k_isspace[] = "isspace";
static const char __pyx_k_needles[] = "needles";
static const char __pyx_k_partial[] = "partial";
static const char __pyx_k_prepare[] = "__prepare__";
static const char __pyx_k_results[] = "results";
static const char __pyx_k_segment[] = "segment";
static const char __pyx_k_success[] = "success";
static const char __pyx_k_w_index[] = "w_index";
static const char __pyx_k_No_match[] = "No match";
static const char __pyx_k_Token_Id[] = "Token Id:";
static const char __pyx_k_argindex[] = "argindex";
static const char __pyx_k_argument[] = "argument";
static const char __pyx_k_commands[] = "commands";
static const char __pyx_k_computed[] = "computed";
static const char __pyx_k_function[] = "function";
static const char __pyx_k_haystack[] = "haystack";
static const char __pyx_k_in_block[] = "in_block";
static const char __pyx_k_internal[] = "internal";
static const char __pyx_k_language[] = "language";
static const char __pyx_k_not_list[] = "---not list";
static const char __pyx_k_optional[] = "optional";
static const char __pyx_k_qualname[] = "__qualname__";
static const char __pyx_k_required[] = "required";
static const char __pyx_k_segments[] = "segments";
static const char __pyx_k_tokenize[] = "tokenize";
static const char __pyx_k_validate[] = "validate";
static const char __pyx_k_var_name[] = "var_name";
static const char __pyx_k_variable[] = "variable";
static const char __pyx_k_NO_APPEND[] = "NO APPEND";
static const char __pyx_k_Object_Id[] = "Object Id:";
static const char __pyx_k_arguments[] = "arguments";
static const char __pyx_k_delimiter[] = "delimiter";
static const char __pyx_k_functions[] = "functions";
static const char __pyx_k_haystacks[] = "haystacks";
static const char __pyx_k_last_char[] = "last_char";
static const char __pyx_k_match_len[] = "match_len";
static const char __pyx_k_meta_type[] = "meta_type";
static const char __pyx_k_metaclass[] = "__metaclass__";
static const char __pyx_k_more_list[] = "------more list";
static const char __pyx_k_object_id[] = "object_id";
static const char __pyx_k_query_err[] = "query_err";
static const char __pyx_k_signature[] = "signature";
static const char __pyx_k_tokenizer[] = "tokenizer";
static const char __pyx_k_Best_Match[] = "Best Match";
static const char __pyx_k_argument_0[] = "argument{0}";
static const char __pyx_k_at_the_end[] = "at the end";
static const char __pyx_k_definition[] = "definition";
static const char __pyx_k_depends_on[] = "depends_on";
static const char __pyx_k_first_char[] = "first_char";
static const char __pyx_k_last_index[] = "last_index";
static const char __pyx_k_lexer_info[] = "lexer.info";
static const char __pyx_k_no_keyword[] = "no_keyword";
static const char __pyx_k_query_mode[] = "query_mode";
static const char __pyx_k_sql_object[] = "sql_object";
static const char __pyx_k_temp_array[] = "temp_array";
static const char __pyx_k_token_list[] = "token_list";
static const char __pyx_k_TESTING_0_1[] = "############# TESTING : {0}.{1}";
static const char __pyx_k_in_argument[] = "in_argument";
static const char __pyx_k_is_function[] = "is_function";
static const char __pyx_k_lexer_flags[] = "lexer.flags";
static const char __pyx_k_lexer_parse[] = "lexer.parse";
static const char __pyx_k_lexer_split[] = "lexer.split";
static const char __pyx_k_store_array[] = "store_array";
static const char __pyx_k_test_syntax[] = "test_syntax";
static const char __pyx_k_token_index[] = "token_index";
static const char __pyx_k_FAILED_MATCH[] = "FAILED MATCH";
static const char __pyx_k_Jumping_from[] = "Jumping from ";
static const char __pyx_k_QUERY_OBJECT[] = "QUERY OBJECT:";
static const char __pyx_k_Query_object[] = "Query object";
static const char __pyx_k_Token_Length[] = "Token Length";
static const char __pyx_k_curent_block[] = "curent_block";
static const char __pyx_k_get_argument[] = "get_argument";
static const char __pyx_k_lexer___init[] = "lexer.__init__";
static const char __pyx_k_query_object[] = "query_object";
static const char __pyx_k_recent_match[] = "recent_match";
static const char __pyx_k_temp_needles[] = "temp_needles";
static const char __pyx_k_token_length[] = "token_length";
static const char __pyx_k_BaseException[] = "BaseException";
static const char __pyx_k_base_argument[] = "base_argument";
static const char __pyx_k_curent_object[] = "curent_object";
static const char __pyx_k_get_sub_array[] = "get_sub_array";
static const char __pyx_k_highest_match[] = "highest_match";
static const char __pyx_k_looking_ahead[] = "--looking ahead";
static const char __pyx_k_query_objects[] = "query_objects";
static const char __pyx_k_segment_index[] = "segment_index";
static const char __pyx_k_variable_data[] = "variable_data";
static const char __pyx_k_variable_type[] = "variable_type";
static const char __pyx_k_Invalid_Syntax[] = "Invalid Syntax";
static const char __pyx_k_argument_index[] = "argument_index";
static const char __pyx_k_index_of_colon[] = "index_of_colon";
static const char __pyx_k_lexer_validate[] = "lexer.validate";
static const char __pyx_k_still_checking[] = "still checking";
static const char __pyx_k_temp_haystacks[] = "temp_haystacks";
static const char __pyx_k_It_s_a_function[] = "It's a function!";
static const char __pyx_k_ddb_lexer_lexer[] = "ddb.lexer.lexer";
static const char __pyx_k_list_of_strings[] = "list_of_strings";
static const char __pyx_k_Dependency_found[] = "Dependency found";
static const char __pyx_k_Depends_on_key_0[] = "Depends on key: '{0}'";
static const char __pyx_k_command_fragment[] = "command_fragment";
static const char __pyx_k_dependency_found[] = "dependency_found";
static const char __pyx_k_Missing_arguments[] = "Missing arguments";
static const char __pyx_k_SUCCESSFULL_MATCH[] = "SUCCESSFULL MATCH";
static const char __pyx_k_keep_non_keywords[] = "keep_non_keywords";
static const char __pyx_k_lexer_test_syntax[] = "lexer.test_syntax";
static const char __pyx_k_print_not_in_list[] = "print not in list";
static const char __pyx_k_signature_compare[] = "signature_compare";
static const char __pyx_k_think_its_a_match[] = "############################think its a match";
static const char __pyx_k_Not_found_argument[] = "Not found argument";
static const char __pyx_k_Too_many_arguments[] = "Too many arguments";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_ddb_lexer_lexer_py[] = "ddb/lexer/lexer.py";
static const char __pyx_k_discard_whitespace[] = "discard_whitespace";
static const char __pyx_k_lexer_flags___init[] = "lexer.flags.__init__";
static const char __pyx_k_lexer_get_argument[] = "lexer.get_argument";
static const char __pyx_k_single_array_match[] = "single_array_match";
static const char __pyx_k_Number_of_arguments[] = "Number of arguments";
static const char __pyx_k_lexer_get_sub_array[] = "lexer.get_sub_array";
static const char __pyx_k_valid_function_name[] = "valid_function_name";
static const char __pyx_k_No_columns_in_select[] = "No columns in select";
static const char __pyx_k_get_sub_array_sub_key[] = "get_sub_array_sub_key";
static const char __pyx_k_0_isn_t_a_valid_function[] = "'{0}' isn't a valid function";
static const char __pyx_k_Syntax_error_near_word_0[] = "\n Syntax error near word {0}";
static const char __pyx_k_lexer_single_array_match[] = "lexer.single_array_match";
static const char __pyx_k_Variable_Data_not_boolean[] = "Variable Data not boolean";
static const char __pyx_k_Validating_Select_Functions[] = "Validating Select Functions";
static const char __pyx_k_lexer_get_sub_array_sub_key[] = "lexer.get_sub_array_sub_key";
static const char __pyx_k_Variable_data_not_an_integer_0[] = "Variable data not an integer '{0}'";
static const char __pyx_k_Non_optional_components_missing[] = "Non optional components missing from query";
static const char __pyx_k_Missing_argument_in_last_element[] = "Missing argument in last element";
static const char __pyx_k_Not_successful_required_argument[] = "Not successful. required arguments missing";
static const char __pyx_k_variable_data_length_exceeded_ty[] = "variable data length exceeded, type char";
static PyObject *__pyx_kp_s_;
static PyObject *__pyx_kp_s_0;
static PyObject *__pyx_kp_s_0_1;
static PyObject *__pyx_kp_s_0_1_2;
static PyObject *__pyx_kp_s_0_1_2_2;
static PyObject *__pyx_kp_s_0_1_3;
static PyObject *__pyx_kp_s_0_2;
static PyObject *__pyx_kp_s_0_isn_t_a_valid_function;
static PyObject *__pyx_n_s_APPEND;
static PyObject *__pyx_kp_s_Adding;
static PyObject *__pyx_n_s_BaseException;
static PyObject *__pyx_kp_s_Best_Match;
static PyObject *__pyx_kp_s_Dependency_found;
static PyObject *__pyx_kp_s_Depends_on_key_0;
static PyObject *__pyx_kp_s_FAILED_MATCH;
static PyObject *__pyx_kp_s_Invalid_Syntax;
static PyObject *__pyx_kp_s_It_s_a_function;
static PyObject *__pyx_n_s_JUMP;
static PyObject *__pyx_kp_s_Jumping_from;
static PyObject *__pyx_n_s_Missing;
static PyObject *__pyx_kp_s_Missing_argument_in_last_element;
static PyObject *__pyx_kp_s_Missing_arguments;
static PyObject *__pyx_kp_s_NO_APPEND;
static PyObject *__pyx_kp_s_No_columns_in_select;
static PyObject *__pyx_kp_s_No_match;
static PyObject *__pyx_kp_s_Non_optional_components_missing;
static PyObject *__pyx_kp_s_Not_found_argument;
static PyObject *__pyx_kp_s_Not_successful_required_argument;
static PyObject *__pyx_kp_s_Number_of_arguments;
static PyObject *__pyx_kp_s_Object_Id;
static PyObject *__pyx_kp_s_QUERY_OBJECT;
static PyObject *__pyx_n_s_Queries;
static PyObject *__pyx_kp_s_Query_object;
static PyObject *__pyx_n_s_SUCCESS;
static PyObject *__pyx_kp_s_SUCCESSFULL_MATCH;
static PyObject *__pyx_kp_s_Syntax_error_near_word_0;
static PyObject *__pyx_kp_s_TESTING_0_1;
static PyObject *__pyx_kp_s_Token_Id;
static PyObject *__pyx_kp_s_Token_Length;
static PyObject *__pyx_kp_s_Too_many_arguments;
static PyObject *__pyx_kp_s_Validating_Select_Functions;
static PyObject *__pyx_kp_s_Variable_Data_not_boolean;
static PyObject *__pyx_kp_s_Variable_data_not_an_integer_0;
static PyObject *__pyx_kp_s__11;
static PyObject *__pyx_kp_s__12;
static PyObject *__pyx_kp_s__13;
static PyObject *__pyx_kp_s__18;
static PyObject *__pyx_kp_s__2;
static PyObject *__pyx_kp_s__20;
static PyObject *__pyx_kp_s__21;
static PyObject *__pyx_kp_s__22;
static PyObject *__pyx_kp_s__23;
static PyObject *__pyx_kp_s__24;
static PyObject *__pyx_kp_s__25;
static PyObject *__pyx_kp_s__26;
static PyObject *__pyx_kp_s__3;
static PyObject *__pyx_kp_s__4;
static PyObject *__pyx_kp_s__5;
static PyObject *__pyx_kp_s__6;
static PyObject *__pyx_kp_s__8;
static PyObject *__pyx_kp_s__9;
static PyObject *__pyx_n_s_append;
static PyObject *__pyx_n_s_arg;
static PyObject *__pyx_n_s_arg1;
static PyObject *__pyx_n_s_arg2;
static PyObject *__pyx_n_s_arg3;
static PyObject *__pyx_n_s_arg_key;
static PyObject *__pyx_n_s_argindex;
static PyObject *__pyx_n_s_argument;
static PyObject *__pyx_kp_s_argument_0;
static PyObject *__pyx_n_s_argument_index;
static PyObject *__pyx_n_s_arguments;
static PyObject *__pyx_n_s_array;
static PyObject *__pyx_kp_s_at_the_end;
static PyObject *__pyx_n_s_bad;
static PyObject *__pyx_n_s_base_argument;
static PyObject *__pyx_n_s_block;
static PyObject *__pyx_n_s_blocks;
static PyObject *__pyx_n_s_bool;
static PyObject *__pyx_n_s_c;
static PyObject *__pyx_n_s_char;
static PyObject *__pyx_n_s_chomp;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_columns;
static PyObject *__pyx_n_s_command;
static PyObject *__pyx_n_s_command_fragment;
static PyObject *__pyx_n_s_commands;
static PyObject *__pyx_n_s_computed;
static PyObject *__pyx_n_s_curent_block;
static PyObject *__pyx_n_s_curent_object;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_db;
static PyObject *__pyx_n_s_ddb_lexer_lexer;
static PyObject *__pyx_kp_s_ddb_lexer_lexer_py;
static PyObject *__pyx_n_s_debug;
static PyObject *__pyx_n_s_definition;
static PyObject *__pyx_n_s_delimiter;
static PyObject *__pyx_n_s_dependency_found;
static PyObject *__pyx_n_s_depends_on;
static PyObject *__pyx_n_s_discard_whitespace;
static PyObject *__pyx_n_s_dispose;
static PyObject *__pyx_n_s_doc;
static PyObject *__pyx_n_s_end;
static PyObject *__pyx_n_s_err_msg;
static PyObject *__pyx_n_s_f;
static PyObject *__pyx_n_s_false;
static PyObject *__pyx_n_s_file;
static PyObject *__pyx_n_s_find;
static PyObject *__pyx_n_s_first_char;
static PyObject *__pyx_n_s_flags;
static PyObject *__pyx_n_s_format;
static PyObject *__pyx_n_s_function;
static PyObject *__pyx_n_s_functions;
static PyObject *__pyx_n_s_get_argument;
static PyObject *__pyx_n_s_get_sub_array;
static PyObject *__pyx_n_s_get_sub_array_sub_key;
static PyObject *__pyx_n_s_haystack;
static PyObject *__pyx_n_s_haystacks;
static PyObject *__pyx_n_s_highest_match;
static PyObject *__pyx_n_s_i;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_in_argument;
static PyObject *__pyx_n_s_in_block;
static PyObject *__pyx_kp_s_in_list;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_n_s_index_of_colon;
static PyObject *__pyx_n_s_info;
static PyObject *__pyx_n_s_init;
static PyObject *__pyx_n_s_int;
static PyObject *__pyx_n_s_internal;
static PyObject *__pyx_n_s_is_function;
static PyObject *__pyx_n_s_isspace;
static PyObject *__pyx_n_s_item;
static PyObject *__pyx_n_s_join;
static PyObject *__pyx_n_s_jump;
static PyObject *__pyx_n_s_keep_non_keywords;
static PyObject *__pyx_n_s_key;
static PyObject *__pyx_n_s_language;
static PyObject *__pyx_n_s_last_char;
static PyObject *__pyx_n_s_last_index;
static PyObject *__pyx_n_s_lexer;
static PyObject *__pyx_n_s_lexer___init;
static PyObject *__pyx_n_s_lexer_flags;
static PyObject *__pyx_n_s_lexer_flags___init;
static PyObject *__pyx_n_s_lexer_get_argument;
static PyObject *__pyx_n_s_lexer_get_sub_array;
static PyObject *__pyx_n_s_lexer_get_sub_array_sub_key;
static PyObject *__pyx_n_s_lexer_info;
static PyObject *__pyx_n_s_lexer_parse;
static PyObject *__pyx_n_s_lexer_single_array_match;
static PyObject *__pyx_n_s_lexer_split;
static PyObject *__pyx_n_s_lexer_test_syntax;
static PyObject *__pyx_n_s_lexer_validate;
static PyObject *__pyx_n_s_list_of_strings;
static PyObject *__pyx_kp_s_looking_ahead;
static PyObject *__pyx_n_s_lower;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_match;
static PyObject *__pyx_n_s_match_len;
static PyObject *__pyx_n_s_meta;
static PyObject *__pyx_n_s_meta_type;
static PyObject *__pyx_n_s_metaclass;
static PyObject *__pyx_n_s_mode;
static PyObject *__pyx_n_s_module;
static PyObject *__pyx_kp_s_more_list;
static PyObject *__pyx_n_s_msg;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_n_s_name_2;
static PyObject *__pyx_n_s_needle;
static PyObject *__pyx_n_s_needles;
static PyObject *__pyx_n_s_no_keyword;
static PyObject *__pyx_n_s_node;
static PyObject *__pyx_kp_s_not_list;
static PyObject *__pyx_n_s_object_id;
static PyObject *__pyx_n_s_optional;
static PyObject *__pyx_n_s_parent;
static PyObject *__pyx_n_s_parse;
static PyObject *__pyx_n_s_parsed;
static PyObject *__pyx_n_s_partial;
static PyObject *__pyx_n_s_prepare;
static PyObject *__pyx_n_s_print;
static PyObject *__pyx_kp_s_print_not_in_list;
static PyObject *__pyx_n_s_q;
static PyObject *__pyx_n_s_qualname;
static PyObject *__pyx_n_s_query;
static PyObject *__pyx_n_s_query_err;
static PyObject *__pyx_n_s_query_mode;
static PyObject *__pyx_n_s_query_object;
static PyObject *__pyx_n_s_query_objects;
static PyObject *__pyx_n_s_querys;
static PyObject *__pyx_n_s_quote;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_recent_match;
static PyObject *__pyx_n_s_required;
static PyObject *__pyx_n_s_res;
static PyObject *__pyx_n_s_result;
static PyObject *__pyx_n_s_results;
static PyObject *__pyx_n_s_segment;
static PyObject *__pyx_n_s_segment_index;
static PyObject *__pyx_n_s_segments;
static PyObject *__pyx_n_s_select;
static PyObject *__pyx_n_s_self;
static PyObject *__pyx_n_s_signature;
static PyObject *__pyx_n_s_signature_compare;
static PyObject *__pyx_n_s_single;
static PyObject *__pyx_n_s_single_array_match;
static PyObject *__pyx_n_s_slots;
static PyObject *__pyx_n_s_specs;
static PyObject *__pyx_n_s_split;
static PyObject *__pyx_n_s_sql_object;
static PyObject *__pyx_kp_s_still_checking;
static PyObject *__pyx_n_s_store_array;
static PyObject *__pyx_n_s_string;
static PyObject *__pyx_n_s_success;
static PyObject *__pyx_n_s_t;
static PyObject *__pyx_n_s_temp_array;
static PyObject *__pyx_n_s_temp_haystacks;
static PyObject *__pyx_n_s_temp_needles;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_test_syntax;
static PyObject *__pyx_kp_s_think_its_a_match;
static PyObject *__pyx_n_s_token;
static PyObject *__pyx_n_s_token_index;
static PyObject *__pyx_n_s_token_length;
static PyObject *__pyx_n_s_token_list;
static PyObject *__pyx_n_s_tokenize;
static PyObject *__pyx_n_s_tokenizer;
static PyObject *__pyx_n_s_tokens;
static PyObject *__pyx_n_s_true;
static PyObject *__pyx_n_s_ts;
static PyObject *__pyx_n_s_tsi;
static PyObject *__pyx_n_s_type;
static PyObject *__pyx_n_s_valid_function_name;
static PyObject *__pyx_n_s_validate;
static PyObject *__pyx_n_s_value;
static PyObject *__pyx_n_s_var;
static PyObject *__pyx_n_s_var_name;
static PyObject *__pyx_n_s_variable;
static PyObject *__pyx_n_s_variable_data;
static PyObject *__pyx_kp_s_variable_data_length_exceeded_ty;
static PyObject *__pyx_n_s_variable_type;
static PyObject *__pyx_n_s_vars;
static PyObject *__pyx_n_s_w_index;
static PyObject *__pyx_n_s_word;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_split(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_delimiter); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_query, PyObject *__pyx_v_debug); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_4get_argument(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_word, PyObject *__pyx_v_segment, PyObject *__pyx_v_tokens, PyObject *__pyx_v_token_index, PyObject *__pyx_v_w_index); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_6parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5flags___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_command_fragment); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_8test_syntax(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_command, PyObject *__pyx_v_tokens); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_curent_object, CYTHON_UNUSED PyObject *__pyx_v_tokens, CYTHON_UNUSED PyObject *__pyx_v_token_index, PyObject *__pyx_v_segment, PyObject *__pyx_v_command, PyObject *__pyx_v_segment_index, PyObject *__pyx_v_query_object, PyObject *__pyx_v_query_mode); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_12get_sub_array(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_array, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_14get_sub_array_sub_key(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_array, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_16single_array_match(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_needles, PyObject *__pyx_v_haystacks); /* proto */
static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_18info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_msg, PyObject *__pyx_v_arg1, PyObject *__pyx_v_arg2, PyObject *__pyx_v_arg3); /* proto */
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_neg_1;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_slice__10;
static PyObject *__pyx_slice__14;
static PyObject *__pyx_slice__17;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__16;
static PyObject *__pyx_tuple__19;
static PyObject *__pyx_tuple__27;
static PyObject *__pyx_tuple__29;
static PyObject *__pyx_tuple__30;
static PyObject *__pyx_tuple__32;
static PyObject *__pyx_tuple__33;
static PyObject *__pyx_tuple__35;
static PyObject *__pyx_tuple__37;
static PyObject *__pyx_tuple__39;
static PyObject *__pyx_tuple__41;
static PyObject *__pyx_tuple__43;
static PyObject *__pyx_tuple__45;
static PyObject *__pyx_tuple__46;
static PyObject *__pyx_tuple__48;
static PyObject *__pyx_tuple__50;
static PyObject *__pyx_tuple__52;
static PyObject *__pyx_codeobj__28;
static PyObject *__pyx_codeobj__31;
static PyObject *__pyx_codeobj__34;
static PyObject *__pyx_codeobj__36;
static PyObject *__pyx_codeobj__38;
static PyObject *__pyx_codeobj__40;
static PyObject *__pyx_codeobj__42;
static PyObject *__pyx_codeobj__44;
static PyObject *__pyx_codeobj__47;
static PyObject *__pyx_codeobj__49;
static PyObject *__pyx_codeobj__51;
/* Late includes */

/* "ddb/lexer/lexer.py":10
 *     __slots__=['keep_non_keywords','debug','query_objects']
 * 
 *     def split(self,data,delimiter=';'):             # <<<<<<<<<<<<<<
 *         in_block    = None
 *         curent_block= None
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_1split(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_1split = {"split", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_1split, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_1split(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_data = 0;
  PyObject *__pyx_v_delimiter = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("split (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_data,&__pyx_n_s_delimiter,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject*)__pyx_kp_s_));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_data)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("split", 0, 2, 3, 1); __PYX_ERR(0, 10, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_delimiter);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "split") < 0)) __PYX_ERR(0, 10, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_data = values[1];
    __pyx_v_delimiter = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("split", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 10, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_split(__pyx_self, __pyx_v_self, __pyx_v_data, __pyx_v_delimiter);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_split(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_data, PyObject *__pyx_v_delimiter) {
  PyObject *__pyx_v_in_block = NULL;
  PyObject *__pyx_v_curent_block = NULL;
  PyObject *__pyx_v_last_index = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_blocks = NULL;
  PyObject *__pyx_v_list_of_strings = NULL;
  PyObject *__pyx_v_c = NULL;
  PyObject *__pyx_v_block = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  __Pyx_RefNannySetupContext("split", 0);

  /* "ddb/lexer/lexer.py":11
 * 
 *     def split(self,data,delimiter=';'):
 *         in_block    = None             # <<<<<<<<<<<<<<
 *         curent_block= None
 *         last_index  = 0
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_in_block = Py_None;

  /* "ddb/lexer/lexer.py":12
 *     def split(self,data,delimiter=';'):
 *         in_block    = None
 *         curent_block= None             # <<<<<<<<<<<<<<
 *         last_index  = 0
 *         index       = 0
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_curent_block = Py_None;

  /* "ddb/lexer/lexer.py":13
 *         in_block    = None
 *         curent_block= None
 *         last_index  = 0             # <<<<<<<<<<<<<<
 *         index       = 0
 *         blocks      = [ ['\'', '\'', 'quote'], # string block
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_last_index = __pyx_int_0;

  /* "ddb/lexer/lexer.py":14
 *         curent_block= None
 *         last_index  = 0
 *         index       = 0             # <<<<<<<<<<<<<<
 *         blocks      = [ ['\'', '\'', 'quote'], # string block
 *                         ['"' , '"' , 'quote'], # string block
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_index = __pyx_int_0;

  /* "ddb/lexer/lexer.py":15
 *         last_index  = 0
 *         index       = 0
 *         blocks      = [ ['\'', '\'', 'quote'], # string block             # <<<<<<<<<<<<<<
 *                         ['"' , '"' , 'quote'], # string block
 *                         ['[' , ']' , 'db'   ], # mssql column
 */
  __pyx_t_1 = PyList_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_s__2);
  __Pyx_GIVEREF(__pyx_kp_s__2);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_s__2);
  __Pyx_INCREF(__pyx_kp_s__2);
  __Pyx_GIVEREF(__pyx_kp_s__2);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_s__2);
  __Pyx_INCREF(__pyx_n_s_quote);
  __Pyx_GIVEREF(__pyx_n_s_quote);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_n_s_quote);

  /* "ddb/lexer/lexer.py":16
 *         index       = 0
 *         blocks      = [ ['\'', '\'', 'quote'], # string block
 *                         ['"' , '"' , 'quote'], # string block             # <<<<<<<<<<<<<<
 *                         ['[' , ']' , 'db'   ], # mssql column
 *                         ['`' , '`' , 'db'   ], # mysql column
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_kp_s__3);
  __Pyx_GIVEREF(__pyx_kp_s__3);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_kp_s__3);
  __Pyx_INCREF(__pyx_kp_s__3);
  __Pyx_GIVEREF(__pyx_kp_s__3);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_kp_s__3);
  __Pyx_INCREF(__pyx_n_s_quote);
  __Pyx_GIVEREF(__pyx_n_s_quote);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_quote);

  /* "ddb/lexer/lexer.py":17
 *         blocks      = [ ['\'', '\'', 'quote'], # string block
 *                         ['"' , '"' , 'quote'], # string block
 *                         ['[' , ']' , 'db'   ], # mssql column             # <<<<<<<<<<<<<<
 *                         ['`' , '`' , 'db'   ], # mysql column
 *                     ]
 */
  __pyx_t_3 = PyList_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_kp_s__4);
  __Pyx_GIVEREF(__pyx_kp_s__4);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s__4);
  __Pyx_INCREF(__pyx_kp_s__5);
  __Pyx_GIVEREF(__pyx_kp_s__5);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_kp_s__5);
  __Pyx_INCREF(__pyx_n_s_db);
  __Pyx_GIVEREF(__pyx_n_s_db);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_db);

  /* "ddb/lexer/lexer.py":18
 *                         ['"' , '"' , 'quote'], # string block
 *                         ['[' , ']' , 'db'   ], # mssql column
 *                         ['`' , '`' , 'db'   ], # mysql column             # <<<<<<<<<<<<<<
 *                     ]
 * 
 */
  __pyx_t_4 = PyList_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 18, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_kp_s__6);
  __Pyx_GIVEREF(__pyx_kp_s__6);
  PyList_SET_ITEM(__pyx_t_4, 0, __pyx_kp_s__6);
  __Pyx_INCREF(__pyx_kp_s__6);
  __Pyx_GIVEREF(__pyx_kp_s__6);
  PyList_SET_ITEM(__pyx_t_4, 1, __pyx_kp_s__6);
  __Pyx_INCREF(__pyx_n_s_db);
  __Pyx_GIVEREF(__pyx_n_s_db);
  PyList_SET_ITEM(__pyx_t_4, 2, __pyx_n_s_db);

  /* "ddb/lexer/lexer.py":15
 *         last_index  = 0
 *         index       = 0
 *         blocks      = [ ['\'', '\'', 'quote'], # string block             # <<<<<<<<<<<<<<
 *                         ['"' , '"' , 'quote'], # string block
 *                         ['[' , ']' , 'db'   ], # mssql column
 */
  __pyx_t_5 = PyList_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  PyList_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_3);
  PyList_SET_ITEM(__pyx_t_5, 2, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyList_SET_ITEM(__pyx_t_5, 3, __pyx_t_4);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_v_blocks = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "ddb/lexer/lexer.py":21
 *                     ]
 * 
 *         list_of_strings=[]                     # the list of split strings             # <<<<<<<<<<<<<<
 * 
 *         for c in data:
 */
  __pyx_t_5 = PyList_New(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_list_of_strings = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "ddb/lexer/lexer.py":23
 *         list_of_strings=[]                     # the list of split strings
 * 
 *         for c in data:             # <<<<<<<<<<<<<<
 *             if not in_block:
 *                 for block in blocks:
 */
  if (likely(PyList_CheckExact(__pyx_v_data)) || PyTuple_CheckExact(__pyx_v_data)) {
    __pyx_t_5 = __pyx_v_data; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 23, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 23, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 23, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 23, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 23, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 23, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_c, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "ddb/lexer/lexer.py":24
 * 
 *         for c in data:
 *             if not in_block:             # <<<<<<<<<<<<<<
 *                 for block in blocks:
 *                     if c==block[0]:
 */
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_in_block); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 24, __pyx_L1_error)
    __pyx_t_9 = ((!__pyx_t_8) != 0);
    if (__pyx_t_9) {

      /* "ddb/lexer/lexer.py":25
 *         for c in data:
 *             if not in_block:
 *                 for block in blocks:             # <<<<<<<<<<<<<<
 *                     if c==block[0]:
 *                         in_block=True
 */
      __pyx_t_4 = __pyx_v_blocks; __Pyx_INCREF(__pyx_t_4); __pyx_t_10 = 0;
      for (;;) {
        if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_4)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_10); __Pyx_INCREF(__pyx_t_3); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 25, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 25, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_block, __pyx_t_3);
        __pyx_t_3 = 0;

        /* "ddb/lexer/lexer.py":26
 *             if not in_block:
 *                 for block in blocks:
 *                     if c==block[0]:             # <<<<<<<<<<<<<<
 *                         in_block=True
 *                         curent_block=block
 */
        __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_block, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 26, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = PyObject_RichCompare(__pyx_v_c, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 26, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_9) {

          /* "ddb/lexer/lexer.py":27
 *                 for block in blocks:
 *                     if c==block[0]:
 *                         in_block=True             # <<<<<<<<<<<<<<
 *                         curent_block=block
 *                         break
 */
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_in_block, Py_True);

          /* "ddb/lexer/lexer.py":28
 *                     if c==block[0]:
 *                         in_block=True
 *                         curent_block=block             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
          __Pyx_INCREF(__pyx_v_block);
          __Pyx_DECREF_SET(__pyx_v_curent_block, __pyx_v_block);

          /* "ddb/lexer/lexer.py":29
 *                         in_block=True
 *                         curent_block=block
 *                         break             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
          goto __pyx_L7_break;

          /* "ddb/lexer/lexer.py":26
 *             if not in_block:
 *                 for block in blocks:
 *                     if c==block[0]:             # <<<<<<<<<<<<<<
 *                         in_block=True
 *                         curent_block=block
 */
        }

        /* "ddb/lexer/lexer.py":25
 *         for c in data:
 *             if not in_block:
 *                 for block in blocks:             # <<<<<<<<<<<<<<
 *                     if c==block[0]:
 *                         in_block=True
 */
      }
      __pyx_L7_break:;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "ddb/lexer/lexer.py":24
 * 
 *         for c in data:
 *             if not in_block:             # <<<<<<<<<<<<<<
 *                 for block in blocks:
 *                     if c==block[0]:
 */
      goto __pyx_L5;
    }

    /* "ddb/lexer/lexer.py":32
 * 
 *             else:
 *                 if c==curent_block[1]:             # <<<<<<<<<<<<<<
 *                     in_block=None
 *                     curent_block=None
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_curent_block, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_c, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 32, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_9) {

        /* "ddb/lexer/lexer.py":33
 *             else:
 *                 if c==curent_block[1]:
 *                     in_block=None             # <<<<<<<<<<<<<<
 *                     curent_block=None
 *                 index+=1
 */
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_in_block, Py_None);

        /* "ddb/lexer/lexer.py":34
 *                 if c==curent_block[1]:
 *                     in_block=None
 *                     curent_block=None             # <<<<<<<<<<<<<<
 *                 index+=1
 *                 continue
 */
        __Pyx_INCREF(Py_None);
        __Pyx_DECREF_SET(__pyx_v_curent_block, Py_None);

        /* "ddb/lexer/lexer.py":32
 * 
 *             else:
 *                 if c==curent_block[1]:             # <<<<<<<<<<<<<<
 *                     in_block=None
 *                     curent_block=None
 */
      }

      /* "ddb/lexer/lexer.py":35
 *                     in_block=None
 *                     curent_block=None
 *                 index+=1             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 35, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":36
 *                     curent_block=None
 *                 index+=1
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             if c==delimiter:
 */
      goto __pyx_L3_continue;
    }
    __pyx_L5:;

    /* "ddb/lexer/lexer.py":38
 *                 continue
 * 
 *             if c==delimiter:             # <<<<<<<<<<<<<<
 *                 list_of_strings.append(data[last_index:index])
 *                 last_index=index+1
 */
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_c, __pyx_v_delimiter, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 38, __pyx_L1_error)
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 38, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {

      /* "ddb/lexer/lexer.py":39
 * 
 *             if c==delimiter:
 *                 list_of_strings.append(data[last_index:index])             # <<<<<<<<<<<<<<
 *                 last_index=index+1
 *             index+=1
 */
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_data, 0, 0, &__pyx_v_last_index, &__pyx_v_index, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 39, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_list_of_strings, __pyx_t_2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 39, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":40
 *             if c==delimiter:
 *                 list_of_strings.append(data[last_index:index])
 *                 last_index=index+1             # <<<<<<<<<<<<<<
 *             index+=1
 *         if index!=last_index:
 */
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_index, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 40, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_last_index, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":38
 *                 continue
 * 
 *             if c==delimiter:             # <<<<<<<<<<<<<<
 *                 list_of_strings.append(data[last_index:index])
 *                 last_index=index+1
 */
    }

    /* "ddb/lexer/lexer.py":41
 *                 list_of_strings.append(data[last_index:index])
 *                 last_index=index+1
 *             index+=1             # <<<<<<<<<<<<<<
 *         if index!=last_index:
 *                 list_of_strings.append(data[last_index:])
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 41, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":23
 *         list_of_strings=[]                     # the list of split strings
 * 
 *         for c in data:             # <<<<<<<<<<<<<<
 *             if not in_block:
 *                 for block in blocks:
 */
    __pyx_L3_continue:;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "ddb/lexer/lexer.py":42
 *                 last_index=index+1
 *             index+=1
 *         if index!=last_index:             # <<<<<<<<<<<<<<
 *                 list_of_strings.append(data[last_index:])
 *         return list_of_strings
 */
  __pyx_t_5 = PyObject_RichCompare(__pyx_v_index, __pyx_v_last_index, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 42, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 42, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_9) {

    /* "ddb/lexer/lexer.py":43
 *             index+=1
 *         if index!=last_index:
 *                 list_of_strings.append(data[last_index:])             # <<<<<<<<<<<<<<
 *         return list_of_strings
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetSlice(__pyx_v_data, 0, 0, &__pyx_v_last_index, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_list_of_strings, __pyx_t_5); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 43, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ddb/lexer/lexer.py":42
 *                 last_index=index+1
 *             index+=1
 *         if index!=last_index:             # <<<<<<<<<<<<<<
 *                 list_of_strings.append(data[last_index:])
 *         return list_of_strings
 */
  }

  /* "ddb/lexer/lexer.py":44
 *         if index!=last_index:
 *                 list_of_strings.append(data[last_index:])
 *         return list_of_strings             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_list_of_strings);
  __pyx_r = __pyx_v_list_of_strings;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":10
 *     __slots__=['keep_non_keywords','debug','query_objects']
 * 
 *     def split(self,data,delimiter=';'):             # <<<<<<<<<<<<<<
 *         in_block    = None
 *         curent_block= None
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.split", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_in_block);
  __Pyx_XDECREF(__pyx_v_curent_block);
  __Pyx_XDECREF(__pyx_v_last_index);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_blocks);
  __Pyx_XDECREF(__pyx_v_list_of_strings);
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XDECREF(__pyx_v_block);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":47
 * 
 * 
 *     def __init__(self, query, debug=None):             # <<<<<<<<<<<<<<
 *         #queries=self.split(query,';')
 *         #print "****"
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_3__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_3__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_3__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_query = 0;
  PyObject *__pyx_v_debug = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_query,&__pyx_n_s_debug,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_query)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, 1); __PYX_ERR(0, 47, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_debug);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 47, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_query = values[1];
    __pyx_v_debug = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 47, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_2__init__(__pyx_self, __pyx_v_self, __pyx_v_query, __pyx_v_debug);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_2__init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_query, PyObject *__pyx_v_debug) {
  PyObject *__pyx_v_querys = NULL;
  PyObject *__pyx_v_q = NULL;
  PyObject *__pyx_v_tokens = NULL;
  PyObject *__pyx_v_token_length = NULL;
  PyObject *__pyx_v_token = NULL;
  PyObject *__pyx_v_parsed = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  int __pyx_t_13;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "ddb/lexer/lexer.py":62
 *         # keep non variable keywords form signature match in object
 *         # realy only need this for debugging
 *         self.keep_non_keywords=True             # <<<<<<<<<<<<<<
 *         self.debug = debug
 *         self.query_objects = []
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_keep_non_keywords, Py_True) < 0) __PYX_ERR(0, 62, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":63
 *         # realy only need this for debugging
 *         self.keep_non_keywords=True
 *         self.debug = debug             # <<<<<<<<<<<<<<
 *         self.query_objects = []
 *         if  query==None:
 */
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_debug, __pyx_v_debug) < 0) __PYX_ERR(0, 63, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":64
 *         self.keep_non_keywords=True
 *         self.debug = debug
 *         self.query_objects = []             # <<<<<<<<<<<<<<
 *         if  query==None:
 *             raise Exception("Invalid Syntax")
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_query_objects, __pyx_t_1) < 0) __PYX_ERR(0, 64, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":65
 *         self.debug = debug
 *         self.query_objects = []
 *         if  query==None:             # <<<<<<<<<<<<<<
 *             raise Exception("Invalid Syntax")
 * 
 */
  __pyx_t_1 = PyObject_RichCompare(__pyx_v_query, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 65, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__pyx_t_2)) {

    /* "ddb/lexer/lexer.py":66
 *         self.query_objects = []
 *         if  query==None:
 *             raise Exception("Invalid Syntax")             # <<<<<<<<<<<<<<
 * 
 *         #print query
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 66, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 66, __pyx_L1_error)

    /* "ddb/lexer/lexer.py":65
 *         self.debug = debug
 *         self.query_objects = []
 *         if  query==None:             # <<<<<<<<<<<<<<
 *             raise Exception("Invalid Syntax")
 * 
 */
  }

  /* "ddb/lexer/lexer.py":71
 * 
 *         #print("---------------------")
 *         querys = self.split(query,';')             # <<<<<<<<<<<<<<
 *         #print querys
 *         #querys = query.split(';')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_split); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_query, __pyx_kp_s_};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_v_query, __pyx_kp_s_};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_v_query);
    __Pyx_GIVEREF(__pyx_v_query);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_v_query);
    __Pyx_INCREF(__pyx_kp_s_);
    __Pyx_GIVEREF(__pyx_kp_s_);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_kp_s_);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 71, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_querys = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":74
 *         #print querys
 *         #querys = query.split(';')
 *         self.info("Queries", querys)             # <<<<<<<<<<<<<<
 *         #print querys
 *         for q in querys:
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_Queries, __pyx_v_querys};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_n_s_Queries, __pyx_v_querys};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (__pyx_t_6) {
      __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6); __pyx_t_6 = NULL;
    }
    __Pyx_INCREF(__pyx_n_s_Queries);
    __Pyx_GIVEREF(__pyx_n_s_Queries);
    PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_n_s_Queries);
    __Pyx_INCREF(__pyx_v_querys);
    __Pyx_GIVEREF(__pyx_v_querys);
    PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_v_querys);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":76
 *         self.info("Queries", querys)
 *         #print querys
 *         for q in querys:             # <<<<<<<<<<<<<<
 *             self.info("-----------------------------------")
 *             if q and q.isspace():
 */
  if (likely(PyList_CheckExact(__pyx_v_querys)) || PyTuple_CheckExact(__pyx_v_querys)) {
    __pyx_t_1 = __pyx_v_querys; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
    __pyx_t_8 = NULL;
  } else {
    __pyx_t_7 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_querys); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 76, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 76, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_8)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 76, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_3); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 76, __pyx_L1_error)
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 76, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_8(__pyx_t_1);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 76, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_q, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":77
 *         #print querys
 *         for q in querys:
 *             self.info("-----------------------------------")             # <<<<<<<<<<<<<<
 *             if q and q.isspace():
 *                 continue
 */
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_6, __pyx_kp_s__8) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_s__8);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":78
 *         for q in querys:
 *             self.info("-----------------------------------")
 *             if q and q.isspace():             # <<<<<<<<<<<<<<
 *                 continue
 *             tokens = tokenizer().chomp(q, discard_whitespace=True, debug=debug)
 */
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_v_q); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 78, __pyx_L1_error)
    if (__pyx_t_9) {
    } else {
      __pyx_t_2 = __pyx_t_9;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_q, __pyx_n_s_isspace); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 78, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_2 = __pyx_t_9;
    __pyx_L7_bool_binop_done:;
    if (__pyx_t_2) {

      /* "ddb/lexer/lexer.py":79
 *             self.info("-----------------------------------")
 *             if q and q.isspace():
 *                 continue             # <<<<<<<<<<<<<<
 *             tokens = tokenizer().chomp(q, discard_whitespace=True, debug=debug)
 *             # skip 0 length commands such as single ';'
 */
      goto __pyx_L4_continue;

      /* "ddb/lexer/lexer.py":78
 *         for q in querys:
 *             self.info("-----------------------------------")
 *             if q and q.isspace():             # <<<<<<<<<<<<<<
 *                 continue
 *             tokens = tokenizer().chomp(q, discard_whitespace=True, debug=debug)
 */
    }

    /* "ddb/lexer/lexer.py":80
 *             if q and q.isspace():
 *                 continue
 *             tokens = tokenizer().chomp(q, discard_whitespace=True, debug=debug)             # <<<<<<<<<<<<<<
 *             # skip 0 length commands such as single ';'
 *             token_length = 0
 */
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_tokenizer); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_6) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_6) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_chomp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_q);
    __Pyx_GIVEREF(__pyx_v_q);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_q);
    __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_discard_whitespace, Py_True) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_debug, __pyx_v_debug) < 0) __PYX_ERR(0, 80, __pyx_L1_error)
    __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_tokens, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "ddb/lexer/lexer.py":82
 *             tokens = tokenizer().chomp(q, discard_whitespace=True, debug=debug)
 *             # skip 0 length commands such as single ';'
 *             token_length = 0             # <<<<<<<<<<<<<<
 *             for token in tokens:
 *                 if token['data'] != '':
 */
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_XDECREF_SET(__pyx_v_token_length, __pyx_int_0);

    /* "ddb/lexer/lexer.py":83
 *             # skip 0 length commands such as single ';'
 *             token_length = 0
 *             for token in tokens:             # <<<<<<<<<<<<<<
 *                 if token['data'] != '':
 *                     token_length += 1
 */
    if (likely(PyList_CheckExact(__pyx_v_tokens)) || PyTuple_CheckExact(__pyx_v_tokens)) {
      __pyx_t_10 = __pyx_v_tokens; __Pyx_INCREF(__pyx_t_10); __pyx_t_11 = 0;
      __pyx_t_12 = NULL;
    } else {
      __pyx_t_11 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_v_tokens); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 83, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 83, __pyx_L1_error)
    }
    for (;;) {
      if (likely(!__pyx_t_12)) {
        if (likely(PyList_CheckExact(__pyx_t_10))) {
          if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_10)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_11); __Pyx_INCREF(__pyx_t_6); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 83, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_10, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 83, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        } else {
          if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_11); __Pyx_INCREF(__pyx_t_6); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 83, __pyx_L1_error)
          #else
          __pyx_t_6 = PySequence_ITEM(__pyx_t_10, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 83, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
        }
      } else {
        __pyx_t_6 = __pyx_t_12(__pyx_t_10);
        if (unlikely(!__pyx_t_6)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 83, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_6);
      }
      __Pyx_XDECREF_SET(__pyx_v_token, __pyx_t_6);
      __pyx_t_6 = 0;

      /* "ddb/lexer/lexer.py":84
 *             token_length = 0
 *             for token in tokens:
 *                 if token['data'] != '':             # <<<<<<<<<<<<<<
 *                     token_length += 1
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_token, __pyx_n_s_data); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 84, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_t_6, __pyx_kp_s__9, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 84, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_2) {

        /* "ddb/lexer/lexer.py":85
 *             for token in tokens:
 *                 if token['data'] != '':
 *                     token_length += 1             # <<<<<<<<<<<<<<
 * 
 *             self.info("Token Length", token_length)
 */
        __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_token_length, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 85, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF_SET(__pyx_v_token_length, __pyx_t_6);
        __pyx_t_6 = 0;

        /* "ddb/lexer/lexer.py":84
 *             token_length = 0
 *             for token in tokens:
 *                 if token['data'] != '':             # <<<<<<<<<<<<<<
 *                     token_length += 1
 * 
 */
      }

      /* "ddb/lexer/lexer.py":83
 *             # skip 0 length commands such as single ';'
 *             token_length = 0
 *             for token in tokens:             # <<<<<<<<<<<<<<
 *                 if token['data'] != '':
 *                     token_length += 1
 */
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "ddb/lexer/lexer.py":87
 *                     token_length += 1
 * 
 *             self.info("Token Length", token_length)             # <<<<<<<<<<<<<<
 *             if token_length == 0:
 *                 continue
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 87, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_s_Token_Length, __pyx_v_token_length};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 87, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_6)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_s_Token_Length, __pyx_v_token_length};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_6, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 87, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_10);
    } else
    #endif
    {
      __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 87, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_s_Token_Length);
      __Pyx_GIVEREF(__pyx_kp_s_Token_Length);
      PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_kp_s_Token_Length);
      __Pyx_INCREF(__pyx_v_token_length);
      __Pyx_GIVEREF(__pyx_v_token_length);
      PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_v_token_length);
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_4, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 87, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "ddb/lexer/lexer.py":88
 * 
 *             self.info("Token Length", token_length)
 *             if token_length == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
    __pyx_t_10 = __Pyx_PyInt_EqObjC(__pyx_v_token_length, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 88, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (__pyx_t_2) {

      /* "ddb/lexer/lexer.py":89
 *             self.info("Token Length", token_length)
 *             if token_length == 0:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             parsed = self.parse(tokens)
 */
      goto __pyx_L4_continue;

      /* "ddb/lexer/lexer.py":88
 * 
 *             self.info("Token Length", token_length)
 *             if token_length == 0:             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
    }

    /* "ddb/lexer/lexer.py":91
 *                 continue
 * 
 *             parsed = self.parse(tokens)             # <<<<<<<<<<<<<<
 *             if None == parsed['success']:
 *                 raise Exception(parsed['msg'])
 */
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_parse); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_10 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_4, __pyx_v_tokens) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_v_tokens);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 91, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF_SET(__pyx_v_parsed, __pyx_t_10);
    __pyx_t_10 = 0;

    /* "ddb/lexer/lexer.py":92
 * 
 *             parsed = self.parse(tokens)
 *             if None == parsed['success']:             # <<<<<<<<<<<<<<
 *                 raise Exception(parsed['msg'])
 *             else:
 */
    __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_parsed, __pyx_n_s_success); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_6 = PyObject_RichCompare(Py_None, __pyx_t_10, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 92, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_t_2)) {

      /* "ddb/lexer/lexer.py":93
 *             parsed = self.parse(tokens)
 *             if None == parsed['success']:
 *                 raise Exception(parsed['msg'])             # <<<<<<<<<<<<<<
 *             else:
 *                 if None == parsed['results']:
 */
      __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_parsed, __pyx_n_s_msg); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 93, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(0, 93, __pyx_L1_error)

      /* "ddb/lexer/lexer.py":92
 * 
 *             parsed = self.parse(tokens)
 *             if None == parsed['success']:             # <<<<<<<<<<<<<<
 *                 raise Exception(parsed['msg'])
 *             else:
 */
    }

    /* "ddb/lexer/lexer.py":95
 *                 raise Exception(parsed['msg'])
 *             else:
 *                 if None == parsed['results']:             # <<<<<<<<<<<<<<
 *                     continue
 *                 self.query_objects.append(parsed['results'])
 */
    /*else*/ {
      __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_parsed, __pyx_n_s_results); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_6 = PyObject_RichCompare(Py_None, __pyx_t_10, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 95, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (__pyx_t_2) {

        /* "ddb/lexer/lexer.py":96
 *             else:
 *                 if None == parsed['results']:
 *                     continue             # <<<<<<<<<<<<<<
 *                 self.query_objects.append(parsed['results'])
 * 
 */
        goto __pyx_L4_continue;

        /* "ddb/lexer/lexer.py":95
 *                 raise Exception(parsed['msg'])
 *             else:
 *                 if None == parsed['results']:             # <<<<<<<<<<<<<<
 *                     continue
 *                 self.query_objects.append(parsed['results'])
 */
      }

      /* "ddb/lexer/lexer.py":97
 *                 if None == parsed['results']:
 *                     continue
 *                 self.query_objects.append(parsed['results'])             # <<<<<<<<<<<<<<
 * 
 *         if len(self.query_objects)==0:
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_query_objects); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_parsed, __pyx_n_s_results); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_13 = __Pyx_PyObject_Append(__pyx_t_6, __pyx_t_10); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(0, 97, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }

    /* "ddb/lexer/lexer.py":76
 *         self.info("Queries", querys)
 *         #print querys
 *         for q in querys:             # <<<<<<<<<<<<<<
 *             self.info("-----------------------------------")
 *             if q and q.isspace():
 */
    __pyx_L4_continue:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":99
 *                 self.query_objects.append(parsed['results'])
 * 
 *         if len(self.query_objects)==0:             # <<<<<<<<<<<<<<
 *             raise Exception("Invalid Syntax")
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_query_objects); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 99, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((__pyx_t_7 == 0) != 0);
  if (unlikely(__pyx_t_2)) {

    /* "ddb/lexer/lexer.py":100
 * 
 *         if len(self.query_objects)==0:
 *             raise Exception("Invalid Syntax")             # <<<<<<<<<<<<<<
 * 
 *     def get_argument(self,word,segment,tokens,token_index,w_index):
 */
    __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 100, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(0, 100, __pyx_L1_error)

    /* "ddb/lexer/lexer.py":99
 *                 self.query_objects.append(parsed['results'])
 * 
 *         if len(self.query_objects)==0:             # <<<<<<<<<<<<<<
 *             raise Exception("Invalid Syntax")
 * 
 */
  }

  /* "ddb/lexer/lexer.py":47
 * 
 * 
 *     def __init__(self, query, debug=None):             # <<<<<<<<<<<<<<
 *         #queries=self.split(query,';')
 *         #print "****"
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_querys);
  __Pyx_XDECREF(__pyx_v_q);
  __Pyx_XDECREF(__pyx_v_tokens);
  __Pyx_XDECREF(__pyx_v_token_length);
  __Pyx_XDECREF(__pyx_v_token);
  __Pyx_XDECREF(__pyx_v_parsed);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":102
 *             raise Exception("Invalid Syntax")
 * 
 *     def get_argument(self,word,segment,tokens,token_index,w_index):             # <<<<<<<<<<<<<<
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_5get_argument(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_5get_argument = {"get_argument", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_5get_argument, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_5get_argument(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_word = 0;
  PyObject *__pyx_v_segment = 0;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_v_token_index = 0;
  PyObject *__pyx_v_w_index = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_argument (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_word,&__pyx_n_s_segment,&__pyx_n_s_tokens,&__pyx_n_s_token_index,&__pyx_n_s_w_index,0};
    PyObject* values[6] = {0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_word)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, 1); __PYX_ERR(0, 102, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_segment)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, 2); __PYX_ERR(0, 102, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, 3); __PYX_ERR(0, 102, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_token_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, 4); __PYX_ERR(0, 102, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_w_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, 5); __PYX_ERR(0, 102, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_argument") < 0)) __PYX_ERR(0, 102, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 6) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
    }
    __pyx_v_self = values[0];
    __pyx_v_word = values[1];
    __pyx_v_segment = values[2];
    __pyx_v_tokens = values[3];
    __pyx_v_token_index = values[4];
    __pyx_v_w_index = values[5];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_argument", 1, 6, 6, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 102, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_4get_argument(__pyx_self, __pyx_v_self, __pyx_v_word, __pyx_v_segment, __pyx_v_tokens, __pyx_v_token_index, __pyx_v_w_index);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_4get_argument(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_word, PyObject *__pyx_v_segment, PyObject *__pyx_v_tokens, PyObject *__pyx_v_token_index, PyObject *__pyx_v_w_index) {
  PyObject *__pyx_v_variable_data = NULL;
  PyObject *__pyx_v_first_char = NULL;
  PyObject *__pyx_v_last_char = NULL;
  PyObject *__pyx_v_definition = NULL;
  PyObject *__pyx_v_variable = NULL;
  PyObject *__pyx_v_variable_type = NULL;
  PyObject *__pyx_v_argument = NULL;
  PyObject *__pyx_v_err_msg = NULL;
  PyObject *__pyx_v_index_of_colon = NULL;
  PyObject *__pyx_v_key = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  __Pyx_RefNannySetupContext("get_argument", 0);

  /* "ddb/lexer/lexer.py":104
 *     def get_argument(self,word,segment,tokens,token_index,w_index):
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']             # <<<<<<<<<<<<<<
 *         first_char=word[0:1]
 *         last_char=word[-1]
 */
  __pyx_t_1 = PyNumber_Add(__pyx_v_token_index, __pyx_v_w_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_variable_data = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":105
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 *         first_char=word[0:1]             # <<<<<<<<<<<<<<
 *         last_char=word[-1]
 *         #if first_char == '[' and last_char == ']':
 */
  __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_word, 0, 1, NULL, NULL, &__pyx_slice__10, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_first_char = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":106
 *         variable_data=tokens[token_index + w_index]['data']
 *         first_char=word[0:1]
 *         last_char=word[-1]             # <<<<<<<<<<<<<<
 *         #if first_char == '[' and last_char == ']':
 *         #    definition='array'
 */
  __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_word, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_last_char = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":109
 *         #if first_char == '[' and last_char == ']':
 *         #    definition='array'
 *         if first_char == '{' and last_char == '}':             # <<<<<<<<<<<<<<
 *                 definition='single'
 *         elif first_char == '$':
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_first_char, __pyx_kp_s__11, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 109, __pyx_L1_error)
  if (__pyx_t_4) {
  } else {
    __pyx_t_3 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_last_char, __pyx_kp_s__12, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 109, __pyx_L1_error)
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_3) {

    /* "ddb/lexer/lexer.py":110
 *         #    definition='array'
 *         if first_char == '{' and last_char == '}':
 *                 definition='single'             # <<<<<<<<<<<<<<
 *         elif first_char == '$':
 *             definition='internal'
 */
    __Pyx_INCREF(__pyx_n_s_single);
    __pyx_v_definition = __pyx_n_s_single;

    /* "ddb/lexer/lexer.py":109
 *         #if first_char == '[' and last_char == ']':
 *         #    definition='array'
 *         if first_char == '{' and last_char == '}':             # <<<<<<<<<<<<<<
 *                 definition='single'
 *         elif first_char == '$':
 */
    goto __pyx_L3;
  }

  /* "ddb/lexer/lexer.py":111
 *         if first_char == '{' and last_char == '}':
 *                 definition='single'
 *         elif first_char == '$':             # <<<<<<<<<<<<<<
 *             definition='internal'
 *         else:
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_first_char, __pyx_kp_s__13, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 111, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "ddb/lexer/lexer.py":112
 *                 definition='single'
 *         elif first_char == '$':
 *             definition='internal'             # <<<<<<<<<<<<<<
 *         else:
 *             definition=None
 */
    __Pyx_INCREF(__pyx_n_s_internal);
    __pyx_v_definition = __pyx_n_s_internal;

    /* "ddb/lexer/lexer.py":111
 *         if first_char == '{' and last_char == '}':
 *                 definition='single'
 *         elif first_char == '$':             # <<<<<<<<<<<<<<
 *             definition='internal'
 *         else:
 */
    goto __pyx_L3;
  }

  /* "ddb/lexer/lexer.py":114
 *             definition='internal'
 *         else:
 *             definition=None             # <<<<<<<<<<<<<<
 * 
 *         # HERE ADD add string length enforcment for colon +1 -1 same for brackets
 */
  /*else*/ {
    __Pyx_INCREF(Py_None);
    __pyx_v_definition = Py_None;
  }
  __pyx_L3:;

  /* "ddb/lexer/lexer.py":118
 *         # HERE ADD add string length enforcment for colon +1 -1 same for brackets
 * 
 *         if definition=='single':             # <<<<<<<<<<<<<<
 *             variable=word[1:-1]
 *             variable_type='string'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_definition, __pyx_n_s_single, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 118, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "ddb/lexer/lexer.py":119
 * 
 *         if definition=='single':
 *             variable=word[1:-1]             # <<<<<<<<<<<<<<
 *             variable_type='string'
 *             if 'specs' in segment:
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_word, 1, -1L, NULL, NULL, &__pyx_slice__14, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_variable = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":120
 *         if definition=='single':
 *             variable=word[1:-1]
 *             variable_type='string'             # <<<<<<<<<<<<<<
 *             if 'specs' in segment:
 *                 # if this is in or definitions
 */
    __Pyx_INCREF(__pyx_n_s_string);
    __pyx_v_variable_type = __pyx_n_s_string;

    /* "ddb/lexer/lexer.py":121
 *             variable=word[1:-1]
 *             variable_type='string'
 *             if 'specs' in segment:             # <<<<<<<<<<<<<<
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:
 */
    __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_specs, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 121, __pyx_L1_error)
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":123
 *             if 'specs' in segment:
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:             # <<<<<<<<<<<<<<
 *                     if 'type' in segment['specs'][variable]:
 *                         variable_type=segment['specs'][variable]['type']
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_specs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 123, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_v_variable, __pyx_t_1, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 123, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_3 = (__pyx_t_4 != 0);
      if (__pyx_t_3) {

        /* "ddb/lexer/lexer.py":124
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:
 *                     if 'type' in segment['specs'][variable]:             # <<<<<<<<<<<<<<
 *                         variable_type=segment['specs'][variable]['type']
 * 
 */
        __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_specs); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_variable); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_3 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_type, __pyx_t_2, Py_EQ)); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 124, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_4 = (__pyx_t_3 != 0);
        if (__pyx_t_4) {

          /* "ddb/lexer/lexer.py":125
 *                 if variable in segment['specs']:
 *                     if 'type' in segment['specs'][variable]:
 *                         variable_type=segment['specs'][variable]['type']             # <<<<<<<<<<<<<<
 * 
 *             argument=None
 */
          __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_specs); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_variable); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 125, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 125, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_DECREF_SET(__pyx_v_variable_type, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":124
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:
 *                     if 'type' in segment['specs'][variable]:             # <<<<<<<<<<<<<<
 *                         variable_type=segment['specs'][variable]['type']
 * 
 */
        }

        /* "ddb/lexer/lexer.py":123
 *             if 'specs' in segment:
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:             # <<<<<<<<<<<<<<
 *                     if 'type' in segment['specs'][variable]:
 *                         variable_type=segment['specs'][variable]['type']
 */
      }

      /* "ddb/lexer/lexer.py":121
 *             variable=word[1:-1]
 *             variable_type='string'
 *             if 'specs' in segment:             # <<<<<<<<<<<<<<
 *                 # if this is in or definitions
 *                 if variable in segment['specs']:
 */
    }

    /* "ddb/lexer/lexer.py":127
 *                         variable_type=segment['specs'][variable]['type']
 * 
 *             argument=None             # <<<<<<<<<<<<<<
 *             if variable_type=='int':
 *                 try:
 */
    __Pyx_INCREF(Py_None);
    __pyx_v_argument = Py_None;

    /* "ddb/lexer/lexer.py":128
 * 
 *             argument=None
 *             if variable_type=='int':             # <<<<<<<<<<<<<<
 *                 try:
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 */
    __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_variable_type, __pyx_n_s_int, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 128, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":129
 *             argument=None
 *             if variable_type=='int':
 *                 try:             # <<<<<<<<<<<<<<
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 *                     argument = tokens[token_index + w_index]['data']
 */
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_7);
        /*try:*/ {

          /* "ddb/lexer/lexer.py":130
 *             if variable_type=='int':
 *                 try:
 *                     tokens[token_index + w_index]['data'] = int(variable_data)             # <<<<<<<<<<<<<<
 *                     argument = tokens[token_index + w_index]['data']
 *                 except BaseException:
 */
          __pyx_t_2 = __Pyx_PyNumber_Int(__pyx_v_variable_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 130, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_1 = PyNumber_Add(__pyx_v_token_index, __pyx_v_w_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 130, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_t_1); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 130, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(PyObject_SetItem(__pyx_t_8, __pyx_n_s_data, __pyx_t_2) < 0)) __PYX_ERR(0, 130, __pyx_L11_error)
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":131
 *                 try:
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 *                     argument = tokens[token_index + w_index]['data']             # <<<<<<<<<<<<<<
 *                 except BaseException:
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)
 */
          __pyx_t_2 = PyNumber_Add(__pyx_v_token_index, __pyx_v_w_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 131, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_8, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 131, __pyx_L11_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF_SET(__pyx_v_argument, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":129
 *             argument=None
 *             if variable_type=='int':
 *                 try:             # <<<<<<<<<<<<<<
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 *                     argument = tokens[token_index + w_index]['data']
 */
        }
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        goto __pyx_L16_try_end;
        __pyx_L11_error:;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

        /* "ddb/lexer/lexer.py":132
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 *                     argument = tokens[token_index + w_index]['data']
 *                 except BaseException:             # <<<<<<<<<<<<<<
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)
 *                     raise Exception (err_msg)
 */
        __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_BaseException);
        if (__pyx_t_9) {
          __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_8, &__pyx_t_1) < 0) __PYX_ERR(0, 132, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_t_8);
          __Pyx_GOTREF(__pyx_t_1);

          /* "ddb/lexer/lexer.py":133
 *                     argument = tokens[token_index + w_index]['data']
 *                 except BaseException:
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)             # <<<<<<<<<<<<<<
 *                     raise Exception (err_msg)
 *             elif variable_type=='bool':
 */
          __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Variable_data_not_an_integer_0, __pyx_n_s_format); if (unlikely(!__pyx_t_11)) __PYX_ERR(0, 133, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_11);
          __pyx_t_12 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_11))) {
            __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
            if (likely(__pyx_t_12)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_11, function);
            }
          }
          __pyx_t_10 = (__pyx_t_12) ? __Pyx_PyObject_Call2Args(__pyx_t_11, __pyx_t_12, __pyx_v_variable_data) : __Pyx_PyObject_CallOneArg(__pyx_t_11, __pyx_v_variable_data);
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 133, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
          __pyx_v_err_msg = __pyx_t_10;
          __pyx_t_10 = 0;

          /* "ddb/lexer/lexer.py":134
 *                 except BaseException:
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)
 *                     raise Exception (err_msg)             # <<<<<<<<<<<<<<
 *             elif variable_type=='bool':
 *                 if variable_data.lower()=='true':
 */
          __pyx_t_10 = __Pyx_PyObject_CallOneArg(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_v_err_msg); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 134, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_Raise(__pyx_t_10, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __PYX_ERR(0, 134, __pyx_L13_except_error)
        }
        goto __pyx_L13_except_error;
        __pyx_L13_except_error:;

        /* "ddb/lexer/lexer.py":129
 *             argument=None
 *             if variable_type=='int':
 *                 try:             # <<<<<<<<<<<<<<
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 *                     argument = tokens[token_index + w_index]['data']
 */
        __Pyx_XGIVEREF(__pyx_t_5);
        __Pyx_XGIVEREF(__pyx_t_6);
        __Pyx_XGIVEREF(__pyx_t_7);
        __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
        goto __pyx_L1_error;
        __pyx_L16_try_end:;
      }

      /* "ddb/lexer/lexer.py":128
 * 
 *             argument=None
 *             if variable_type=='int':             # <<<<<<<<<<<<<<
 *                 try:
 *                     tokens[token_index + w_index]['data'] = int(variable_data)
 */
      goto __pyx_L10;
    }

    /* "ddb/lexer/lexer.py":135
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)
 *                     raise Exception (err_msg)
 *             elif variable_type=='bool':             # <<<<<<<<<<<<<<
 *                 if variable_data.lower()=='true':
 *                     argument=True
 */
    __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_variable_type, __pyx_n_s_bool, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 135, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":136
 *                     raise Exception (err_msg)
 *             elif variable_type=='bool':
 *                 if variable_data.lower()=='true':             # <<<<<<<<<<<<<<
 *                     argument=True
 *                 elif variable_data.lower()=='false':
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_variable_data, __pyx_n_s_lower); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_true, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 136, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__pyx_t_4) {

        /* "ddb/lexer/lexer.py":137
 *             elif variable_type=='bool':
 *                 if variable_data.lower()=='true':
 *                     argument=True             # <<<<<<<<<<<<<<
 *                 elif variable_data.lower()=='false':
 *                     argument =False
 */
        __Pyx_INCREF(Py_True);
        __Pyx_DECREF_SET(__pyx_v_argument, Py_True);

        /* "ddb/lexer/lexer.py":136
 *                     raise Exception (err_msg)
 *             elif variable_type=='bool':
 *                 if variable_data.lower()=='true':             # <<<<<<<<<<<<<<
 *                     argument=True
 *                 elif variable_data.lower()=='false':
 */
        goto __pyx_L19;
      }

      /* "ddb/lexer/lexer.py":138
 *                 if variable_data.lower()=='true':
 *                     argument=True
 *                 elif variable_data.lower()=='false':             # <<<<<<<<<<<<<<
 *                     argument =False
 *                 else:
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_variable_data, __pyx_n_s_lower); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_t_1, __pyx_n_s_false, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 138, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (likely(__pyx_t_4)) {

        /* "ddb/lexer/lexer.py":139
 *                     argument=True
 *                 elif variable_data.lower()=='false':
 *                     argument =False             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise Exception("Variable Data not boolean")
 */
        __Pyx_INCREF(Py_False);
        __Pyx_DECREF_SET(__pyx_v_argument, Py_False);

        /* "ddb/lexer/lexer.py":138
 *                 if variable_data.lower()=='true':
 *                     argument=True
 *                 elif variable_data.lower()=='false':             # <<<<<<<<<<<<<<
 *                     argument =False
 *                 else:
 */
        goto __pyx_L19;
      }

      /* "ddb/lexer/lexer.py":141
 *                     argument =False
 *                 else:
 *                     raise Exception("Variable Data not boolean")             # <<<<<<<<<<<<<<
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:
 */
      /*else*/ {
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__15, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 141, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 141, __pyx_L1_error)
      }
      __pyx_L19:;

      /* "ddb/lexer/lexer.py":135
 *                     err_msg="Variable data not an integer '{0}'".format(variable_data,)
 *                     raise Exception (err_msg)
 *             elif variable_type=='bool':             # <<<<<<<<<<<<<<
 *                 if variable_data.lower()=='true':
 *                     argument=True
 */
      goto __pyx_L10;
    }

    /* "ddb/lexer/lexer.py":142
 *                 else:
 *                     raise Exception("Variable Data not boolean")
 *             elif variable_type=='char':             # <<<<<<<<<<<<<<
 *                 if len(variable_data)!=1:
 *                     raise Exception("variable data length exceeded, type char")
 */
    __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_variable_type, __pyx_n_s_char, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 142, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":143
 *                     raise Exception("Variable Data not boolean")
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:             # <<<<<<<<<<<<<<
 *                     raise Exception("variable data length exceeded, type char")
 *                 argument =variable_data
 */
      __pyx_t_13 = PyObject_Length(__pyx_v_variable_data); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 143, __pyx_L1_error)
      __pyx_t_4 = ((__pyx_t_13 != 1) != 0);
      if (unlikely(__pyx_t_4)) {

        /* "ddb/lexer/lexer.py":144
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:
 *                     raise Exception("variable data length exceeded, type char")             # <<<<<<<<<<<<<<
 *                 argument =variable_data
 *             #default catch
 */
        __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 144, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_Raise(__pyx_t_1, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __PYX_ERR(0, 144, __pyx_L1_error)

        /* "ddb/lexer/lexer.py":143
 *                     raise Exception("Variable Data not boolean")
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:             # <<<<<<<<<<<<<<
 *                     raise Exception("variable data length exceeded, type char")
 *                 argument =variable_data
 */
      }

      /* "ddb/lexer/lexer.py":145
 *                 if len(variable_data)!=1:
 *                     raise Exception("variable data length exceeded, type char")
 *                 argument =variable_data             # <<<<<<<<<<<<<<
 *             #default catch
 *             elif variable_type=='string':
 */
      __Pyx_INCREF(__pyx_v_variable_data);
      __Pyx_DECREF_SET(__pyx_v_argument, __pyx_v_variable_data);

      /* "ddb/lexer/lexer.py":142
 *                 else:
 *                     raise Exception("Variable Data not boolean")
 *             elif variable_type=='char':             # <<<<<<<<<<<<<<
 *                 if len(variable_data)!=1:
 *                     raise Exception("variable data length exceeded, type char")
 */
      goto __pyx_L10;
    }

    /* "ddb/lexer/lexer.py":147
 *                 argument =variable_data
 *             #default catch
 *             elif variable_type=='string':             # <<<<<<<<<<<<<<
 *                 argument =variable_data
 * 
 */
    __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_variable_type, __pyx_n_s_string, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 147, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":148
 *             #default catch
 *             elif variable_type=='string':
 *                 argument =variable_data             # <<<<<<<<<<<<<<
 * 
 *             return {'key':variable,'value':argument}
 */
      __Pyx_INCREF(__pyx_v_variable_data);
      __Pyx_DECREF_SET(__pyx_v_argument, __pyx_v_variable_data);

      /* "ddb/lexer/lexer.py":147
 *                 argument =variable_data
 *             #default catch
 *             elif variable_type=='string':             # <<<<<<<<<<<<<<
 *                 argument =variable_data
 * 
 */
    }
    __pyx_L10:;

    /* "ddb/lexer/lexer.py":150
 *                 argument =variable_data
 * 
 *             return {'key':variable,'value':argument}             # <<<<<<<<<<<<<<
 *         elif definition=='internal':
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 150, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_key, __pyx_v_variable) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_v_argument) < 0) __PYX_ERR(0, 150, __pyx_L1_error)
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "ddb/lexer/lexer.py":118
 *         # HERE ADD add string length enforcment for colon +1 -1 same for brackets
 * 
 *         if definition=='single':             # <<<<<<<<<<<<<<
 *             variable=word[1:-1]
 *             variable_type='string'
 */
  }

  /* "ddb/lexer/lexer.py":151
 * 
 *             return {'key':variable,'value':argument}
 *         elif definition=='internal':             # <<<<<<<<<<<<<<
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 *             variable=word[1:]
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_definition, __pyx_n_s_internal, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 151, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "ddb/lexer/lexer.py":153
 *         elif definition=='internal':
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 *             variable=word[1:]             # <<<<<<<<<<<<<<
 *             index_of_colon=variable.find(':')
 *             if index_of_colon!=-1:
 */
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_word, 1, 0, NULL, NULL, &__pyx_slice__17, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_variable = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":154
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 *             variable=word[1:]
 *             index_of_colon=variable.find(':')             # <<<<<<<<<<<<<<
 *             if index_of_colon!=-1:
 *                 #variable=word[0:index_of_colon-1]
 */
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_variable, __pyx_n_s_find); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_8, __pyx_t_2, __pyx_kp_s__18) : __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_kp_s__18);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 154, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_v_index_of_colon = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":155
 *             variable=word[1:]
 *             index_of_colon=variable.find(':')
 *             if index_of_colon!=-1:             # <<<<<<<<<<<<<<
 *                 #variable=word[0:index_of_colon-1]
 *                 key=variable[index_of_colon+1:].lower()
 */
    __pyx_t_1 = __Pyx_PyInt_NeObjC(__pyx_v_index_of_colon, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 155, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":157
 *             if index_of_colon!=-1:
 *                 #variable=word[0:index_of_colon-1]
 *                 key=variable[index_of_colon+1:].lower()             # <<<<<<<<<<<<<<
 *             else:
 *                 key=variable.lower()
 */
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_index_of_colon, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_variable, 0, 0, &__pyx_t_8, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_lower); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 157, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_key = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "ddb/lexer/lexer.py":155
 *             variable=word[1:]
 *             index_of_colon=variable.find(':')
 *             if index_of_colon!=-1:             # <<<<<<<<<<<<<<
 *                 #variable=word[0:index_of_colon-1]
 *                 key=variable[index_of_colon+1:].lower()
 */
      goto __pyx_L21;
    }

    /* "ddb/lexer/lexer.py":159
 *                 key=variable[index_of_colon+1:].lower()
 *             else:
 *                 key=variable.lower()             # <<<<<<<<<<<<<<
 *             return {'key':key,'value':variable_data}
 * 
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_variable, __pyx_n_s_lower); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_8, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 159, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_key = __pyx_t_1;
      __pyx_t_1 = 0;
    }
    __pyx_L21:;

    /* "ddb/lexer/lexer.py":160
 *             else:
 *                 key=variable.lower()
 *             return {'key':key,'value':variable_data}             # <<<<<<<<<<<<<<
 * 
 *         else:
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_key, __pyx_v_key) < 0) __PYX_ERR(0, 160, __pyx_L1_error)
    if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_v_variable_data) < 0) __PYX_ERR(0, 160, __pyx_L1_error)
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "ddb/lexer/lexer.py":151
 * 
 *             return {'key':variable,'value':argument}
 *         elif definition=='internal':             # <<<<<<<<<<<<<<
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 *             variable=word[1:]
 */
  }

  /* "ddb/lexer/lexer.py":164
 *         else:
 *            # normal keyword
 *            if self.keep_non_keywords:             # <<<<<<<<<<<<<<
 *                return {'key':word,'value':variable_data}
 * 
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_keep_non_keywords); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 164, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 164, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":165
 *            # normal keyword
 *            if self.keep_non_keywords:
 *                return {'key':word,'value':variable_data}             # <<<<<<<<<<<<<<
 * 
 *         raise Exception ("Not found argument")
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 165, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_key, __pyx_v_word) < 0) __PYX_ERR(0, 165, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_value, __pyx_v_variable_data) < 0) __PYX_ERR(0, 165, __pyx_L1_error)
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":164
 *         else:
 *            # normal keyword
 *            if self.keep_non_keywords:             # <<<<<<<<<<<<<<
 *                return {'key':word,'value':variable_data}
 * 
 */
    }
  }

  /* "ddb/lexer/lexer.py":167
 *                return {'key':word,'value':variable_data}
 * 
 *         raise Exception ("Not found argument")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])), __pyx_tuple__19, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(0, 167, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":102
 *             raise Exception("Invalid Syntax")
 * 
 *     def get_argument(self,word,segment,tokens,token_index,w_index):             # <<<<<<<<<<<<<<
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_argument", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_variable_data);
  __Pyx_XDECREF(__pyx_v_first_char);
  __Pyx_XDECREF(__pyx_v_last_char);
  __Pyx_XDECREF(__pyx_v_definition);
  __Pyx_XDECREF(__pyx_v_variable);
  __Pyx_XDECREF(__pyx_v_variable_type);
  __Pyx_XDECREF(__pyx_v_argument);
  __Pyx_XDECREF(__pyx_v_err_msg);
  __Pyx_XDECREF(__pyx_v_index_of_colon);
  __Pyx_XDECREF(__pyx_v_key);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":170
 * 
 * 
 *     def parse(self, tokens):             # <<<<<<<<<<<<<<
 *         # SOME TODO!
 *         # loop through commands, return the first matching result
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_7parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_7parse = {"parse", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_7parse, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_7parse(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_tokens,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("parse", 1, 2, 2, 1); __PYX_ERR(0, 170, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "parse") < 0)) __PYX_ERR(0, 170, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_tokens = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 170, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_6parse(__pyx_self, __pyx_v_self, __pyx_v_tokens);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_6parse(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_tokens) {
  PyObject *__pyx_v_highest_match = NULL;
  PyObject *__pyx_v_recent_match = NULL;
  PyObject *__pyx_v_command = NULL;
  PyObject *__pyx_v_res = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  __Pyx_RefNannySetupContext("parse", 0);

  /* "ddb/lexer/lexer.py":174
 *         # loop through commands, return the first matching result
 *         # return the exact match, OR the match with the highest score
 *         highest_match=-1             # <<<<<<<<<<<<<<
 *         recent_match=None
 *         for command in language['commands']:
 */
  __Pyx_INCREF(__pyx_int_neg_1);
  __pyx_v_highest_match = __pyx_int_neg_1;

  /* "ddb/lexer/lexer.py":175
 *         # return the exact match, OR the match with the highest score
 *         highest_match=-1
 *         recent_match=None             # <<<<<<<<<<<<<<
 *         for command in language['commands']:
 *             res=self.test_syntax(command,tokens)
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_recent_match = Py_None;

  /* "ddb/lexer/lexer.py":176
 *         highest_match=-1
 *         recent_match=None
 *         for command in language['commands']:             # <<<<<<<<<<<<<<
 *             res=self.test_syntax(command,tokens)
 *             if res['success']:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_commands); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 176, __pyx_L1_error)
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_3 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 176, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_3 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_3); __Pyx_INCREF(__pyx_t_2); __pyx_t_3++; if (unlikely(0 < 0)) __PYX_ERR(0, 176, __pyx_L1_error)
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 176, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_4(__pyx_t_1);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 176, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_command, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":177
 *         recent_match=None
 *         for command in language['commands']:
 *             res=self.test_syntax(command,tokens)             # <<<<<<<<<<<<<<
 *             if res['success']:
 *                 #print (res)
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_test_syntax); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_command, __pyx_v_tokens};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_5)) {
      PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_command, __pyx_v_tokens};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_5, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_GOTREF(__pyx_t_2);
    } else
    #endif
    {
      __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      if (__pyx_t_6) {
        __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
      }
      __Pyx_INCREF(__pyx_v_command);
      __Pyx_GIVEREF(__pyx_v_command);
      PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_command);
      __Pyx_INCREF(__pyx_v_tokens);
      __Pyx_GIVEREF(__pyx_v_tokens);
      PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_tokens);
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 177, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF_SET(__pyx_v_res, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":178
 *         for command in language['commands']:
 *             res=self.test_syntax(command,tokens)
 *             if res['success']:             # <<<<<<<<<<<<<<
 *                 #print (res)
 *                 return res
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_success); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 178, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_9) {

      /* "ddb/lexer/lexer.py":180
 *             if res['success']:
 *                 #print (res)
 *                 return res             # <<<<<<<<<<<<<<
 *             else:
 *                 if res['match']>highest_match:
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_res);
      __pyx_r = __pyx_v_res;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":178
 *         for command in language['commands']:
 *             res=self.test_syntax(command,tokens)
 *             if res['success']:             # <<<<<<<<<<<<<<
 *                 #print (res)
 *                 return res
 */
    }

    /* "ddb/lexer/lexer.py":182
 *                 return res
 *             else:
 *                 if res['match']>highest_match:             # <<<<<<<<<<<<<<
 *                     highest_match=res['match']
 *                     recent_match=res
 */
    /*else*/ {
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_match); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, __pyx_v_highest_match, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 182, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_9) {

        /* "ddb/lexer/lexer.py":183
 *             else:
 *                 if res['match']>highest_match:
 *                     highest_match=res['match']             # <<<<<<<<<<<<<<
 *                     recent_match=res
 * 
 */
        __pyx_t_5 = __Pyx_PyObject_Dict_GetItem(__pyx_v_res, __pyx_n_s_match); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 183, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF_SET(__pyx_v_highest_match, __pyx_t_5);
        __pyx_t_5 = 0;

        /* "ddb/lexer/lexer.py":184
 *                 if res['match']>highest_match:
 *                     highest_match=res['match']
 *                     recent_match=res             # <<<<<<<<<<<<<<
 * 
 *         return recent_match
 */
        __Pyx_INCREF(__pyx_v_res);
        __Pyx_DECREF_SET(__pyx_v_recent_match, __pyx_v_res);

        /* "ddb/lexer/lexer.py":182
 *                 return res
 *             else:
 *                 if res['match']>highest_match:             # <<<<<<<<<<<<<<
 *                     highest_match=res['match']
 *                     recent_match=res
 */
      }
    }

    /* "ddb/lexer/lexer.py":176
 *         highest_match=-1
 *         recent_match=None
 *         for command in language['commands']:             # <<<<<<<<<<<<<<
 *             res=self.test_syntax(command,tokens)
 *             if res['success']:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":186
 *                     recent_match=res
 * 
 *         return recent_match             # <<<<<<<<<<<<<<
 *     # place holder for the status of a command fragment
 *     class flags:
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_recent_match);
  __pyx_r = __pyx_v_recent_match;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":170
 * 
 * 
 *     def parse(self, tokens):             # <<<<<<<<<<<<<<
 *         # SOME TODO!
 *         # loop through commands, return the first matching result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.parse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_highest_match);
  __Pyx_XDECREF(__pyx_v_recent_match);
  __Pyx_XDECREF(__pyx_v_command);
  __Pyx_XDECREF(__pyx_v_res);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":192
 * 
 * 
 *         def __init__(self,command_fragment):             # <<<<<<<<<<<<<<
 *             if 'dispose' in command_fragment:
 *                 self.dispose = command_fragment['dispose']
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5flags_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5flags_1__init__ = {"__init__", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5flags_1__init__, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5flags_1__init__(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_command_fragment = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_command_fragment,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_command_fragment)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); __PYX_ERR(0, 192, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 192, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_self = values[0];
    __pyx_v_command_fragment = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 192, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.flags.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5flags___init__(__pyx_self, __pyx_v_self, __pyx_v_command_fragment);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5flags___init__(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_command_fragment) {
  PyObject *__pyx_v_x = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "ddb/lexer/lexer.py":193
 * 
 *         def __init__(self,command_fragment):
 *             if 'dispose' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.dispose = command_fragment['dispose']
 *             else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_dispose, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 193, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":194
 *         def __init__(self,command_fragment):
 *             if 'dispose' in command_fragment:
 *                 self.dispose = command_fragment['dispose']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.dispose = False
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_dispose); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_dispose, __pyx_t_3) < 0) __PYX_ERR(0, 194, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":193
 * 
 *         def __init__(self,command_fragment):
 *             if 'dispose' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.dispose = command_fragment['dispose']
 *             else:
 */
    goto __pyx_L3;
  }

  /* "ddb/lexer/lexer.py":196
 *                 self.dispose = command_fragment['dispose']
 *             else:
 *                 self.dispose = False             # <<<<<<<<<<<<<<
 *             if 'no_keyword' in command_fragment:
 *                 self.no_keyword = command_fragment['no_keyword']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_dispose, Py_False) < 0) __PYX_ERR(0, 196, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "ddb/lexer/lexer.py":197
 *             else:
 *                 self.dispose = False
 *             if 'no_keyword' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.no_keyword = command_fragment['no_keyword']
 *             else:
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_no_keyword, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 197, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":198
 *                 self.dispose = False
 *             if 'no_keyword' in command_fragment:
 *                 self.no_keyword = command_fragment['no_keyword']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.no_keyword = False
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_no_keyword); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_no_keyword, __pyx_t_3) < 0) __PYX_ERR(0, 198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":197
 *             else:
 *                 self.dispose = False
 *             if 'no_keyword' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.no_keyword = command_fragment['no_keyword']
 *             else:
 */
    goto __pyx_L4;
  }

  /* "ddb/lexer/lexer.py":200
 *                 self.no_keyword = command_fragment['no_keyword']
 *             else:
 *                 self.no_keyword = False             # <<<<<<<<<<<<<<
 *             if 'store_array' in command_fragment:
 *                 self.store_array = command_fragment['store_array']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_no_keyword, Py_False) < 0) __PYX_ERR(0, 200, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "ddb/lexer/lexer.py":201
 *             else:
 *                 self.no_keyword = False
 *             if 'store_array' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.store_array = command_fragment['store_array']
 *             else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_store_array, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 201, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":202
 *                 self.no_keyword = False
 *             if 'store_array' in command_fragment:
 *                 self.store_array = command_fragment['store_array']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.store_array = False
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_store_array); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_store_array, __pyx_t_3) < 0) __PYX_ERR(0, 202, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":201
 *             else:
 *                 self.no_keyword = False
 *             if 'store_array' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.store_array = command_fragment['store_array']
 *             else:
 */
    goto __pyx_L5;
  }

  /* "ddb/lexer/lexer.py":204
 *                 self.store_array = command_fragment['store_array']
 *             else:
 *                 self.store_array = False             # <<<<<<<<<<<<<<
 *             if 'key' in command_fragment:
 *                 self.arg_key=command_fragment['key']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_store_array, Py_False) < 0) __PYX_ERR(0, 204, __pyx_L1_error)
  }
  __pyx_L5:;

  /* "ddb/lexer/lexer.py":205
 *             else:
 *                 self.store_array = False
 *             if 'key' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.arg_key=command_fragment['key']
 *             else:
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_key, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 205, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":206
 *                 self.store_array = False
 *             if 'key' in command_fragment:
 *                 self.arg_key=command_fragment['key']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.arg_key=None
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_arg_key, __pyx_t_3) < 0) __PYX_ERR(0, 206, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":205
 *             else:
 *                 self.store_array = False
 *             if 'key' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.arg_key=command_fragment['key']
 *             else:
 */
    goto __pyx_L6;
  }

  /* "ddb/lexer/lexer.py":208
 *                 self.arg_key=command_fragment['key']
 *             else:
 *                 self.arg_key=None             # <<<<<<<<<<<<<<
 *             if 'parent' in command_fragment:
 *                 self.parent = command_fragment['parent']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_arg_key, Py_None) < 0) __PYX_ERR(0, 208, __pyx_L1_error)
  }
  __pyx_L6:;

  /* "ddb/lexer/lexer.py":209
 *             else:
 *                 self.arg_key=None
 *             if 'parent' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.parent = command_fragment['parent']
 *             else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_parent, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 209, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":210
 *                 self.arg_key=None
 *             if 'parent' in command_fragment:
 *                 self.parent = command_fragment['parent']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.parent = None
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_parent); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parent, __pyx_t_3) < 0) __PYX_ERR(0, 210, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":209
 *             else:
 *                 self.arg_key=None
 *             if 'parent' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.parent = command_fragment['parent']
 *             else:
 */
    goto __pyx_L7;
  }

  /* "ddb/lexer/lexer.py":212
 *                 self.parent = command_fragment['parent']
 *             else:
 *                 self.parent = None             # <<<<<<<<<<<<<<
 *             if 'type' in command_fragment:
 *                 self.meta_type = command_fragment['type']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_parent, Py_None) < 0) __PYX_ERR(0, 212, __pyx_L1_error)
  }
  __pyx_L7:;

  /* "ddb/lexer/lexer.py":213
 *             else:
 *                 self.parent = None
 *             if 'type' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.meta_type = command_fragment['type']
 *             else:
 */
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_type, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 213, __pyx_L1_error)
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":214
 *                 self.parent = None
 *             if 'type' in command_fragment:
 *                 self.meta_type = command_fragment['type']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.meta_type = None
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_type); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_meta_type, __pyx_t_3) < 0) __PYX_ERR(0, 214, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":213
 *             else:
 *                 self.parent = None
 *             if 'type' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.meta_type = command_fragment['type']
 *             else:
 */
    goto __pyx_L8;
  }

  /* "ddb/lexer/lexer.py":216
 *                 self.meta_type = command_fragment['type']
 *             else:
 *                 self.meta_type = None             # <<<<<<<<<<<<<<
 *             if 'optional' in command_fragment:
 *                 self.optional = command_fragment['optional']
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_meta_type, Py_None) < 0) __PYX_ERR(0, 216, __pyx_L1_error)
  }
  __pyx_L8:;

  /* "ddb/lexer/lexer.py":217
 *             else:
 *                 self.meta_type = None
 *             if 'optional' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.optional = command_fragment['optional']
 *             else:
 */
  __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_optional, __pyx_v_command_fragment, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 217, __pyx_L1_error)
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":218
 *                 self.meta_type = None
 *             if 'optional' in command_fragment:
 *                 self.optional = command_fragment['optional']             # <<<<<<<<<<<<<<
 *             else:
 *                 self.optional = False
 */
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_optional, __pyx_t_3) < 0) __PYX_ERR(0, 218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":217
 *             else:
 *                 self.meta_type = None
 *             if 'optional' in command_fragment:             # <<<<<<<<<<<<<<
 *                 self.optional = command_fragment['optional']
 *             else:
 */
    goto __pyx_L9;
  }

  /* "ddb/lexer/lexer.py":220
 *                 self.optional = command_fragment['optional']
 *             else:
 *                 self.optional = False             # <<<<<<<<<<<<<<
 *             if isinstance(command_fragment['name'], list):
 *                 self.object_id = ' '.join([str(x) for x in command_fragment['name']])
 */
  /*else*/ {
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_optional, Py_False) < 0) __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_L9:;

  /* "ddb/lexer/lexer.py":221
 *             else:
 *                 self.optional = False
 *             if isinstance(command_fragment['name'], list):             # <<<<<<<<<<<<<<
 *                 self.object_id = ' '.join([str(x) for x in command_fragment['name']])
 *                 self.object_id = self.object_id.lower()
 */
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyList_Check(__pyx_t_3); 
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":222
 *                 self.optional = False
 *             if isinstance(command_fragment['name'], list):
 *                 self.object_id = ' '.join([str(x) for x in command_fragment['name']])             # <<<<<<<<<<<<<<
 *                 self.object_id = self.object_id.lower()
 *             else:
 */
    __pyx_t_3 = PyList_New(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_5 = __pyx_t_4; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
      __pyx_t_7 = NULL;
    } else {
      __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 222, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_7)) {
        if (likely(PyList_CheckExact(__pyx_t_5))) {
          if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 222, __pyx_L1_error)
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_7(__pyx_t_5);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 222, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_x, __pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_CallOneArg(((PyObject *)(&PyString_Type)), __pyx_v_x); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_3, (PyObject*)__pyx_t_4))) __PYX_ERR(0, 222, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyString_Join(__pyx_kp_s__20, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_object_id, __pyx_t_5) < 0) __PYX_ERR(0, 222, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ddb/lexer/lexer.py":223
 *             if isinstance(command_fragment['name'], list):
 *                 self.object_id = ' '.join([str(x) for x in command_fragment['name']])
 *                 self.object_id = self.object_id.lower()             # <<<<<<<<<<<<<<
 *             else:
 *                 self.object_id = command_fragment['name'].lower()
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_object_id); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_lower); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_5 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_object_id, __pyx_t_5) < 0) __PYX_ERR(0, 223, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ddb/lexer/lexer.py":221
 *             else:
 *                 self.optional = False
 *             if isinstance(command_fragment['name'], list):             # <<<<<<<<<<<<<<
 *                 self.object_id = ' '.join([str(x) for x in command_fragment['name']])
 *                 self.object_id = self.object_id.lower()
 */
    goto __pyx_L10;
  }

  /* "ddb/lexer/lexer.py":225
 *                 self.object_id = self.object_id.lower()
 *             else:
 *                 self.object_id = command_fragment['name'].lower()             # <<<<<<<<<<<<<<
 *             #logic
 *             # key override for segment
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command_fragment, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_lower); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_5 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_object_id, __pyx_t_5) < 0) __PYX_ERR(0, 225, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_L10:;

  /* "ddb/lexer/lexer.py":228
 *             #logic
 *             # key override for segment
 *             if self.arg_key:             # <<<<<<<<<<<<<<
 *                 self.object_id=self.arg_key
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_arg_key); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":229
 *             # key override for segment
 *             if self.arg_key:
 *                 self.object_id=self.arg_key             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_arg_key); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (__Pyx_PyObject_SetAttrStr(__pyx_v_self, __pyx_n_s_object_id, __pyx_t_5) < 0) __PYX_ERR(0, 229, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "ddb/lexer/lexer.py":228
 *             #logic
 *             # key override for segment
 *             if self.arg_key:             # <<<<<<<<<<<<<<
 *                 self.object_id=self.arg_key
 * 
 */
  }

  /* "ddb/lexer/lexer.py":192
 * 
 * 
 *         def __init__(self,command_fragment):             # <<<<<<<<<<<<<<
 *             if 'dispose' in command_fragment:
 *                 self.dispose = command_fragment['dispose']
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("ddb.lexer.lexer.flags.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":232
 * 
 * 
 *     def test_syntax(self,command,tokens):             # <<<<<<<<<<<<<<
 *         query_object = {}
 *         token_index = 0
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_9test_syntax(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_9test_syntax = {"test_syntax", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_9test_syntax, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_9test_syntax(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_command = 0;
  PyObject *__pyx_v_tokens = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("test_syntax (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_command,&__pyx_n_s_tokens,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_command)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("test_syntax", 1, 3, 3, 1); __PYX_ERR(0, 232, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("test_syntax", 1, 3, 3, 2); __PYX_ERR(0, 232, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "test_syntax") < 0)) __PYX_ERR(0, 232, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_command = values[1];
    __pyx_v_tokens = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("test_syntax", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 232, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.test_syntax", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_8test_syntax(__pyx_self, __pyx_v_self, __pyx_v_command, __pyx_v_tokens);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_8test_syntax(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_command, PyObject *__pyx_v_tokens) {
  PyObject *__pyx_v_query_object = NULL;
  PyObject *__pyx_v_token_index = NULL;
  PyObject *__pyx_v_segment_index = NULL;
  PyObject *__pyx_v_query_mode = NULL;
  PyObject *__pyx_v_curent_object = NULL;
  PyObject *__pyx_v_segment = NULL;
  PyObject *__pyx_v_token_list = NULL;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_v_base_argument = NULL;
  int __pyx_v_in_argument;
  PyObject *__pyx_v_argument_index = NULL;
  PyObject *__pyx_v_flags = NULL;
  PyObject *__pyx_v_depends_on = NULL;
  PyObject *__pyx_v_dependency_found = NULL;
  PyObject *__pyx_v_arguments = NULL;
  Py_ssize_t __pyx_v_match_len;
  PyObject *__pyx_v_match = NULL;
  PyObject *__pyx_v_partial = NULL;
  PyObject *__pyx_v_signature_compare = NULL;
  PyObject *__pyx_v_haystack = NULL;
  PyObject *__pyx_v_signature = NULL;
  PyObject *__pyx_v_var_name = NULL;
  PyObject *__pyx_v_argument = NULL;
  Py_ssize_t __pyx_v_w_index;
  PyObject *__pyx_v_word = NULL;
  PyObject *__pyx_v_computed = NULL;
  PyObject *__pyx_v_jump = NULL;
  PyObject *__pyx_v_tsi = NULL;
  PyObject *__pyx_v_ts = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_query_err = NULL;
  Py_ssize_t __pyx_v_index;
  PyObject *__pyx_v_err_msg = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *(*__pyx_t_16)(PyObject *);
  PyObject *__pyx_t_17 = NULL;
  PyObject *__pyx_t_18 = NULL;
  PyObject *__pyx_t_19 = NULL;
  __Pyx_RefNannySetupContext("test_syntax", 0);

  /* "ddb/lexer/lexer.py":233
 * 
 *     def test_syntax(self,command,tokens):
 *         query_object = {}             # <<<<<<<<<<<<<<
 *         token_index = 0
 *         self.info("-----", command['name'])
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_query_object = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":234
 *     def test_syntax(self,command,tokens):
 *         query_object = {}
 *         token_index = 0             # <<<<<<<<<<<<<<
 *         self.info("-----", command['name'])
 *         segment_index = 0
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_token_index = __pyx_int_0;

  /* "ddb/lexer/lexer.py":235
 *         query_object = {}
 *         token_index = 0
 *         self.info("-----", command['name'])             # <<<<<<<<<<<<<<
 *         segment_index = 0
 *         query_mode = None
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_s__21, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
    PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_s__21, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  } else
  #endif
  {
    __pyx_t_6 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (__pyx_t_4) {
      __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4); __pyx_t_4 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_s__21);
    __Pyx_GIVEREF(__pyx_kp_s__21);
    PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_5, __pyx_kp_s__21);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_5, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_6, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":236
 *         token_index = 0
 *         self.info("-----", command['name'])
 *         segment_index = 0             # <<<<<<<<<<<<<<
 *         query_mode = None
 *         curent_object = {}
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_segment_index = __pyx_int_0;

  /* "ddb/lexer/lexer.py":237
 *         self.info("-----", command['name'])
 *         segment_index = 0
 *         query_mode = None             # <<<<<<<<<<<<<<
 *         curent_object = {}
 *         segment = {}
 */
  __Pyx_INCREF(Py_None);
  __pyx_v_query_mode = Py_None;

  /* "ddb/lexer/lexer.py":238
 *         segment_index = 0
 *         query_mode = None
 *         curent_object = {}             # <<<<<<<<<<<<<<
 *         segment = {}
 *         token_list=[]
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_curent_object = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":239
 *         query_mode = None
 *         curent_object = {}
 *         segment = {}             # <<<<<<<<<<<<<<
 *         token_list=[]
 *         for i in range(0,len(tokens)):
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_segment = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":240
 *         curent_object = {}
 *         segment = {}
 *         token_list=[]             # <<<<<<<<<<<<<<
 *         for i in range(0,len(tokens)):
 *             token_list.append("{0}-{1}".format(i,tokens[i]['data']))
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_token_list = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":241
 *         segment = {}
 *         token_list=[]
 *         for i in range(0,len(tokens)):             # <<<<<<<<<<<<<<
 *             token_list.append("{0}-{1}".format(i,tokens[i]['data']))
 *         self.info(",".join(token_list))
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 241, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "ddb/lexer/lexer.py":242
 *         token_list=[]
 *         for i in range(0,len(tokens)):
 *             token_list.append("{0}-{1}".format(i,tokens[i]['data']))             # <<<<<<<<<<<<<<
 *         self.info(",".join(token_list))
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_1, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_i); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_GetItemInt(__pyx_v_tokens, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_6, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
      PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_t_6, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    } else
    #endif
    {
      __pyx_t_10 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (__pyx_t_3) {
        __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_3); __pyx_t_3 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_5, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_5, __pyx_t_4);
      __pyx_t_6 = 0;
      __pyx_t_4 = 0;
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_token_list, __pyx_t_1); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 242, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }

  /* "ddb/lexer/lexer.py":243
 *         for i in range(0,len(tokens)):
 *             token_list.append("{0}-{1}".format(i,tokens[i]['data']))
 *         self.info(",".join(token_list))             # <<<<<<<<<<<<<<
 * 
 *         while segment_index < len(command['segments']) and token_index < len(tokens):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = __Pyx_PyString_Join(__pyx_kp_s__22, __pyx_v_token_list); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_10);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":245
 *         self.info(",".join(token_list))
 * 
 *         while segment_index < len(command['segments']) and token_index < len(tokens):             # <<<<<<<<<<<<<<
 *             # set the state
 *             segment = command['segments'][segment_index]
 */
  while (1) {
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_RichCompare(__pyx_v_segment_index, __pyx_t_1, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (__pyx_t_13) {
    } else {
      __pyx_t_12 = __pyx_t_13;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 245, __pyx_L1_error)
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyObject_RichCompare(__pyx_v_token_index, __pyx_t_2, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 245, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = __pyx_t_13;
    __pyx_L7_bool_binop_done:;
    if (!__pyx_t_12) break;

    /* "ddb/lexer/lexer.py":247
 *         while segment_index < len(command['segments']) and token_index < len(tokens):
 *             # set the state
 *             segment = command['segments'][segment_index]             # <<<<<<<<<<<<<<
 *             self.info("############# TESTING : {0}.{1}".format(command['name'],segment['name']))
 *             segment_index += 1
 */
    __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_segment_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_segment, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":248
 *             # set the state
 *             segment = command['segments'][segment_index]
 *             self.info("############# TESTING : {0}.{1}".format(command['name'],segment['name']))             # <<<<<<<<<<<<<<
 *             segment_index += 1
 *             curent_object = {}
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_TESTING_0_1, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_name); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_14 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_14)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_t_6, __pyx_t_3};
      __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
      PyObject *__pyx_temp[3] = {__pyx_t_14, __pyx_t_6, __pyx_t_3};
      __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    } else
    #endif
    {
      __pyx_t_15 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      if (__pyx_t_14) {
        __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_14); __pyx_t_14 = NULL;
      }
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_5, __pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_5, __pyx_t_3);
      __pyx_t_6 = 0;
      __pyx_t_3 = 0;
      __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_15, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 248, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_10);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 248, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":249
 *             segment = command['segments'][segment_index]
 *             self.info("############# TESTING : {0}.{1}".format(command['name'],segment['name']))
 *             segment_index += 1             # <<<<<<<<<<<<<<
 *             curent_object = {}
 *             base_argument={}
 */
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_segment_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_segment_index, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":250
 *             self.info("############# TESTING : {0}.{1}".format(command['name'],segment['name']))
 *             segment_index += 1
 *             curent_object = {}             # <<<<<<<<<<<<<<
 *             base_argument={}
 *             in_argument = True
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_curent_object, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":251
 *             segment_index += 1
 *             curent_object = {}
 *             base_argument={}             # <<<<<<<<<<<<<<
 *             in_argument = True
 *             argument_index = 0
 */
    __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 251, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_base_argument, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":252
 *             curent_object = {}
 *             base_argument={}
 *             in_argument = True             # <<<<<<<<<<<<<<
 *             argument_index = 0
 * 
 */
    __pyx_v_in_argument = 1;

    /* "ddb/lexer/lexer.py":253
 *             base_argument={}
 *             in_argument = True
 *             argument_index = 0             # <<<<<<<<<<<<<<
 * 
 *             flags=lexer.flags(segment)
 */
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_XDECREF_SET(__pyx_v_argument_index, __pyx_int_0);

    /* "ddb/lexer/lexer.py":255
 *             argument_index = 0
 * 
 *             flags=lexer.flags(segment)             # <<<<<<<<<<<<<<
 * 
 *             curent_object['mode'] = flags.object_id
 */
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_lexer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_flags); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_1, __pyx_v_segment) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_segment);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_XDECREF_SET(__pyx_v_flags, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":257
 *             flags=lexer.flags(segment)
 * 
 *             curent_object['mode'] = flags.object_id             # <<<<<<<<<<<<<<
 *             query_mode = command['name']
 *             self.info("Object Id:", flags.object_id, "Token Id:", token_index)
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_object_id); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (unlikely(PyDict_SetItem(__pyx_v_curent_object, __pyx_n_s_mode, __pyx_t_2) < 0)) __PYX_ERR(0, 257, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":258
 * 
 *             curent_object['mode'] = flags.object_id
 *             query_mode = command['name']             # <<<<<<<<<<<<<<
 *             self.info("Object Id:", flags.object_id, "Token Id:", token_index)
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 258, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_query_mode, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":259
 *             curent_object['mode'] = flags.object_id
 *             query_mode = command['name']
 *             self.info("Object Id:", flags.object_id, "Token Id:", token_index)             # <<<<<<<<<<<<<<
 * 
 *             while True == in_argument:
 */
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_object_id); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 259, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_10);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_10, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_kp_s_Object_Id, __pyx_t_1, __pyx_kp_s_Token_Id, __pyx_v_token_index};
      __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
      PyObject *__pyx_temp[5] = {__pyx_t_4, __pyx_kp_s_Object_Id, __pyx_t_1, __pyx_kp_s_Token_Id, __pyx_v_token_index};
      __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 4+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    } else
    #endif
    {
      __pyx_t_15 = PyTuple_New(4+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_15);
      if (__pyx_t_4) {
        __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_4); __pyx_t_4 = NULL;
      }
      __Pyx_INCREF(__pyx_kp_s_Object_Id);
      __Pyx_GIVEREF(__pyx_kp_s_Object_Id);
      PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_5, __pyx_kp_s_Object_Id);
      __Pyx_GIVEREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_5, __pyx_t_1);
      __Pyx_INCREF(__pyx_kp_s_Token_Id);
      __Pyx_GIVEREF(__pyx_kp_s_Token_Id);
      PyTuple_SET_ITEM(__pyx_t_15, 2+__pyx_t_5, __pyx_kp_s_Token_Id);
      __Pyx_INCREF(__pyx_v_token_index);
      __Pyx_GIVEREF(__pyx_v_token_index);
      PyTuple_SET_ITEM(__pyx_t_15, 3+__pyx_t_5, __pyx_v_token_index);
      __pyx_t_1 = 0;
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 259, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":261
 *             self.info("Object Id:", flags.object_id, "Token Id:", token_index)
 * 
 *             while True == in_argument:             # <<<<<<<<<<<<<<
 *                 if 'depends_on' in segment:
 *                     depends_on = segment['depends_on']
 */
    while (1) {
      __pyx_t_12 = ((1 == __pyx_v_in_argument) != 0);
      if (!__pyx_t_12) break;

      /* "ddb/lexer/lexer.py":262
 * 
 *             while True == in_argument:
 *                 if 'depends_on' in segment:             # <<<<<<<<<<<<<<
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:
 */
      __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_depends_on, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 262, __pyx_L1_error)
      __pyx_t_13 = (__pyx_t_12 != 0);
      if (__pyx_t_13) {

        /* "ddb/lexer/lexer.py":263
 *             while True == in_argument:
 *                 if 'depends_on' in segment:
 *                     depends_on = segment['depends_on']             # <<<<<<<<<<<<<<
 *                     if len(depends_on)>0:
 *                         if depends_on[0]=='.':
 */
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_depends_on); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 263, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_depends_on, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":264
 *                 if 'depends_on' in segment:
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:             # <<<<<<<<<<<<<<
 *                         if depends_on[0]=='.':
 *                             depends_on=depends_on[1:]
 */
        __pyx_t_7 = PyObject_Length(__pyx_v_depends_on); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 264, __pyx_L1_error)
        __pyx_t_13 = ((__pyx_t_7 > 0) != 0);
        if (__pyx_t_13) {

          /* "ddb/lexer/lexer.py":265
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:
 *                         if depends_on[0]=='.':             # <<<<<<<<<<<<<<
 *                             depends_on=depends_on[1:]
 * 
 */
          __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_depends_on, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 265, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s__23, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 265, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_13) {

            /* "ddb/lexer/lexer.py":266
 *                     if len(depends_on)>0:
 *                         if depends_on[0]=='.':
 *                             depends_on=depends_on[1:]             # <<<<<<<<<<<<<<
 * 
 *                     self.info("Depends on key: '{0}'".format(depends_on))
 */
            __pyx_t_2 = __Pyx_PyObject_GetSlice(__pyx_v_depends_on, 1, 0, NULL, NULL, &__pyx_slice__17, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 266, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF_SET(__pyx_v_depends_on, __pyx_t_2);
            __pyx_t_2 = 0;

            /* "ddb/lexer/lexer.py":265
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:
 *                         if depends_on[0]=='.':             # <<<<<<<<<<<<<<
 *                             depends_on=depends_on[1:]
 * 
 */
          }

          /* "ddb/lexer/lexer.py":264
 *                 if 'depends_on' in segment:
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:             # <<<<<<<<<<<<<<
 *                         if depends_on[0]=='.':
 *                             depends_on=depends_on[1:]
 */
        }

        /* "ddb/lexer/lexer.py":268
 *                             depends_on=depends_on[1:]
 * 
 *                     self.info("Depends on key: '{0}'".format(depends_on))             # <<<<<<<<<<<<<<
 *                 else:
 *                     depends_on = None
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 268, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Depends_on_key_0, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_1, function);
          }
        }
        __pyx_t_15 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_v_depends_on) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_depends_on);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 268, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_1 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_1)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
          }
        }
        __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_1, __pyx_t_15) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_t_15);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 268, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":262
 * 
 *             while True == in_argument:
 *                 if 'depends_on' in segment:             # <<<<<<<<<<<<<<
 *                     depends_on = segment['depends_on']
 *                     if len(depends_on)>0:
 */
        goto __pyx_L11;
      }

      /* "ddb/lexer/lexer.py":270
 *                     self.info("Depends on key: '{0}'".format(depends_on))
 *                 else:
 *                     depends_on = None             # <<<<<<<<<<<<<<
 * 
 *                 # if there is a dependency, enforce
 */
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __Pyx_XDECREF_SET(__pyx_v_depends_on, Py_None);
      }
      __pyx_L11:;

      /* "ddb/lexer/lexer.py":273
 * 
 *                 # if there is a dependency, enforce
 *                 if depends_on:             # <<<<<<<<<<<<<<
 *                     self.info ("QUERY OBJECT:", query_object)
 *                     dependency_found=None
 */
      __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_v_depends_on); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 273, __pyx_L1_error)
      if (__pyx_t_13) {

        /* "ddb/lexer/lexer.py":274
 *                 # if there is a dependency, enforce
 *                 if depends_on:
 *                     self.info ("QUERY OBJECT:", query_object)             # <<<<<<<<<<<<<<
 *                     dependency_found=None
 *                     if depends_on in query_object:
 */
        __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 274, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_15 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_10);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_10, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_kp_s_QUERY_OBJECT, __pyx_v_query_object};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_kp_s_QUERY_OBJECT, __pyx_v_query_object};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 274, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__pyx_t_15) {
            __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_15); __pyx_t_15 = NULL;
          }
          __Pyx_INCREF(__pyx_kp_s_QUERY_OBJECT);
          __Pyx_GIVEREF(__pyx_kp_s_QUERY_OBJECT);
          PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_5, __pyx_kp_s_QUERY_OBJECT);
          __Pyx_INCREF(__pyx_v_query_object);
          __Pyx_GIVEREF(__pyx_v_query_object);
          PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_5, __pyx_v_query_object);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 274, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":275
 *                 if depends_on:
 *                     self.info ("QUERY OBJECT:", query_object)
 *                     dependency_found=None             # <<<<<<<<<<<<<<
 *                     if depends_on in query_object:
 *                             dependency_found=True
 */
        __Pyx_INCREF(Py_None);
        __Pyx_XDECREF_SET(__pyx_v_dependency_found, Py_None);

        /* "ddb/lexer/lexer.py":276
 *                     self.info ("QUERY OBJECT:", query_object)
 *                     dependency_found=None
 *                     if depends_on in query_object:             # <<<<<<<<<<<<<<
 *                             dependency_found=True
 * 
 */
        __pyx_t_13 = (__Pyx_PyDict_ContainsTF(__pyx_v_depends_on, __pyx_v_query_object, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 276, __pyx_L1_error)
        __pyx_t_12 = (__pyx_t_13 != 0);
        if (__pyx_t_12) {

          /* "ddb/lexer/lexer.py":277
 *                     dependency_found=None
 *                     if depends_on in query_object:
 *                             dependency_found=True             # <<<<<<<<<<<<<<
 * 
 *                     if dependency_found:
 */
          __Pyx_INCREF(Py_True);
          __Pyx_DECREF_SET(__pyx_v_dependency_found, Py_True);

          /* "ddb/lexer/lexer.py":276
 *                     self.info ("QUERY OBJECT:", query_object)
 *                     dependency_found=None
 *                     if depends_on in query_object:             # <<<<<<<<<<<<<<
 *                             dependency_found=True
 * 
 */
        }

        /* "ddb/lexer/lexer.py":279
 *                             dependency_found=True
 * 
 *                     if dependency_found:             # <<<<<<<<<<<<<<
 *                         self.info("Dependency found", depends_on)
 *                     else:
 */
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_v_dependency_found); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 279, __pyx_L1_error)
        if (__pyx_t_12) {

          /* "ddb/lexer/lexer.py":280
 * 
 *                     if dependency_found:
 *                         self.info("Dependency found", depends_on)             # <<<<<<<<<<<<<<
 *                     else:
 *                         self.info("Missing", depends_on)
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 280, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_1 = NULL;
          __pyx_t_5 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_1)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_1);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_5 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Dependency_found, __pyx_v_depends_on};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Dependency_found, __pyx_v_depends_on};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          {
            __pyx_t_15 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_15);
            if (__pyx_t_1) {
              __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1); __pyx_t_1 = NULL;
            }
            __Pyx_INCREF(__pyx_kp_s_Dependency_found);
            __Pyx_GIVEREF(__pyx_kp_s_Dependency_found);
            PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_5, __pyx_kp_s_Dependency_found);
            __Pyx_INCREF(__pyx_v_depends_on);
            __Pyx_GIVEREF(__pyx_v_depends_on);
            PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_5, __pyx_v_depends_on);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 280, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":279
 *                             dependency_found=True
 * 
 *                     if dependency_found:             # <<<<<<<<<<<<<<
 *                         self.info("Dependency found", depends_on)
 *                     else:
 */
          goto __pyx_L16;
        }

        /* "ddb/lexer/lexer.py":282
 *                         self.info("Dependency found", depends_on)
 *                     else:
 *                         self.info("Missing", depends_on)             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
        /*else*/ {
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 282, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_15 = NULL;
          __pyx_t_5 = 0;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_15)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_15);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
              __pyx_t_5 = 1;
            }
          }
          #if CYTHON_FAST_PYCALL
          if (PyFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_n_s_Missing, __pyx_v_depends_on};
            __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          #if CYTHON_FAST_PYCCALL
          if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
            PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_n_s_Missing, __pyx_v_depends_on};
            __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_GOTREF(__pyx_t_2);
          } else
          #endif
          {
            __pyx_t_1 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 282, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (__pyx_t_15) {
              __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_15); __pyx_t_15 = NULL;
            }
            __Pyx_INCREF(__pyx_n_s_Missing);
            __Pyx_GIVEREF(__pyx_n_s_Missing);
            PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_5, __pyx_n_s_Missing);
            __Pyx_INCREF(__pyx_v_depends_on);
            __Pyx_GIVEREF(__pyx_v_depends_on);
            PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_5, __pyx_v_depends_on);
            __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 282, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":283
 *                     else:
 *                         self.info("Missing", depends_on)
 *                         break             # <<<<<<<<<<<<<<
 * 
 *                 # self.info("data",segment['data'])
 */
          goto __pyx_L10_break;
        }
        __pyx_L16:;

        /* "ddb/lexer/lexer.py":273
 * 
 *                 # if there is a dependency, enforce
 *                 if depends_on:             # <<<<<<<<<<<<<<
 *                     self.info ("QUERY OBJECT:", query_object)
 *                     dependency_found=None
 */
      }

      /* "ddb/lexer/lexer.py":286
 * 
 *                 # self.info("data",segment['data'])
 *                 if 'arguments' in segment:             # <<<<<<<<<<<<<<
 *                     arguments = segment['arguments']
 *                 else:
 */
      __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_arguments, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 286, __pyx_L1_error)
      __pyx_t_13 = (__pyx_t_12 != 0);
      if (__pyx_t_13) {

        /* "ddb/lexer/lexer.py":287
 *                 # self.info("data",segment['data'])
 *                 if 'arguments' in segment:
 *                     arguments = segment['arguments']             # <<<<<<<<<<<<<<
 *                 else:
 *                     arguments = 1
 */
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 287, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_arguments, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":286
 * 
 *                 # self.info("data",segment['data'])
 *                 if 'arguments' in segment:             # <<<<<<<<<<<<<<
 *                     arguments = segment['arguments']
 *                 else:
 */
        goto __pyx_L17;
      }

      /* "ddb/lexer/lexer.py":289
 *                     arguments = segment['arguments']
 *                 else:
 *                     arguments = 1             # <<<<<<<<<<<<<<
 *                 if arguments == None:
 *                     arguments = 1
 */
      /*else*/ {
        __Pyx_INCREF(__pyx_int_1);
        __Pyx_XDECREF_SET(__pyx_v_arguments, __pyx_int_1);
      }
      __pyx_L17:;

      /* "ddb/lexer/lexer.py":290
 *                 else:
 *                     arguments = 1
 *                 if arguments == None:             # <<<<<<<<<<<<<<
 *                     arguments = 1
 *                 self.info("Number of arguments", arguments)
 */
      __pyx_t_2 = PyObject_RichCompare(__pyx_v_arguments, Py_None, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 290, __pyx_L1_error)
      __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 290, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (__pyx_t_13) {

        /* "ddb/lexer/lexer.py":291
 *                     arguments = 1
 *                 if arguments == None:
 *                     arguments = 1             # <<<<<<<<<<<<<<
 *                 self.info("Number of arguments", arguments)
 * 
 */
        __Pyx_INCREF(__pyx_int_1);
        __Pyx_DECREF_SET(__pyx_v_arguments, __pyx_int_1);

        /* "ddb/lexer/lexer.py":290
 *                 else:
 *                     arguments = 1
 *                 if arguments == None:             # <<<<<<<<<<<<<<
 *                     arguments = 1
 *                 self.info("Number of arguments", arguments)
 */
      }

      /* "ddb/lexer/lexer.py":292
 *                 if arguments == None:
 *                     arguments = 1
 *                 self.info("Number of arguments", arguments)             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 292, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_1 = NULL;
      __pyx_t_5 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_10);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_10, function);
          __pyx_t_5 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Number_of_arguments, __pyx_v_arguments};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_10)) {
        PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Number_of_arguments, __pyx_v_arguments};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_10, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_15 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 292, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        if (__pyx_t_1) {
          __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1); __pyx_t_1 = NULL;
        }
        __Pyx_INCREF(__pyx_kp_s_Number_of_arguments);
        __Pyx_GIVEREF(__pyx_kp_s_Number_of_arguments);
        PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_5, __pyx_kp_s_Number_of_arguments);
        __Pyx_INCREF(__pyx_v_arguments);
        __Pyx_GIVEREF(__pyx_v_arguments);
        PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_5, __pyx_v_arguments);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_15, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 292, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":295
 * 
 * 
 *                 match_len = 0             # <<<<<<<<<<<<<<
 *                 match = None
 *                 for partial in segment['data']:
 */
      __pyx_v_match_len = 0;

      /* "ddb/lexer/lexer.py":296
 * 
 *                 match_len = 0
 *                 match = None             # <<<<<<<<<<<<<<
 *                 for partial in segment['data']:
 *                     signature_compare = partial['signature']
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_match, Py_None);

      /* "ddb/lexer/lexer.py":297
 *                 match_len = 0
 *                 match = None
 *                 for partial in segment['data']:             # <<<<<<<<<<<<<<
 *                     signature_compare = partial['signature']
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')
 */
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
        __pyx_t_10 = __pyx_t_2; __Pyx_INCREF(__pyx_t_10); __pyx_t_7 = 0;
        __pyx_t_16 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_10 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 297, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_16 = Py_TYPE(__pyx_t_10)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 297, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      for (;;) {
        if (likely(!__pyx_t_16)) {
          if (likely(PyList_CheckExact(__pyx_t_10))) {
            if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_10)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_2 = PyList_GET_ITEM(__pyx_t_10, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 297, __pyx_L1_error)
            #else
            __pyx_t_2 = PySequence_ITEM(__pyx_t_10, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            #endif
          } else {
            if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_10)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_10, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 297, __pyx_L1_error)
            #else
            __pyx_t_2 = PySequence_ITEM(__pyx_t_10, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 297, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            #endif
          }
        } else {
          __pyx_t_2 = __pyx_t_16(__pyx_t_10);
          if (unlikely(!__pyx_t_2)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 297, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_XDECREF_SET(__pyx_v_partial, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":298
 *                 match = None
 *                 for partial in segment['data']:
 *                     signature_compare = partial['signature']             # <<<<<<<<<<<<<<
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')
 *                     if True == self.single_array_match(signature_compare, haystack):
 */
        __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_partial, __pyx_n_s_signature); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_signature_compare, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":299
 *                 for partial in segment['data']:
 *                     signature_compare = partial['signature']
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')             # <<<<<<<<<<<<<<
 *                     if True == self.single_array_match(signature_compare, haystack):
 *                         #    self.info("match", signature_compare,haystack)
 */
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_sub_array_sub_key); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_v_tokens, 0, 0, &__pyx_v_token_index, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_1, __pyx_n_s_data};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_t_1, __pyx_n_s_data};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        } else
        #endif
        {
          __pyx_t_3 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 299, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (__pyx_t_4) {
            __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4); __pyx_t_4 = NULL;
          }
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_3, 0+__pyx_t_5, __pyx_t_1);
          __Pyx_INCREF(__pyx_n_s_data);
          __Pyx_GIVEREF(__pyx_n_s_data);
          PyTuple_SET_ITEM(__pyx_t_3, 1+__pyx_t_5, __pyx_n_s_data);
          __pyx_t_1 = 0;
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 299, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF_SET(__pyx_v_haystack, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":300
 *                     signature_compare = partial['signature']
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')
 *                     if True == self.single_array_match(signature_compare, haystack):             # <<<<<<<<<<<<<<
 *                         #    self.info("match", signature_compare,haystack)
 *                         if len(signature_compare) > match_len:
 */
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_single_array_match); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_3 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_3)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_3);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_signature_compare, __pyx_v_haystack};
          __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_15)) {
          PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_signature_compare, __pyx_v_haystack};
          __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_15, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_GOTREF(__pyx_t_2);
        } else
        #endif
        {
          __pyx_t_1 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (__pyx_t_3) {
            __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3); __pyx_t_3 = NULL;
          }
          __Pyx_INCREF(__pyx_v_signature_compare);
          __Pyx_GIVEREF(__pyx_v_signature_compare);
          PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_5, __pyx_v_signature_compare);
          __Pyx_INCREF(__pyx_v_haystack);
          __Pyx_GIVEREF(__pyx_v_haystack);
          PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_5, __pyx_v_haystack);
          __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_15, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        }
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __pyx_t_15 = PyObject_RichCompare(Py_True, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_15); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_15); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 300, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (__pyx_t_13) {

          /* "ddb/lexer/lexer.py":302
 *                     if True == self.single_array_match(signature_compare, haystack):
 *                         #    self.info("match", signature_compare,haystack)
 *                         if len(signature_compare) > match_len:             # <<<<<<<<<<<<<<
 *                             match_len = len(signature_compare)
 *                             match = signature_compare
 */
          __pyx_t_8 = PyObject_Length(__pyx_v_signature_compare); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 302, __pyx_L1_error)
          __pyx_t_13 = ((__pyx_t_8 > __pyx_v_match_len) != 0);
          if (__pyx_t_13) {

            /* "ddb/lexer/lexer.py":303
 *                         #    self.info("match", signature_compare,haystack)
 *                         if len(signature_compare) > match_len:
 *                             match_len = len(signature_compare)             # <<<<<<<<<<<<<<
 *                             match = signature_compare
 *                             signature=partial
 */
            __pyx_t_8 = PyObject_Length(__pyx_v_signature_compare); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 303, __pyx_L1_error)
            __pyx_v_match_len = __pyx_t_8;

            /* "ddb/lexer/lexer.py":304
 *                         if len(signature_compare) > match_len:
 *                             match_len = len(signature_compare)
 *                             match = signature_compare             # <<<<<<<<<<<<<<
 *                             signature=partial
 *                             self.info("Best Match", match_len)
 */
            __Pyx_INCREF(__pyx_v_signature_compare);
            __Pyx_DECREF_SET(__pyx_v_match, __pyx_v_signature_compare);

            /* "ddb/lexer/lexer.py":305
 *                             match_len = len(signature_compare)
 *                             match = signature_compare
 *                             signature=partial             # <<<<<<<<<<<<<<
 *                             self.info("Best Match", match_len)
 *                 if None == match:
 */
            __Pyx_INCREF(__pyx_v_partial);
            __Pyx_XDECREF_SET(__pyx_v_signature, __pyx_v_partial);

            /* "ddb/lexer/lexer.py":306
 *                             match = signature_compare
 *                             signature=partial
 *                             self.info("Best Match", match_len)             # <<<<<<<<<<<<<<
 *                 if None == match:
 *                     self.info("No match")
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 306, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_match_len); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 306, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_3 = NULL;
            __pyx_t_5 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
                __pyx_t_5 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_s_Best_Match, __pyx_t_1};
              __pyx_t_15 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 306, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_kp_s_Best_Match, __pyx_t_1};
              __pyx_t_15 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 306, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 306, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              if (__pyx_t_3) {
                __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3); __pyx_t_3 = NULL;
              }
              __Pyx_INCREF(__pyx_kp_s_Best_Match);
              __Pyx_GIVEREF(__pyx_kp_s_Best_Match);
              PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_kp_s_Best_Match);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 306, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

            /* "ddb/lexer/lexer.py":302
 *                     if True == self.single_array_match(signature_compare, haystack):
 *                         #    self.info("match", signature_compare,haystack)
 *                         if len(signature_compare) > match_len:             # <<<<<<<<<<<<<<
 *                             match_len = len(signature_compare)
 *                             match = signature_compare
 */
          }

          /* "ddb/lexer/lexer.py":300
 *                     signature_compare = partial['signature']
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')
 *                     if True == self.single_array_match(signature_compare, haystack):             # <<<<<<<<<<<<<<
 *                         #    self.info("match", signature_compare,haystack)
 *                         if len(signature_compare) > match_len:
 */
        }

        /* "ddb/lexer/lexer.py":297
 *                 match_len = 0
 *                 match = None
 *                 for partial in segment['data']:             # <<<<<<<<<<<<<<
 *                     signature_compare = partial['signature']
 *                     haystack = self.get_sub_array_sub_key(tokens[token_index:], 'data')
 */
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "ddb/lexer/lexer.py":307
 *                             signature=partial
 *                             self.info("Best Match", match_len)
 *                 if None == match:             # <<<<<<<<<<<<<<
 *                     self.info("No match")
 *                     break
 */
      __pyx_t_10 = PyObject_RichCompare(Py_None, __pyx_v_match, Py_EQ); __Pyx_XGOTREF(__pyx_t_10); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 307, __pyx_L1_error)
      __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_10); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 307, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (__pyx_t_13) {

        /* "ddb/lexer/lexer.py":308
 *                             self.info("Best Match", match_len)
 *                 if None == match:
 *                     self.info("No match")             # <<<<<<<<<<<<<<
 *                     break
 *                 else:
 */
        __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 308, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_15);
        __pyx_t_2 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_15))) {
          __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_15);
          if (likely(__pyx_t_2)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_15);
            __Pyx_INCREF(__pyx_t_2);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_15, function);
          }
        }
        __pyx_t_10 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_15, __pyx_t_2, __pyx_kp_s_No_match) : __Pyx_PyObject_CallOneArg(__pyx_t_15, __pyx_kp_s_No_match);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 308, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

        /* "ddb/lexer/lexer.py":309
 *                 if None == match:
 *                     self.info("No match")
 *                     break             # <<<<<<<<<<<<<<
 *                 else:
 *                     # add the static vars
 */
        goto __pyx_L10_break;

        /* "ddb/lexer/lexer.py":307
 *                             signature=partial
 *                             self.info("Best Match", match_len)
 *                 if None == match:             # <<<<<<<<<<<<<<
 *                     self.info("No match")
 *                     break
 */
      }

      /* "ddb/lexer/lexer.py":312
 *                 else:
 *                     # add the static vars
 *                     base_argument={}             # <<<<<<<<<<<<<<
 *                     if 'vars' in signature:
 *                         for var_name in signature['vars']:
 */
      /*else*/ {
        __pyx_t_10 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 312, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF_SET(__pyx_v_base_argument, ((PyObject*)__pyx_t_10));
        __pyx_t_10 = 0;

        /* "ddb/lexer/lexer.py":313
 *                     # add the static vars
 *                     base_argument={}
 *                     if 'vars' in signature:             # <<<<<<<<<<<<<<
 *                         for var_name in signature['vars']:
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))
 */
        if (unlikely(!__pyx_v_signature)) { __Pyx_RaiseUnboundLocalError("signature"); __PYX_ERR(0, 313, __pyx_L1_error) }
        __pyx_t_13 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_vars, __pyx_v_signature, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 313, __pyx_L1_error)
        __pyx_t_12 = (__pyx_t_13 != 0);
        if (__pyx_t_12) {

          /* "ddb/lexer/lexer.py":314
 *                     base_argument={}
 *                     if 'vars' in signature:
 *                         for var_name in signature['vars']:             # <<<<<<<<<<<<<<
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))
 *                             base_argument[var_name]=signature['vars'][var_name]
 */
          if (unlikely(!__pyx_v_signature)) { __Pyx_RaiseUnboundLocalError("signature"); __PYX_ERR(0, 314, __pyx_L1_error) }
          __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_signature, __pyx_n_s_vars); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 314, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (likely(PyList_CheckExact(__pyx_t_10)) || PyTuple_CheckExact(__pyx_t_10)) {
            __pyx_t_15 = __pyx_t_10; __Pyx_INCREF(__pyx_t_15); __pyx_t_7 = 0;
            __pyx_t_16 = NULL;
          } else {
            __pyx_t_7 = -1; __pyx_t_15 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 314, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_15);
            __pyx_t_16 = Py_TYPE(__pyx_t_15)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 314, __pyx_L1_error)
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          for (;;) {
            if (likely(!__pyx_t_16)) {
              if (likely(PyList_CheckExact(__pyx_t_15))) {
                if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_15)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyList_GET_ITEM(__pyx_t_15, __pyx_t_7); __Pyx_INCREF(__pyx_t_10); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_15, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 314, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              } else {
                if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_15)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_15, __pyx_t_7); __Pyx_INCREF(__pyx_t_10); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_15, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 314, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              }
            } else {
              __pyx_t_10 = __pyx_t_16(__pyx_t_15);
              if (unlikely(!__pyx_t_10)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 314, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_10);
            }
            __Pyx_XDECREF_SET(__pyx_v_var_name, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "ddb/lexer/lexer.py":315
 *                     if 'vars' in signature:
 *                         for var_name in signature['vars']:
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))             # <<<<<<<<<<<<<<
 *                             base_argument[var_name]=signature['vars'][var_name]
 * 
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 315, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_1_2, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 315, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            if (unlikely(!__pyx_v_signature)) { __Pyx_RaiseUnboundLocalError("signature"); __PYX_ERR(0, 315, __pyx_L1_error) }
            __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_signature, __pyx_n_s_vars); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 315, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
            __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_var_name); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 315, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __pyx_t_3 = NULL;
            __pyx_t_5 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
              __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
              if (likely(__pyx_t_3)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_1, function);
                __pyx_t_5 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_var_name, __pyx_t_6};
              __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
              PyObject *__pyx_temp[3] = {__pyx_t_3, __pyx_v_var_name, __pyx_t_6};
              __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              if (__pyx_t_3) {
                __Pyx_GIVEREF(__pyx_t_3); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_3); __pyx_t_3 = NULL;
              }
              __Pyx_INCREF(__pyx_v_var_name);
              __Pyx_GIVEREF(__pyx_v_var_name);
              PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_5, __pyx_v_var_name);
              __Pyx_GIVEREF(__pyx_t_6);
              PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_5, __pyx_t_6);
              __pyx_t_6 = 0;
              __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_14, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            __pyx_t_1 = NULL;
            __pyx_t_5 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_1)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_1);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
                __pyx_t_5 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_n_s_var, __pyx_t_4};
              __pyx_t_10 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_n_s_var, __pyx_t_4};
              __pyx_t_10 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              if (__pyx_t_1) {
                __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_1); __pyx_t_1 = NULL;
              }
              __Pyx_INCREF(__pyx_n_s_var);
              __Pyx_GIVEREF(__pyx_n_s_var);
              PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_5, __pyx_n_s_var);
              __Pyx_GIVEREF(__pyx_t_4);
              PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_5, __pyx_t_4);
              __pyx_t_4 = 0;
              __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_14, NULL); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 315, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

            /* "ddb/lexer/lexer.py":316
 *                         for var_name in signature['vars']:
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))
 *                             base_argument[var_name]=signature['vars'][var_name]             # <<<<<<<<<<<<<<
 * 
 *                     argument = base_argument
 */
            if (unlikely(!__pyx_v_signature)) { __Pyx_RaiseUnboundLocalError("signature"); __PYX_ERR(0, 316, __pyx_L1_error) }
            __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_signature, __pyx_n_s_vars); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 316, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_10, __pyx_v_var_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 316, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            if (unlikely(PyDict_SetItem(__pyx_v_base_argument, __pyx_v_var_name, __pyx_t_2) < 0)) __PYX_ERR(0, 316, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "ddb/lexer/lexer.py":314
 *                     base_argument={}
 *                     if 'vars' in signature:
 *                         for var_name in signature['vars']:             # <<<<<<<<<<<<<<
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))
 *                             base_argument[var_name]=signature['vars'][var_name]
 */
          }
          __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

          /* "ddb/lexer/lexer.py":313
 *                     # add the static vars
 *                     base_argument={}
 *                     if 'vars' in signature:             # <<<<<<<<<<<<<<
 *                         for var_name in signature['vars']:
 *                             self.info("var","'{0}'='{1}'".format(var_name,signature['vars'][var_name]))
 */
        }

        /* "ddb/lexer/lexer.py":318
 *                             base_argument[var_name]=signature['vars'][var_name]
 * 
 *                     argument = base_argument             # <<<<<<<<<<<<<<
 *                     for w_index in range(0,len(match)):
 *                         word=match[w_index]
 */
        __Pyx_INCREF(__pyx_v_base_argument);
        __Pyx_XDECREF_SET(__pyx_v_argument, __pyx_v_base_argument);

        /* "ddb/lexer/lexer.py":319
 * 
 *                     argument = base_argument
 *                     for w_index in range(0,len(match)):             # <<<<<<<<<<<<<<
 *                         word=match[w_index]
 *                         try:
 */
        __pyx_t_7 = PyObject_Length(__pyx_v_match); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 319, __pyx_L1_error)
        __pyx_t_8 = __pyx_t_7;
        for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
          __pyx_v_w_index = __pyx_t_9;

          /* "ddb/lexer/lexer.py":320
 *                     argument = base_argument
 *                     for w_index in range(0,len(match)):
 *                         word=match[w_index]             # <<<<<<<<<<<<<<
 *                         try:
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 */
          __pyx_t_15 = __Pyx_GetItemInt(__pyx_v_match, __pyx_v_w_index, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 320, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_15);
          __Pyx_XDECREF_SET(__pyx_v_word, __pyx_t_15);
          __pyx_t_15 = 0;

          /* "ddb/lexer/lexer.py":321
 *                     for w_index in range(0,len(match)):
 *                         word=match[w_index]
 *                         try:             # <<<<<<<<<<<<<<
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 *                             argument[computed['key']]=computed['value']
 */
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_17, &__pyx_t_18, &__pyx_t_19);
            __Pyx_XGOTREF(__pyx_t_17);
            __Pyx_XGOTREF(__pyx_t_18);
            __Pyx_XGOTREF(__pyx_t_19);
            /*try:*/ {

              /* "ddb/lexer/lexer.py":322
 *                         word=match[w_index]
 *                         try:
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)             # <<<<<<<<<<<<<<
 *                             argument[computed['key']]=computed['value']
 *                         except:
 */
              __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_get_argument); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 322, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_10 = PyInt_FromSsize_t(__pyx_v_w_index); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 322, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_14 = NULL;
              __pyx_t_5 = 0;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
                __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_2);
                if (likely(__pyx_t_14)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                  __Pyx_INCREF(__pyx_t_14);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_2, function);
                  __pyx_t_5 = 1;
                }
              }
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_2)) {
                PyObject *__pyx_temp[6] = {__pyx_t_14, __pyx_v_word, __pyx_v_segment, __pyx_v_tokens, __pyx_v_token_index, __pyx_t_10};
                __pyx_t_15 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 5+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 322, __pyx_L29_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
                PyObject *__pyx_temp[6] = {__pyx_t_14, __pyx_v_word, __pyx_v_segment, __pyx_v_tokens, __pyx_v_token_index, __pyx_t_10};
                __pyx_t_15 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 5+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 322, __pyx_L29_error)
                __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              } else
              #endif
              {
                __pyx_t_4 = PyTuple_New(5+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 322, __pyx_L29_error)
                __Pyx_GOTREF(__pyx_t_4);
                if (__pyx_t_14) {
                  __Pyx_GIVEREF(__pyx_t_14); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_14); __pyx_t_14 = NULL;
                }
                __Pyx_INCREF(__pyx_v_word);
                __Pyx_GIVEREF(__pyx_v_word);
                PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_v_word);
                __Pyx_INCREF(__pyx_v_segment);
                __Pyx_GIVEREF(__pyx_v_segment);
                PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_v_segment);
                __Pyx_INCREF(__pyx_v_tokens);
                __Pyx_GIVEREF(__pyx_v_tokens);
                PyTuple_SET_ITEM(__pyx_t_4, 2+__pyx_t_5, __pyx_v_tokens);
                __Pyx_INCREF(__pyx_v_token_index);
                __Pyx_GIVEREF(__pyx_v_token_index);
                PyTuple_SET_ITEM(__pyx_t_4, 3+__pyx_t_5, __pyx_v_token_index);
                __Pyx_GIVEREF(__pyx_t_10);
                PyTuple_SET_ITEM(__pyx_t_4, 4+__pyx_t_5, __pyx_t_10);
                __pyx_t_10 = 0;
                __pyx_t_15 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, NULL); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 322, __pyx_L29_error)
                __Pyx_GOTREF(__pyx_t_15);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_XDECREF_SET(__pyx_v_computed, __pyx_t_15);
              __pyx_t_15 = 0;

              /* "ddb/lexer/lexer.py":323
 *                         try:
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 *                             argument[computed['key']]=computed['value']             # <<<<<<<<<<<<<<
 *                         except:
 *                             break
 */
              __pyx_t_15 = __Pyx_PyObject_Dict_GetItem(__pyx_v_computed, __pyx_n_s_value); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 323, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_15);
              __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_computed, __pyx_n_s_key); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 323, __pyx_L29_error)
              __Pyx_GOTREF(__pyx_t_2);
              if (unlikely(PyDict_SetItem(__pyx_v_argument, __pyx_t_2, __pyx_t_15) < 0)) __PYX_ERR(0, 323, __pyx_L29_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;

              /* "ddb/lexer/lexer.py":321
 *                     for w_index in range(0,len(match)):
 *                         word=match[w_index]
 *                         try:             # <<<<<<<<<<<<<<
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 *                             argument[computed['key']]=computed['value']
 */
            }
            __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
            __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
            __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
            goto __pyx_L36_try_end;
            __pyx_L29_error:;
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

            /* "ddb/lexer/lexer.py":324
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 *                             argument[computed['key']]=computed['value']
 *                         except:             # <<<<<<<<<<<<<<
 *                             break
 * 
 */
            /*except:*/ {
              __Pyx_AddTraceback("ddb.lexer.lexer.lexer.test_syntax", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_15, &__pyx_t_2, &__pyx_t_4) < 0) __PYX_ERR(0, 324, __pyx_L31_except_error)
              __Pyx_GOTREF(__pyx_t_15);
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_GOTREF(__pyx_t_4);

              /* "ddb/lexer/lexer.py":325
 *                             argument[computed['key']]=computed['value']
 *                         except:
 *                             break             # <<<<<<<<<<<<<<
 * 
 * 
 */
              goto __pyx_L37_except_break;
              __pyx_L37_except_break:;
              __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              goto __pyx_L34_try_break;
            }
            __pyx_L31_except_error:;

            /* "ddb/lexer/lexer.py":321
 *                     for w_index in range(0,len(match)):
 *                         word=match[w_index]
 *                         try:             # <<<<<<<<<<<<<<
 *                             computed=self.get_argument(word,segment,tokens,token_index,w_index)
 *                             argument[computed['key']]=computed['value']
 */
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            goto __pyx_L1_error;
            __pyx_L34_try_break:;
            __Pyx_XGIVEREF(__pyx_t_17);
            __Pyx_XGIVEREF(__pyx_t_18);
            __Pyx_XGIVEREF(__pyx_t_19);
            __Pyx_ExceptionReset(__pyx_t_17, __pyx_t_18, __pyx_t_19);
            goto __pyx_L28_break;
            __pyx_L36_try_end:;
          }
        }
        __pyx_L28_break:;

        /* "ddb/lexer/lexer.py":330
 * 
 * 
 *                     if 'arguments' not in curent_object:             # <<<<<<<<<<<<<<
 *                         curent_object['arguments'] = []
 * 
 */
        __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_arguments, __pyx_v_curent_object, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 330, __pyx_L1_error)
        __pyx_t_13 = (__pyx_t_12 != 0);
        if (__pyx_t_13) {

          /* "ddb/lexer/lexer.py":331
 * 
 *                     if 'arguments' not in curent_object:
 *                         curent_object['arguments'] = []             # <<<<<<<<<<<<<<
 * 
 *                     if arguments == 1:
 */
          __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 331, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          if (unlikely(PyDict_SetItem(__pyx_v_curent_object, __pyx_n_s_arguments, __pyx_t_4) < 0)) __PYX_ERR(0, 331, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

          /* "ddb/lexer/lexer.py":330
 * 
 * 
 *                     if 'arguments' not in curent_object:             # <<<<<<<<<<<<<<
 *                         curent_object['arguments'] = []
 * 
 */
        }

        /* "ddb/lexer/lexer.py":333
 *                         curent_object['arguments'] = []
 * 
 *                     if arguments == 1:             # <<<<<<<<<<<<<<
 *                         curent_object['arguments'] = argument
 *                     else:
 */
        __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_arguments, __pyx_int_1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 333, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 333, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (__pyx_t_13) {

          /* "ddb/lexer/lexer.py":334
 * 
 *                     if arguments == 1:
 *                         curent_object['arguments'] = argument             # <<<<<<<<<<<<<<
 *                     else:
 *                         # add the arguments to curent object
 */
          if (unlikely(PyDict_SetItem(__pyx_v_curent_object, __pyx_n_s_arguments, __pyx_v_argument) < 0)) __PYX_ERR(0, 334, __pyx_L1_error)

          /* "ddb/lexer/lexer.py":333
 *                         curent_object['arguments'] = []
 * 
 *                     if arguments == 1:             # <<<<<<<<<<<<<<
 *                         curent_object['arguments'] = argument
 *                     else:
 */
          goto __pyx_L40;
        }

        /* "ddb/lexer/lexer.py":337
 *                     else:
 *                         # add the arguments to curent object
 *                         curent_object['arguments'].append(argument)             # <<<<<<<<<<<<<<
 * 
 *                     self.info("match", match)
 */
        /*else*/ {
          __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 337, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_4, __pyx_v_argument); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 337, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_L40:;

        /* "ddb/lexer/lexer.py":339
 *                         curent_object['arguments'].append(argument)
 * 
 *                     self.info("match", match)             # <<<<<<<<<<<<<<
 *                     token_index += len(match)
 *                     if arguments != 0:
 */
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 339, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_15 = NULL;
        __pyx_t_5 = 0;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
          __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_2);
          if (likely(__pyx_t_15)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
            __Pyx_INCREF(__pyx_t_15);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_2, function);
            __pyx_t_5 = 1;
          }
        }
        #if CYTHON_FAST_PYCALL
        if (PyFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_n_s_match, __pyx_v_match};
          __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 339, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        #if CYTHON_FAST_PYCCALL
        if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
          PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_n_s_match, __pyx_v_match};
          __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 339, __pyx_L1_error)
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_GOTREF(__pyx_t_4);
        } else
        #endif
        {
          __pyx_t_10 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 339, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          if (__pyx_t_15) {
            __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_15); __pyx_t_15 = NULL;
          }
          __Pyx_INCREF(__pyx_n_s_match);
          __Pyx_GIVEREF(__pyx_n_s_match);
          PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_5, __pyx_n_s_match);
          __Pyx_INCREF(__pyx_v_match);
          __Pyx_GIVEREF(__pyx_v_match);
          PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_5, __pyx_v_match);
          __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 339, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        }
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "ddb/lexer/lexer.py":340
 * 
 *                     self.info("match", match)
 *                     token_index += len(match)             # <<<<<<<<<<<<<<
 *                     if arguments != 0:
 *                         self.info("print not in list")
 */
        __pyx_t_7 = PyObject_Length(__pyx_v_match); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 340, __pyx_L1_error)
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 340, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_2 = PyNumber_InPlaceAdd(__pyx_v_token_index, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 340, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF_SET(__pyx_v_token_index, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "ddb/lexer/lexer.py":341
 *                     self.info("match", match)
 *                     token_index += len(match)
 *                     if arguments != 0:             # <<<<<<<<<<<<<<
 *                         self.info("print not in list")
 *                         argument_index += 1
 */
        __pyx_t_2 = __Pyx_PyInt_NeObjC(__pyx_v_arguments, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 341, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_13) {

          /* "ddb/lexer/lexer.py":342
 *                     token_index += len(match)
 *                     if arguments != 0:
 *                         self.info("print not in list")             # <<<<<<<<<<<<<<
 *                         argument_index += 1
 *                         if argument_index >= arguments:
 */
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 342, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_4, function);
            }
          }
          __pyx_t_2 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_10, __pyx_kp_s_print_not_in_list) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_s_print_not_in_list);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 342, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":343
 *                     if arguments != 0:
 *                         self.info("print not in list")
 *                         argument_index += 1             # <<<<<<<<<<<<<<
 *                         if argument_index >= arguments:
 *                             self.info("----------Adding", curent_object['mode'])
 */
          __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_argument_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 343, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF_SET(__pyx_v_argument_index, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "ddb/lexer/lexer.py":344
 *                         self.info("print not in list")
 *                         argument_index += 1
 *                         if argument_index >= arguments:             # <<<<<<<<<<<<<<
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:
 */
          __pyx_t_2 = PyObject_RichCompare(__pyx_v_argument_index, __pyx_v_arguments, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 344, __pyx_L1_error)
          __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 344, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_13) {

            /* "ddb/lexer/lexer.py":345
 *                         argument_index += 1
 *                         if argument_index >= arguments:
 *                             self.info("----------Adding", curent_object['mode'])             # <<<<<<<<<<<<<<
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:
 */
            __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 345, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 345, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_15 = NULL;
            __pyx_t_5 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
              __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_4);
              if (likely(__pyx_t_15)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                __Pyx_INCREF(__pyx_t_15);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_4, function);
                __pyx_t_5 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_4)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_kp_s_Adding, __pyx_t_10};
              __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
              PyObject *__pyx_temp[3] = {__pyx_t_15, __pyx_kp_s_Adding, __pyx_t_10};
              __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            } else
            #endif
            {
              __pyx_t_14 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 345, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              if (__pyx_t_15) {
                __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_t_15); __pyx_t_15 = NULL;
              }
              __Pyx_INCREF(__pyx_kp_s_Adding);
              __Pyx_GIVEREF(__pyx_kp_s_Adding);
              PyTuple_SET_ITEM(__pyx_t_14, 0+__pyx_t_5, __pyx_kp_s_Adding);
              __Pyx_GIVEREF(__pyx_t_10);
              PyTuple_SET_ITEM(__pyx_t_14, 1+__pyx_t_5, __pyx_t_10);
              __pyx_t_10 = 0;
              __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_14, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 345, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            }
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "ddb/lexer/lexer.py":346
 *                         if argument_index >= arguments:
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_store_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 346, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = PyObject_RichCompare(Py_True, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 346, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 346, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (__pyx_t_13) {

              /* "ddb/lexer/lexer.py":347
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                     query_object[curent_object['mode']] = []
 * 
 */
              __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 347, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_13 = (__Pyx_PyDict_ContainsTF(__pyx_t_4, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 347, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_12 = (__pyx_t_13 != 0);
              if (__pyx_t_12) {

                /* "ddb/lexer/lexer.py":348
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []             # <<<<<<<<<<<<<<
 * 
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 */
                __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 348, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 348, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_2, __pyx_t_4) < 0)) __PYX_ERR(0, 348, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                /* "ddb/lexer/lexer.py":347
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                     query_object[curent_object['mode']] = []
 * 
 */
              }

              /* "ddb/lexer/lexer.py":350
 *                                     query_object[curent_object['mode']] = []
 * 
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 *                             else:
 *                                 if None == flags.parent:
 */
              __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (PyDict_SetItem(__pyx_t_4, __pyx_t_14, __pyx_t_10) < 0) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_4); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 350, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

              /* "ddb/lexer/lexer.py":346
 *                         if argument_index >= arguments:
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []
 */
              goto __pyx_L43;
            }

            /* "ddb/lexer/lexer.py":352
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                             else:
 *                                 if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                     if flags.meta_type=='single':
 *                                         for flags.arg_key in curent_object['arguments']:
 */
            /*else*/ {
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 352, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_2 = PyObject_RichCompare(Py_None, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 352, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 352, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (__pyx_t_12) {

                /* "ddb/lexer/lexer.py":353
 *                             else:
 *                                 if None == flags.parent:
 *                                     if flags.meta_type=='single':             # <<<<<<<<<<<<<<
 *                                         for flags.arg_key in curent_object['arguments']:
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]
 */
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_meta_type); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 353, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_n_s_single, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 353, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (__pyx_t_12) {

                  /* "ddb/lexer/lexer.py":354
 *                                 if None == flags.parent:
 *                                     if flags.meta_type=='single':
 *                                         for flags.arg_key in curent_object['arguments']:             # <<<<<<<<<<<<<<
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]
 *                                     else:
 */
                  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
                    __pyx_t_4 = __pyx_t_2; __Pyx_INCREF(__pyx_t_4); __pyx_t_7 = 0;
                    __pyx_t_16 = NULL;
                  } else {
                    __pyx_t_7 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 354, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_4);
                    __pyx_t_16 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 354, __pyx_L1_error)
                  }
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  for (;;) {
                    if (likely(!__pyx_t_16)) {
                      if (likely(PyList_CheckExact(__pyx_t_4))) {
                        if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_4)) break;
                        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 354, __pyx_L1_error)
                        #else
                        __pyx_t_2 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
                        __Pyx_GOTREF(__pyx_t_2);
                        #endif
                      } else {
                        if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
                        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 354, __pyx_L1_error)
                        #else
                        __pyx_t_2 = PySequence_ITEM(__pyx_t_4, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 354, __pyx_L1_error)
                        __Pyx_GOTREF(__pyx_t_2);
                        #endif
                      }
                    } else {
                      __pyx_t_2 = __pyx_t_16(__pyx_t_4);
                      if (unlikely(!__pyx_t_2)) {
                        PyObject* exc_type = PyErr_Occurred();
                        if (exc_type) {
                          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                          else __PYX_ERR(0, 354, __pyx_L1_error)
                        }
                        break;
                      }
                      __Pyx_GOTREF(__pyx_t_2);
                    }
                    if (__Pyx_PyObject_SetAttrStr(__pyx_v_flags, __pyx_n_s_arg_key, __pyx_t_2) < 0) __PYX_ERR(0, 354, __pyx_L1_error)
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                    /* "ddb/lexer/lexer.py":355
 *                                     if flags.meta_type=='single':
 *                                         for flags.arg_key in curent_object['arguments']:
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]             # <<<<<<<<<<<<<<
 *                                     else:
 *                                         query_object[curent_object['mode']] = curent_object['arguments']
 */
                    __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 355, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_arg_key); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 355, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_10);
                    __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_t_10); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 355, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_arg_key); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 355, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_10);
                    if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_10, __pyx_t_14) < 0)) __PYX_ERR(0, 355, __pyx_L1_error)
                    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

                    /* "ddb/lexer/lexer.py":354
 *                                 if None == flags.parent:
 *                                     if flags.meta_type=='single':
 *                                         for flags.arg_key in curent_object['arguments']:             # <<<<<<<<<<<<<<
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]
 *                                     else:
 */
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "ddb/lexer/lexer.py":353
 *                             else:
 *                                 if None == flags.parent:
 *                                     if flags.meta_type=='single':             # <<<<<<<<<<<<<<
 *                                         for flags.arg_key in curent_object['arguments']:
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]
 */
                  goto __pyx_L46;
                }

                /* "ddb/lexer/lexer.py":357
 *                                             query_object[flags.arg_key] = curent_object['arguments'][flags.arg_key]
 *                                     else:
 *                                         query_object[curent_object['mode']] = curent_object['arguments']             # <<<<<<<<<<<<<<
 *                                     self.info("NO APPEND")
 *                                 else:
 */
                /*else*/ {
                  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 357, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 357, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_4) < 0)) __PYX_ERR(0, 357, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                }
                __pyx_L46:;

                /* "ddb/lexer/lexer.py":358
 *                                     else:
 *                                         query_object[curent_object['mode']] = curent_object['arguments']
 *                                     self.info("NO APPEND")             # <<<<<<<<<<<<<<
 *                                 else:
 *                                     self.info("APPEND")
 */
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 358, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_10 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                  __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
                  if (likely(__pyx_t_10)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                    __Pyx_INCREF(__pyx_t_10);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_14, function);
                  }
                }
                __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_kp_s_NO_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_NO_APPEND);
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 358, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                /* "ddb/lexer/lexer.py":352
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                             else:
 *                                 if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                     if flags.meta_type=='single':
 *                                         for flags.arg_key in curent_object['arguments']:
 */
                goto __pyx_L45;
              }

              /* "ddb/lexer/lexer.py":360
 *                                     self.info("NO APPEND")
 *                                 else:
 *                                     self.info("APPEND")             # <<<<<<<<<<<<<<
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]
 */
              /*else*/ {
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 360, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_10 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                  __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
                  if (likely(__pyx_t_10)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                    __Pyx_INCREF(__pyx_t_10);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_14, function);
                  }
                }
                __pyx_t_4 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_n_s_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_s_APPEND);
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 360, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                /* "ddb/lexer/lexer.py":361
 *                                 else:
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 361, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_t_4, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 361, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_13 = (__pyx_t_12 != 0);
                if (__pyx_t_13) {

                  /* "ddb/lexer/lexer.py":362
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]             # <<<<<<<<<<<<<<
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                             jump = None
 */
                  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 362, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 362, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_4) < 0)) __PYX_ERR(0, 362, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                  /* "ddb/lexer/lexer.py":361
 *                                 else:
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                }

                /* "ddb/lexer/lexer.py":363
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 *                             jump = None
 *                             if 'jump' in segment:
 */
                __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                if (PyDict_SetItem(__pyx_t_4, __pyx_t_10, __pyx_t_2) < 0) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_14, __pyx_t_4); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 363, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __pyx_L45:;
            }
            __pyx_L43:;

            /* "ddb/lexer/lexer.py":364
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                             jump = None             # <<<<<<<<<<<<<<
 *                             if 'jump' in segment:
 *                                 self.info("JUMP")
 */
            __Pyx_INCREF(Py_None);
            __Pyx_XDECREF_SET(__pyx_v_jump, Py_None);

            /* "ddb/lexer/lexer.py":365
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                             jump = None
 *                             if 'jump' in segment:             # <<<<<<<<<<<<<<
 *                                 self.info("JUMP")
 *                                 jump = segment['jump']
 */
            __pyx_t_13 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_jump, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 365, __pyx_L1_error)
            __pyx_t_12 = (__pyx_t_13 != 0);
            if (__pyx_t_12) {

              /* "ddb/lexer/lexer.py":366
 *                             jump = None
 *                             if 'jump' in segment:
 *                                 self.info("JUMP")             # <<<<<<<<<<<<<<
 *                                 jump = segment['jump']
 *                             if None != jump:
 */
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 366, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_2 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_14);
                if (likely(__pyx_t_2)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                  __Pyx_INCREF(__pyx_t_2);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_14, function);
                }
              }
              __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_2, __pyx_n_s_JUMP) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_s_JUMP);
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 366, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

              /* "ddb/lexer/lexer.py":367
 *                             if 'jump' in segment:
 *                                 self.info("JUMP")
 *                                 jump = segment['jump']             # <<<<<<<<<<<<<<
 *                             if None != jump:
 *                                 tsi = 0
 */
              __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_jump); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 367, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __Pyx_DECREF_SET(__pyx_v_jump, __pyx_t_4);
              __pyx_t_4 = 0;

              /* "ddb/lexer/lexer.py":365
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                             jump = None
 *                             if 'jump' in segment:             # <<<<<<<<<<<<<<
 *                                 self.info("JUMP")
 *                                 jump = segment['jump']
 */
            }

            /* "ddb/lexer/lexer.py":368
 *                                 self.info("JUMP")
 *                                 jump = segment['jump']
 *                             if None != jump:             # <<<<<<<<<<<<<<
 *                                 tsi = 0
 *                                 for ts in command['segments']:
 */
            __pyx_t_4 = PyObject_RichCompare(Py_None, __pyx_v_jump, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 368, __pyx_L1_error)
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 368, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (__pyx_t_12) {

              /* "ddb/lexer/lexer.py":369
 *                                 jump = segment['jump']
 *                             if None != jump:
 *                                 tsi = 0             # <<<<<<<<<<<<<<
 *                                 for ts in command['segments']:
 *                                     if ts['name'] == jump:
 */
              __Pyx_INCREF(__pyx_int_0);
              __Pyx_XDECREF_SET(__pyx_v_tsi, __pyx_int_0);

              /* "ddb/lexer/lexer.py":370
 *                             if None != jump:
 *                                 tsi = 0
 *                                 for ts in command['segments']:             # <<<<<<<<<<<<<<
 *                                     if ts['name'] == jump:
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 */
              __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 370, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
                __pyx_t_14 = __pyx_t_4; __Pyx_INCREF(__pyx_t_14); __pyx_t_7 = 0;
                __pyx_t_16 = NULL;
              } else {
                __pyx_t_7 = -1; __pyx_t_14 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 370, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_16 = Py_TYPE(__pyx_t_14)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 370, __pyx_L1_error)
              }
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              for (;;) {
                if (likely(!__pyx_t_16)) {
                  if (likely(PyList_CheckExact(__pyx_t_14))) {
                    if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_14)) break;
                    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                    __pyx_t_4 = PyList_GET_ITEM(__pyx_t_14, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 370, __pyx_L1_error)
                    #else
                    __pyx_t_4 = PySequence_ITEM(__pyx_t_14, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 370, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_4);
                    #endif
                  } else {
                    if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_14)) break;
                    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                    __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_14, __pyx_t_7); __Pyx_INCREF(__pyx_t_4); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 370, __pyx_L1_error)
                    #else
                    __pyx_t_4 = PySequence_ITEM(__pyx_t_14, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 370, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_4);
                    #endif
                  }
                } else {
                  __pyx_t_4 = __pyx_t_16(__pyx_t_14);
                  if (unlikely(!__pyx_t_4)) {
                    PyObject* exc_type = PyErr_Occurred();
                    if (exc_type) {
                      if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                      else __PYX_ERR(0, 370, __pyx_L1_error)
                    }
                    break;
                  }
                  __Pyx_GOTREF(__pyx_t_4);
                }
                __Pyx_XDECREF_SET(__pyx_v_ts, __pyx_t_4);
                __pyx_t_4 = 0;

                /* "ddb/lexer/lexer.py":371
 *                                 tsi = 0
 *                                 for ts in command['segments']:
 *                                     if ts['name'] == jump:             # <<<<<<<<<<<<<<
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 *                                         segment_index = tsi + 1
 */
                __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ts, __pyx_n_s_name); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 371, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_2 = PyObject_RichCompare(__pyx_t_4, __pyx_v_jump, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 371, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 371, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (__pyx_t_12) {

                  /* "ddb/lexer/lexer.py":372
 *                                 for ts in command['segments']:
 *                                     if ts['name'] == jump:
 *                                         self.info("Jumping from ", segment_index, tsi + 1)             # <<<<<<<<<<<<<<
 *                                         segment_index = tsi + 1
 *                                         break
 */
                  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 372, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 372, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_10);
                  __pyx_t_15 = NULL;
                  __pyx_t_5 = 0;
                  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
                    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_4);
                    if (likely(__pyx_t_15)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                      __Pyx_INCREF(__pyx_t_15);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_4, function);
                      __pyx_t_5 = 1;
                    }
                  }
                  #if CYTHON_FAST_PYCALL
                  if (PyFunction_Check(__pyx_t_4)) {
                    PyObject *__pyx_temp[4] = {__pyx_t_15, __pyx_kp_s_Jumping_from, __pyx_v_segment_index, __pyx_t_10};
                    __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
                    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                    __Pyx_GOTREF(__pyx_t_2);
                    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                  } else
                  #endif
                  #if CYTHON_FAST_PYCCALL
                  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
                    PyObject *__pyx_temp[4] = {__pyx_t_15, __pyx_kp_s_Jumping_from, __pyx_v_segment_index, __pyx_t_10};
                    __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
                    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                    __Pyx_GOTREF(__pyx_t_2);
                    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                  } else
                  #endif
                  {
                    __pyx_t_1 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 372, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_1);
                    if (__pyx_t_15) {
                      __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_15); __pyx_t_15 = NULL;
                    }
                    __Pyx_INCREF(__pyx_kp_s_Jumping_from);
                    __Pyx_GIVEREF(__pyx_kp_s_Jumping_from);
                    PyTuple_SET_ITEM(__pyx_t_1, 0+__pyx_t_5, __pyx_kp_s_Jumping_from);
                    __Pyx_INCREF(__pyx_v_segment_index);
                    __Pyx_GIVEREF(__pyx_v_segment_index);
                    PyTuple_SET_ITEM(__pyx_t_1, 1+__pyx_t_5, __pyx_v_segment_index);
                    __Pyx_GIVEREF(__pyx_t_10);
                    PyTuple_SET_ITEM(__pyx_t_1, 2+__pyx_t_5, __pyx_t_10);
                    __pyx_t_10 = 0;
                    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 372, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                  }
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":373
 *                                     if ts['name'] == jump:
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 *                                         segment_index = tsi + 1             # <<<<<<<<<<<<<<
 *                                         break
 *                                     tsi += 1
 */
                  __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 373, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF_SET(__pyx_v_segment_index, __pyx_t_2);
                  __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":374
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 *                                         segment_index = tsi + 1
 *                                         break             # <<<<<<<<<<<<<<
 *                                     tsi += 1
 *                             in_argument = False
 */
                  goto __pyx_L53_break;

                  /* "ddb/lexer/lexer.py":371
 *                                 tsi = 0
 *                                 for ts in command['segments']:
 *                                     if ts['name'] == jump:             # <<<<<<<<<<<<<<
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 *                                         segment_index = tsi + 1
 */
                }

                /* "ddb/lexer/lexer.py":375
 *                                         segment_index = tsi + 1
 *                                         break
 *                                     tsi += 1             # <<<<<<<<<<<<<<
 *                             in_argument = False
 *                     else:
 */
                __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 375, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF_SET(__pyx_v_tsi, __pyx_t_2);
                __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":370
 *                             if None != jump:
 *                                 tsi = 0
 *                                 for ts in command['segments']:             # <<<<<<<<<<<<<<
 *                                     if ts['name'] == jump:
 *                                         self.info("Jumping from ", segment_index, tsi + 1)
 */
              }
              __pyx_L53_break:;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

              /* "ddb/lexer/lexer.py":368
 *                                 self.info("JUMP")
 *                                 jump = segment['jump']
 *                             if None != jump:             # <<<<<<<<<<<<<<
 *                                 tsi = 0
 *                                 for ts in command['segments']:
 */
            }

            /* "ddb/lexer/lexer.py":376
 *                                         break
 *                                     tsi += 1
 *                             in_argument = False             # <<<<<<<<<<<<<<
 *                     else:
 *                         self.info("in list")
 */
            __pyx_v_in_argument = 0;

            /* "ddb/lexer/lexer.py":344
 *                         self.info("print not in list")
 *                         argument_index += 1
 *                         if argument_index >= arguments:             # <<<<<<<<<<<<<<
 *                             self.info("----------Adding", curent_object['mode'])
 *                             if True == flags.store_array:
 */
          }

          /* "ddb/lexer/lexer.py":341
 *                     self.info("match", match)
 *                     token_index += len(match)
 *                     if arguments != 0:             # <<<<<<<<<<<<<<
 *                         self.info("print not in list")
 *                         argument_index += 1
 */
          goto __pyx_L41;
        }

        /* "ddb/lexer/lexer.py":378
 *                             in_argument = False
 *                     else:
 *                         self.info("in list")             # <<<<<<<<<<<<<<
 * 
 *                         if len(tokens) <= token_index:
 */
        /*else*/ {
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 378, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_4 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_4)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_4);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
            }
          }
          __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_kp_s_in_list) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s_in_list);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 378, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "ddb/lexer/lexer.py":380
 *                         self.info("in list")
 * 
 *                         if len(tokens) <= token_index:             # <<<<<<<<<<<<<<
 *                             self.info("at the end")
 *                             if True == flags.store_array:
 */
          __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 380, __pyx_L1_error)
          __pyx_t_14 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 380, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_14);
          __pyx_t_2 = PyObject_RichCompare(__pyx_t_14, __pyx_v_token_index, Py_LE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 380, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 380, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (__pyx_t_12) {

            /* "ddb/lexer/lexer.py":381
 * 
 *                         if len(tokens) <= token_index:
 *                             self.info("at the end")             # <<<<<<<<<<<<<<
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:
 */
            __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 381, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_4 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_14);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_14, function);
              }
            }
            __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_4, __pyx_kp_s_at_the_end) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_at_the_end);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 381, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "ddb/lexer/lexer.py":382
 *                         if len(tokens) <= token_index:
 *                             self.info("at the end")
 *                             if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_store_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 382, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_14 = PyObject_RichCompare(Py_True, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 382, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 382, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (__pyx_t_12) {

              /* "ddb/lexer/lexer.py":383
 *                             self.info("at the end")
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                     query_object[curent_object['mode']] = []
 * 
 */
              __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 383, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_t_14, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 383, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __pyx_t_13 = (__pyx_t_12 != 0);
              if (__pyx_t_13) {

                /* "ddb/lexer/lexer.py":384
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []             # <<<<<<<<<<<<<<
 * 
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 */
                __pyx_t_14 = PyList_New(0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 384, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 384, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_2, __pyx_t_14) < 0)) __PYX_ERR(0, 384, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

                /* "ddb/lexer/lexer.py":383
 *                             self.info("at the end")
 *                             if True == flags.store_array:
 *                                 if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                     query_object[curent_object['mode']] = []
 * 
 */
              }

              /* "ddb/lexer/lexer.py":386
 *                                     query_object[curent_object['mode']] = []
 * 
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 *                             else:
 *                                 if None == flags.parent:
 */
              __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __pyx_t_14 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_1);
              if (PyDict_SetItem(__pyx_t_14, __pyx_t_4, __pyx_t_1) < 0) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_14); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 386, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

              /* "ddb/lexer/lexer.py":382
 *                         if len(tokens) <= token_index:
 *                             self.info("at the end")
 *                             if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                 if curent_object['mode'] not in query_object:
 *                                     query_object[curent_object['mode']] = []
 */
              goto __pyx_L56;
            }

            /* "ddb/lexer/lexer.py":388
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                             else:
 *                                 if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                     #print curent_object
 *                                     query_object[curent_object['mode']] = curent_object['arguments']
 */
            /*else*/ {
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 388, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_2 = PyObject_RichCompare(Py_None, __pyx_t_14, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 388, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 388, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (__pyx_t_13) {

                /* "ddb/lexer/lexer.py":390
 *                                 if None == flags.parent:
 *                                     #print curent_object
 *                                     query_object[curent_object['mode']] = curent_object['arguments']             # <<<<<<<<<<<<<<
 *                                     self.info("NO APPEND")
 * 
 */
                __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 390, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 390, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_2) < 0)) __PYX_ERR(0, 390, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":391
 *                                     #print curent_object
 *                                     query_object[curent_object['mode']] = curent_object['arguments']
 *                                     self.info("NO APPEND")             # <<<<<<<<<<<<<<
 * 
 *                                 else:
 */
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 391, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_1 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_14);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_14, function);
                  }
                }
                __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_1, __pyx_kp_s_NO_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_NO_APPEND);
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 391, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":388
 *                                 query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                             else:
 *                                 if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                     #print curent_object
 *                                     query_object[curent_object['mode']] = curent_object['arguments']
 */
                goto __pyx_L58;
              }

              /* "ddb/lexer/lexer.py":394
 * 
 *                                 else:
 *                                     self.info("APPEND")             # <<<<<<<<<<<<<<
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]
 */
              /*else*/ {
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 394, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_1 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                  __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_14);
                  if (likely(__pyx_t_1)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                    __Pyx_INCREF(__pyx_t_1);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_14, function);
                  }
                }
                __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_1, __pyx_n_s_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_s_APPEND);
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 394, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":395
 *                                 else:
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 395, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_13 = (__Pyx_PyDict_ContainsTF(__pyx_t_2, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 395, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __pyx_t_12 = (__pyx_t_13 != 0);
                if (__pyx_t_12) {

                  /* "ddb/lexer/lexer.py":396
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]             # <<<<<<<<<<<<<<
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 * 
 */
                  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 396, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 396, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_2) < 0)) __PYX_ERR(0, 396, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":395
 *                                 else:
 *                                     self.info("APPEND")
 *                                     if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                }

                /* "ddb/lexer/lexer.py":397
 *                                     if flags.parent not in query_object:
 *                                         query_object[flags.parent]=[]
 *                                     query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 * 
 *                         # look ahead to see if its a list ","
 */
                __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __pyx_t_1 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_1);
                __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                if (PyDict_SetItem(__pyx_t_2, __pyx_t_1, __pyx_t_4) < 0) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_14, __pyx_t_2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 397, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              }
              __pyx_L58:;
            }
            __pyx_L56:;

            /* "ddb/lexer/lexer.py":380
 *                         self.info("in list")
 * 
 *                         if len(tokens) <= token_index:             # <<<<<<<<<<<<<<
 *                             self.info("at the end")
 *                             if True == flags.store_array:
 */
          }

          /* "ddb/lexer/lexer.py":400
 * 
 *                         # look ahead to see if its a list ","
 *                         if len(tokens) > token_index:             # <<<<<<<<<<<<<<
 *                             self.info("--looking ahead")
 *                             # if its not exit
 */
          __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 400, __pyx_L1_error)
          __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 400, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_14 = PyObject_RichCompare(__pyx_t_2, __pyx_v_token_index, Py_GT); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 400, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 400, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
          if (__pyx_t_12) {

            /* "ddb/lexer/lexer.py":401
 *                         # look ahead to see if its a list ","
 *                         if len(tokens) > token_index:
 *                             self.info("--looking ahead")             # <<<<<<<<<<<<<<
 *                             # if its not exit
 *                             self.info("----", tokens[token_index]['data'])
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 401, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = NULL;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
              }
            }
            __pyx_t_14 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_kp_s_looking_ahead) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s_looking_ahead);
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 401, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "ddb/lexer/lexer.py":403
 *                             self.info("--looking ahead")
 *                             # if its not exit
 *                             self.info("----", tokens[token_index]['data'])             # <<<<<<<<<<<<<<
 *                             if tokens[token_index]['data'] != ',':
 *                                 self.info("---not list")
 */
            __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 403, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_v_token_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 403, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_4);
            __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_t_4, __pyx_n_s_data); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 403, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __pyx_t_4 = NULL;
            __pyx_t_5 = 0;
            if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
              __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
              if (likely(__pyx_t_4)) {
                PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                __Pyx_INCREF(__pyx_t_4);
                __Pyx_INCREF(function);
                __Pyx_DECREF_SET(__pyx_t_2, function);
                __pyx_t_5 = 1;
              }
            }
            #if CYTHON_FAST_PYCALL
            if (PyFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_s__24, __pyx_t_1};
              __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 403, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            #if CYTHON_FAST_PYCCALL
            if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
              PyObject *__pyx_temp[3] = {__pyx_t_4, __pyx_kp_s__24, __pyx_t_1};
              __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 403, __pyx_L1_error)
              __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            } else
            #endif
            {
              __pyx_t_10 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 403, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              if (__pyx_t_4) {
                __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4); __pyx_t_4 = NULL;
              }
              __Pyx_INCREF(__pyx_kp_s__24);
              __Pyx_GIVEREF(__pyx_kp_s__24);
              PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_5, __pyx_kp_s__24);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_5, __pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_10, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 403, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            }
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

            /* "ddb/lexer/lexer.py":404
 *                             # if its not exit
 *                             self.info("----", tokens[token_index]['data'])
 *                             if tokens[token_index]['data'] != ',':             # <<<<<<<<<<<<<<
 *                                 self.info("---not list")
 *                                 # only append object after argument collection is done
 */
            __pyx_t_14 = __Pyx_PyObject_GetItem(__pyx_v_tokens, __pyx_v_token_index); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 404, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_14);
            __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_14, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 404, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            __pyx_t_12 = (__Pyx_PyString_Equals(__pyx_t_2, __pyx_kp_s__22, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 404, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            if (__pyx_t_12) {

              /* "ddb/lexer/lexer.py":405
 *                             self.info("----", tokens[token_index]['data'])
 *                             if tokens[token_index]['data'] != ',':
 *                                 self.info("---not list")             # <<<<<<<<<<<<<<
 *                                 # only append object after argument collection is done
 *                                 self.info("----------Adding", curent_object['mode'])
 */
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 405, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_10 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
                if (likely(__pyx_t_10)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                  __Pyx_INCREF(__pyx_t_10);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_14, function);
                }
              }
              __pyx_t_2 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_kp_s_not_list) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_not_list);
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 405, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "ddb/lexer/lexer.py":407
 *                                 self.info("---not list")
 *                                 # only append object after argument collection is done
 *                                 self.info("----------Adding", curent_object['mode'])             # <<<<<<<<<<<<<<
 *                                 if True == flags.store_array:
 *                                     if curent_object['mode'] not in query_object:
 */
              __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 407, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 407, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_1 = NULL;
              __pyx_t_5 = 0;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_14);
                if (likely(__pyx_t_1)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                  __Pyx_INCREF(__pyx_t_1);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_14, function);
                  __pyx_t_5 = 1;
                }
              }
              #if CYTHON_FAST_PYCALL
              if (PyFunction_Check(__pyx_t_14)) {
                PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Adding, __pyx_t_10};
                __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              } else
              #endif
              #if CYTHON_FAST_PYCCALL
              if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
                PyObject *__pyx_temp[3] = {__pyx_t_1, __pyx_kp_s_Adding, __pyx_t_10};
                __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_5, 2+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
                __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              } else
              #endif
              {
                __pyx_t_4 = PyTuple_New(2+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 407, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                if (__pyx_t_1) {
                  __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_1); __pyx_t_1 = NULL;
                }
                __Pyx_INCREF(__pyx_kp_s_Adding);
                __Pyx_GIVEREF(__pyx_kp_s_Adding);
                PyTuple_SET_ITEM(__pyx_t_4, 0+__pyx_t_5, __pyx_kp_s_Adding);
                __Pyx_GIVEREF(__pyx_t_10);
                PyTuple_SET_ITEM(__pyx_t_4, 1+__pyx_t_5, __pyx_t_10);
                __pyx_t_10 = 0;
                __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_4, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 407, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              }
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "ddb/lexer/lexer.py":408
 *                                 # only append object after argument collection is done
 *                                 self.info("----------Adding", curent_object['mode'])
 *                                 if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                     if curent_object['mode'] not in query_object:
 *                                         query_object[curent_object['mode']] = []
 */
              __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_store_array); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 408, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_14 = PyObject_RichCompare(Py_True, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 408, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 408, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              if (__pyx_t_12) {

                /* "ddb/lexer/lexer.py":409
 *                                 self.info("----------Adding", curent_object['mode'])
 *                                 if True == flags.store_array:
 *                                     if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[curent_object['mode']] = []
 * 
 */
                __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 409, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_12 = (__Pyx_PyDict_ContainsTF(__pyx_t_14, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 409, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __pyx_t_13 = (__pyx_t_12 != 0);
                if (__pyx_t_13) {

                  /* "ddb/lexer/lexer.py":410
 *                                 if True == flags.store_array:
 *                                     if curent_object['mode'] not in query_object:
 *                                         query_object[curent_object['mode']] = []             # <<<<<<<<<<<<<<
 * 
 *                                     query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 */
                  __pyx_t_14 = PyList_New(0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 410, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 410, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_2, __pyx_t_14) < 0)) __PYX_ERR(0, 410, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

                  /* "ddb/lexer/lexer.py":409
 *                                 self.info("----------Adding", curent_object['mode'])
 *                                 if True == flags.store_array:
 *                                     if curent_object['mode'] not in query_object:             # <<<<<<<<<<<<<<
 *                                         query_object[curent_object['mode']] = []
 * 
 */
                }

                /* "ddb/lexer/lexer.py":412
 *                                         query_object[curent_object['mode']] = []
 * 
 *                                     query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 *                                 else:
 *                                     if None == flags.parent:
 */
                __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_14); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __pyx_t_14 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_4);
                __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                if (PyDict_SetItem(__pyx_t_14, __pyx_t_4, __pyx_t_10) < 0) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_2, __pyx_t_14); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 412, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

                /* "ddb/lexer/lexer.py":408
 *                                 # only append object after argument collection is done
 *                                 self.info("----------Adding", curent_object['mode'])
 *                                 if True == flags.store_array:             # <<<<<<<<<<<<<<
 *                                     if curent_object['mode'] not in query_object:
 *                                         query_object[curent_object['mode']] = []
 */
                goto __pyx_L62;
              }

              /* "ddb/lexer/lexer.py":414
 *                                     query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                                 else:
 *                                     if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                         #print curent_object
 *                                         query_object[curent_object['mode']] = curent_object['arguments']
 */
              /*else*/ {
                __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 414, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_14);
                __pyx_t_2 = PyObject_RichCompare(Py_None, __pyx_t_14, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 414, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 414, __pyx_L1_error)
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                if (__pyx_t_13) {

                  /* "ddb/lexer/lexer.py":416
 *                                     if None == flags.parent:
 *                                         #print curent_object
 *                                         query_object[curent_object['mode']] = curent_object['arguments']             # <<<<<<<<<<<<<<
 *                                         self.info("NO APPEND")
 * 
 */
                  __pyx_t_2 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 416, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 416, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_2) < 0)) __PYX_ERR(0, 416, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":417
 *                                         #print curent_object
 *                                         query_object[curent_object['mode']] = curent_object['arguments']
 *                                         self.info("NO APPEND")             # <<<<<<<<<<<<<<
 * 
 *                                     else:
 */
                  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 417, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  __pyx_t_10 = NULL;
                  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
                    if (likely(__pyx_t_10)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                      __Pyx_INCREF(__pyx_t_10);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_14, function);
                    }
                  }
                  __pyx_t_2 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_kp_s_NO_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_NO_APPEND);
                  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 417, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":414
 *                                     query_object[curent_object['mode']].append({curent_object['mode']: curent_object['arguments']})
 *                                 else:
 *                                     if None == flags.parent:             # <<<<<<<<<<<<<<
 *                                         #print curent_object
 *                                         query_object[curent_object['mode']] = curent_object['arguments']
 */
                  goto __pyx_L64;
                }

                /* "ddb/lexer/lexer.py":420
 * 
 *                                     else:
 *                                         self.info("APPEND")             # <<<<<<<<<<<<<<
 *                                         if flags.parent not in query_object:
 *                                             query_object[flags.parent]=[]
 */
                /*else*/ {
                  __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 420, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  __pyx_t_10 = NULL;
                  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
                    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
                    if (likely(__pyx_t_10)) {
                      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
                      __Pyx_INCREF(__pyx_t_10);
                      __Pyx_INCREF(function);
                      __Pyx_DECREF_SET(__pyx_t_14, function);
                    }
                  }
                  __pyx_t_2 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_10, __pyx_n_s_APPEND) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_n_s_APPEND);
                  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 420, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":421
 *                                     else:
 *                                         self.info("APPEND")
 *                                         if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                             query_object[flags.parent]=[]
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 421, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_13 = (__Pyx_PyDict_ContainsTF(__pyx_t_2, __pyx_v_query_object, Py_NE)); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 421, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __pyx_t_12 = (__pyx_t_13 != 0);
                  if (__pyx_t_12) {

                    /* "ddb/lexer/lexer.py":422
 *                                         self.info("APPEND")
 *                                         if flags.parent not in query_object:
 *                                             query_object[flags.parent]=[]             # <<<<<<<<<<<<<<
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                                 jump = None
 */
                    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 422, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 422, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_14);
                    if (unlikely(PyDict_SetItem(__pyx_v_query_object, __pyx_t_14, __pyx_t_2) < 0)) __PYX_ERR(0, 422, __pyx_L1_error)
                    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                    /* "ddb/lexer/lexer.py":421
 *                                     else:
 *                                         self.info("APPEND")
 *                                         if flags.parent not in query_object:             # <<<<<<<<<<<<<<
 *                                             query_object[flags.parent]=[]
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 */
                  }

                  /* "ddb/lexer/lexer.py":423
 *                                         if flags.parent not in query_object:
 *                                             query_object[flags.parent]=[]
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})             # <<<<<<<<<<<<<<
 *                                 jump = None
 *                                 if 'jump' in segment:
 */
                  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_flags, __pyx_n_s_parent); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_14 = __Pyx_PyDict_GetItem(__pyx_v_query_object, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_10 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_mode); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_10);
                  __pyx_t_4 = __Pyx_PyDict_GetItem(__pyx_v_curent_object, __pyx_n_s_arguments); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  if (PyDict_SetItem(__pyx_t_2, __pyx_t_10, __pyx_t_4) < 0) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  __pyx_t_11 = __Pyx_PyObject_Append(__pyx_t_14, __pyx_t_2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 423, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                }
                __pyx_L64:;
              }
              __pyx_L62:;

              /* "ddb/lexer/lexer.py":424
 *                                             query_object[flags.parent]=[]
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                                 jump = None             # <<<<<<<<<<<<<<
 *                                 if 'jump' in segment:
 *                                     jump = segment['jump']
 */
              __Pyx_INCREF(Py_None);
              __Pyx_XDECREF_SET(__pyx_v_jump, Py_None);

              /* "ddb/lexer/lexer.py":425
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                                 jump = None
 *                                 if 'jump' in segment:             # <<<<<<<<<<<<<<
 *                                     jump = segment['jump']
 *                                 if None != jump:
 */
              __pyx_t_12 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_jump, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_12 < 0)) __PYX_ERR(0, 425, __pyx_L1_error)
              __pyx_t_13 = (__pyx_t_12 != 0);
              if (__pyx_t_13) {

                /* "ddb/lexer/lexer.py":426
 *                                 jump = None
 *                                 if 'jump' in segment:
 *                                     jump = segment['jump']             # <<<<<<<<<<<<<<
 *                                 if None != jump:
 *                                     tsi = 0
 */
                __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_segment, __pyx_n_s_jump); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 426, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF_SET(__pyx_v_jump, __pyx_t_2);
                __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":425
 *                                         query_object[flags.parent].append({curent_object['mode']: curent_object['arguments']})
 *                                 jump = None
 *                                 if 'jump' in segment:             # <<<<<<<<<<<<<<
 *                                     jump = segment['jump']
 *                                 if None != jump:
 */
              }

              /* "ddb/lexer/lexer.py":427
 *                                 if 'jump' in segment:
 *                                     jump = segment['jump']
 *                                 if None != jump:             # <<<<<<<<<<<<<<
 *                                     tsi = 0
 *                                     for ts in command['segments']:
 */
              __pyx_t_2 = PyObject_RichCompare(Py_None, __pyx_v_jump, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 427, __pyx_L1_error)
              __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 427, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (__pyx_t_13) {

                /* "ddb/lexer/lexer.py":428
 *                                     jump = segment['jump']
 *                                 if None != jump:
 *                                     tsi = 0             # <<<<<<<<<<<<<<
 *                                     for ts in command['segments']:
 *                                         if ts['name'] == jump:
 */
                __Pyx_INCREF(__pyx_int_0);
                __Pyx_XDECREF_SET(__pyx_v_tsi, __pyx_int_0);

                /* "ddb/lexer/lexer.py":429
 *                                 if None != jump:
 *                                     tsi = 0
 *                                     for ts in command['segments']:             # <<<<<<<<<<<<<<
 *                                         if ts['name'] == jump:
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 */
                __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
                  __pyx_t_14 = __pyx_t_2; __Pyx_INCREF(__pyx_t_14); __pyx_t_7 = 0;
                  __pyx_t_16 = NULL;
                } else {
                  __pyx_t_7 = -1; __pyx_t_14 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 429, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_14);
                  __pyx_t_16 = Py_TYPE(__pyx_t_14)->tp_iternext; if (unlikely(!__pyx_t_16)) __PYX_ERR(0, 429, __pyx_L1_error)
                }
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                for (;;) {
                  if (likely(!__pyx_t_16)) {
                    if (likely(PyList_CheckExact(__pyx_t_14))) {
                      if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_14)) break;
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_14, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
                      #else
                      __pyx_t_2 = PySequence_ITEM(__pyx_t_14, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_2);
                      #endif
                    } else {
                      if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_14)) break;
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_14, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 429, __pyx_L1_error)
                      #else
                      __pyx_t_2 = PySequence_ITEM(__pyx_t_14, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 429, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_2);
                      #endif
                    }
                  } else {
                    __pyx_t_2 = __pyx_t_16(__pyx_t_14);
                    if (unlikely(!__pyx_t_2)) {
                      PyObject* exc_type = PyErr_Occurred();
                      if (exc_type) {
                        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                        else __PYX_ERR(0, 429, __pyx_L1_error)
                      }
                      break;
                    }
                    __Pyx_GOTREF(__pyx_t_2);
                  }
                  __Pyx_XDECREF_SET(__pyx_v_ts, __pyx_t_2);
                  __pyx_t_2 = 0;

                  /* "ddb/lexer/lexer.py":430
 *                                     tsi = 0
 *                                     for ts in command['segments']:
 *                                         if ts['name'] == jump:             # <<<<<<<<<<<<<<
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 *                                             segment_index = tsi + 1
 */
                  __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_ts, __pyx_n_s_name); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 430, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_v_jump, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 430, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                  __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 430, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
                  if (__pyx_t_13) {

                    /* "ddb/lexer/lexer.py":431
 *                                     for ts in command['segments']:
 *                                         if ts['name'] == jump:
 *                                             self.info("Jumping from ", segment_index, tsi + 1)             # <<<<<<<<<<<<<<
 *                                             segment_index = tsi + 1
 *                                             break
 */
                    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 431, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_2);
                    __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 431, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_10);
                    __pyx_t_1 = NULL;
                    __pyx_t_5 = 0;
                    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
                      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
                      if (likely(__pyx_t_1)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
                        __Pyx_INCREF(__pyx_t_1);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_2, function);
                        __pyx_t_5 = 1;
                      }
                    }
                    #if CYTHON_FAST_PYCALL
                    if (PyFunction_Check(__pyx_t_2)) {
                      PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_kp_s_Jumping_from, __pyx_v_segment_index, __pyx_t_10};
                      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 431, __pyx_L1_error)
                      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                      __Pyx_GOTREF(__pyx_t_4);
                      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                    } else
                    #endif
                    #if CYTHON_FAST_PYCCALL
                    if (__Pyx_PyFastCFunction_Check(__pyx_t_2)) {
                      PyObject *__pyx_temp[4] = {__pyx_t_1, __pyx_kp_s_Jumping_from, __pyx_v_segment_index, __pyx_t_10};
                      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_2, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 431, __pyx_L1_error)
                      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
                      __Pyx_GOTREF(__pyx_t_4);
                      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                    } else
                    #endif
                    {
                      __pyx_t_15 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 431, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_15);
                      if (__pyx_t_1) {
                        __Pyx_GIVEREF(__pyx_t_1); PyTuple_SET_ITEM(__pyx_t_15, 0, __pyx_t_1); __pyx_t_1 = NULL;
                      }
                      __Pyx_INCREF(__pyx_kp_s_Jumping_from);
                      __Pyx_GIVEREF(__pyx_kp_s_Jumping_from);
                      PyTuple_SET_ITEM(__pyx_t_15, 0+__pyx_t_5, __pyx_kp_s_Jumping_from);
                      __Pyx_INCREF(__pyx_v_segment_index);
                      __Pyx_GIVEREF(__pyx_v_segment_index);
                      PyTuple_SET_ITEM(__pyx_t_15, 1+__pyx_t_5, __pyx_v_segment_index);
                      __Pyx_GIVEREF(__pyx_t_10);
                      PyTuple_SET_ITEM(__pyx_t_15, 2+__pyx_t_5, __pyx_t_10);
                      __pyx_t_10 = 0;
                      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_15, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 431, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_4);
                      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
                    }
                    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

                    /* "ddb/lexer/lexer.py":432
 *                                         if ts['name'] == jump:
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 *                                             segment_index = tsi + 1             # <<<<<<<<<<<<<<
 *                                             break
 *                                         tsi += 1
 */
                    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 432, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_4);
                    __Pyx_DECREF_SET(__pyx_v_segment_index, __pyx_t_4);
                    __pyx_t_4 = 0;

                    /* "ddb/lexer/lexer.py":433
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 *                                             segment_index = tsi + 1
 *                                             break             # <<<<<<<<<<<<<<
 *                                         tsi += 1
 *                                 in_argument = False
 */
                    goto __pyx_L69_break;

                    /* "ddb/lexer/lexer.py":430
 *                                     tsi = 0
 *                                     for ts in command['segments']:
 *                                         if ts['name'] == jump:             # <<<<<<<<<<<<<<
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 *                                             segment_index = tsi + 1
 */
                  }

                  /* "ddb/lexer/lexer.py":434
 *                                             segment_index = tsi + 1
 *                                             break
 *                                         tsi += 1             # <<<<<<<<<<<<<<
 *                                 in_argument = False
 *                             else:
 */
                  __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_v_tsi, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 434, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_4);
                  __Pyx_DECREF_SET(__pyx_v_tsi, __pyx_t_4);
                  __pyx_t_4 = 0;

                  /* "ddb/lexer/lexer.py":429
 *                                 if None != jump:
 *                                     tsi = 0
 *                                     for ts in command['segments']:             # <<<<<<<<<<<<<<
 *                                         if ts['name'] == jump:
 *                                             self.info("Jumping from ", segment_index, tsi + 1)
 */
                }
                __pyx_L69_break:;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

                /* "ddb/lexer/lexer.py":427
 *                                 if 'jump' in segment:
 *                                     jump = segment['jump']
 *                                 if None != jump:             # <<<<<<<<<<<<<<
 *                                     tsi = 0
 *                                     for ts in command['segments']:
 */
              }

              /* "ddb/lexer/lexer.py":435
 *                                             break
 *                                         tsi += 1
 *                                 in_argument = False             # <<<<<<<<<<<<<<
 *                             else:
 *                                 self.info("------more list")
 */
              __pyx_v_in_argument = 0;

              /* "ddb/lexer/lexer.py":404
 *                             # if its not exit
 *                             self.info("----", tokens[token_index]['data'])
 *                             if tokens[token_index]['data'] != ',':             # <<<<<<<<<<<<<<
 *                                 self.info("---not list")
 *                                 # only append object after argument collection is done
 */
              goto __pyx_L61;
            }

            /* "ddb/lexer/lexer.py":437
 *                                 in_argument = False
 *                             else:
 *                                 self.info("------more list")             # <<<<<<<<<<<<<<
 *                                 token_index += 1
 * 
 */
            /*else*/ {
              __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 437, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_4);
              __pyx_t_2 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
                __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
                if (likely(__pyx_t_2)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
                  __Pyx_INCREF(__pyx_t_2);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_4, function);
                }
              }
              __pyx_t_14 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, __pyx_kp_s_more_list) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_s_more_list);
              __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
              if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 437, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

              /* "ddb/lexer/lexer.py":438
 *                             else:
 *                                 self.info("------more list")
 *                                 token_index += 1             # <<<<<<<<<<<<<<
 * 
 *         # This is where we exit if we reached the end of processing with a full length
 */
              __pyx_t_14 = __Pyx_PyInt_AddObjC(__pyx_v_token_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 438, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_14);
              __Pyx_DECREF_SET(__pyx_v_token_index, __pyx_t_14);
              __pyx_t_14 = 0;
            }
            __pyx_L61:;

            /* "ddb/lexer/lexer.py":400
 * 
 *                         # look ahead to see if its a list ","
 *                         if len(tokens) > token_index:             # <<<<<<<<<<<<<<
 *                             self.info("--looking ahead")
 *                             # if its not exit
 */
          }
        }
        __pyx_L41:;
      }
    }
    __pyx_L10_break:;
  }

  /* "ddb/lexer/lexer.py":442
 *         # This is where we exit if we reached the end of processing with a full length
 *         #print token_index,len(tokens)
 *         self.info(segment_index, token_index, len(tokens))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 442, __pyx_L1_error)
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_15 = NULL;
  __pyx_t_5 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_15)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_15);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_5 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[4] = {__pyx_t_15, __pyx_v_segment_index, __pyx_v_token_index, __pyx_t_2};
    __pyx_t_14 = __Pyx_PyFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_4)) {
    PyObject *__pyx_temp[4] = {__pyx_t_15, __pyx_v_segment_index, __pyx_v_token_index, __pyx_t_2};
    __pyx_t_14 = __Pyx_PyCFunction_FastCall(__pyx_t_4, __pyx_temp+1-__pyx_t_5, 3+__pyx_t_5); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else
  #endif
  {
    __pyx_t_10 = PyTuple_New(3+__pyx_t_5); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (__pyx_t_15) {
      __Pyx_GIVEREF(__pyx_t_15); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_15); __pyx_t_15 = NULL;
    }
    __Pyx_INCREF(__pyx_v_segment_index);
    __Pyx_GIVEREF(__pyx_v_segment_index);
    PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_5, __pyx_v_segment_index);
    __Pyx_INCREF(__pyx_v_token_index);
    __Pyx_GIVEREF(__pyx_v_token_index);
    PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_5, __pyx_v_token_index);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_10, 2+__pyx_t_5, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_14 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_10, NULL); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 442, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "ddb/lexer/lexer.py":445
 * 
 * 
 *         self.info(query_object)             # <<<<<<<<<<<<<<
 *         if token_index == len(tokens):
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_14 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_10, __pyx_v_query_object) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_query_object);
  __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "ddb/lexer/lexer.py":446
 * 
 *         self.info(query_object)
 *         if token_index == len(tokens):             # <<<<<<<<<<<<<<
 * 
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 446, __pyx_L1_error)
  __pyx_t_14 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_token_index, __pyx_t_14, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
  __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__pyx_t_13) {

    /* "ddb/lexer/lexer.py":448
 *         if token_index == len(tokens):
 * 
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)             # <<<<<<<<<<<<<<
 *             if  result['success']:
 *                 self.info("SUCCESSFULL MATCH")
 */
    __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_validate); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 448, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_14);
    __pyx_t_10 = NULL;
    __pyx_t_5 = 0;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_14);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_14, function);
        __pyx_t_5 = 1;
      }
    }
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(__pyx_t_14)) {
      PyObject *__pyx_temp[9] = {__pyx_t_10, __pyx_v_curent_object, __pyx_v_tokens, __pyx_v_token_index, __pyx_v_segment, __pyx_v_command, __pyx_v_segment_index, __pyx_v_query_object, __pyx_v_query_mode};
      __pyx_t_4 = __Pyx_PyFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_5, 8+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(__pyx_t_14)) {
      PyObject *__pyx_temp[9] = {__pyx_t_10, __pyx_v_curent_object, __pyx_v_tokens, __pyx_v_token_index, __pyx_v_segment, __pyx_v_command, __pyx_v_segment_index, __pyx_v_query_object, __pyx_v_query_mode};
      __pyx_t_4 = __Pyx_PyCFunction_FastCall(__pyx_t_14, __pyx_temp+1-__pyx_t_5, 8+__pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_GOTREF(__pyx_t_4);
    } else
    #endif
    {
      __pyx_t_2 = PyTuple_New(8+__pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (__pyx_t_10) {
        __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10); __pyx_t_10 = NULL;
      }
      __Pyx_INCREF(__pyx_v_curent_object);
      __Pyx_GIVEREF(__pyx_v_curent_object);
      PyTuple_SET_ITEM(__pyx_t_2, 0+__pyx_t_5, __pyx_v_curent_object);
      __Pyx_INCREF(__pyx_v_tokens);
      __Pyx_GIVEREF(__pyx_v_tokens);
      PyTuple_SET_ITEM(__pyx_t_2, 1+__pyx_t_5, __pyx_v_tokens);
      __Pyx_INCREF(__pyx_v_token_index);
      __Pyx_GIVEREF(__pyx_v_token_index);
      PyTuple_SET_ITEM(__pyx_t_2, 2+__pyx_t_5, __pyx_v_token_index);
      __Pyx_INCREF(__pyx_v_segment);
      __Pyx_GIVEREF(__pyx_v_segment);
      PyTuple_SET_ITEM(__pyx_t_2, 3+__pyx_t_5, __pyx_v_segment);
      __Pyx_INCREF(__pyx_v_command);
      __Pyx_GIVEREF(__pyx_v_command);
      PyTuple_SET_ITEM(__pyx_t_2, 4+__pyx_t_5, __pyx_v_command);
      __Pyx_INCREF(__pyx_v_segment_index);
      __Pyx_GIVEREF(__pyx_v_segment_index);
      PyTuple_SET_ITEM(__pyx_t_2, 5+__pyx_t_5, __pyx_v_segment_index);
      __Pyx_INCREF(__pyx_v_query_object);
      __Pyx_GIVEREF(__pyx_v_query_object);
      PyTuple_SET_ITEM(__pyx_t_2, 6+__pyx_t_5, __pyx_v_query_object);
      __Pyx_INCREF(__pyx_v_query_mode);
      __Pyx_GIVEREF(__pyx_v_query_mode);
      PyTuple_SET_ITEM(__pyx_t_2, 7+__pyx_t_5, __pyx_v_query_mode);
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_14, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __pyx_v_result = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "ddb/lexer/lexer.py":449
 * 
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)
 *             if  result['success']:             # <<<<<<<<<<<<<<
 *                 self.info("SUCCESSFULL MATCH")
 *                 return {'success':True,'results':result,'match':token_index,'msg':None}
 */
    __pyx_t_4 = __Pyx_PyObject_Dict_GetItem(__pyx_v_result, __pyx_n_s_success); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 449, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_13) {

      /* "ddb/lexer/lexer.py":450
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)
 *             if  result['success']:
 *                 self.info("SUCCESSFULL MATCH")             # <<<<<<<<<<<<<<
 *                 return {'success':True,'results':result,'match':token_index,'msg':None}
 *             else:
 */
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_2, __pyx_kp_s_SUCCESSFULL_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_SUCCESSFULL_MATCH);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 450, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "ddb/lexer/lexer.py":451
 *             if  result['success']:
 *                 self.info("SUCCESSFULL MATCH")
 *                 return {'success':True,'results':result,'match':token_index,'msg':None}             # <<<<<<<<<<<<<<
 *             else:
 *                 self.info("FAILED MATCH")
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 451, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_success, Py_True) < 0) __PYX_ERR(0, 451, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_results, __pyx_v_result) < 0) __PYX_ERR(0, 451, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_match, __pyx_v_token_index) < 0) __PYX_ERR(0, 451, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_msg, Py_None) < 0) __PYX_ERR(0, 451, __pyx_L1_error)
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":449
 * 
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)
 *             if  result['success']:             # <<<<<<<<<<<<<<
 *                 self.info("SUCCESSFULL MATCH")
 *                 return {'success':True,'results':result,'match':token_index,'msg':None}
 */
    }

    /* "ddb/lexer/lexer.py":453
 *                 return {'success':True,'results':result,'match':token_index,'msg':None}
 *             else:
 *                 self.info("FAILED MATCH")             # <<<<<<<<<<<<<<
 *                 return {'success':None,'results':None,'match':token_index,'msg':result['msg']}
 * 
 */
    /*else*/ {
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_14);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_14);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_14, function);
        }
      }
      __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_14, __pyx_t_2, __pyx_kp_s_FAILED_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_14, __pyx_kp_s_FAILED_MATCH);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 453, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "ddb/lexer/lexer.py":454
 *             else:
 *                 self.info("FAILED MATCH")
 *                 return {'success':None,'results':None,'match':token_index,'msg':result['msg']}             # <<<<<<<<<<<<<<
 * 
 *         query_err=[]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_results, Py_None) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_match, __pyx_v_token_index) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
      __pyx_t_14 = __Pyx_PyObject_Dict_GetItem(__pyx_v_result, __pyx_n_s_msg); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_msg, __pyx_t_14) < 0) __PYX_ERR(0, 454, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __pyx_r = __pyx_t_4;
      __pyx_t_4 = 0;
      goto __pyx_L0;
    }

    /* "ddb/lexer/lexer.py":446
 * 
 *         self.info(query_object)
 *         if token_index == len(tokens):             # <<<<<<<<<<<<<<
 * 
 *             result=self.validate(curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode)
 */
  }

  /* "ddb/lexer/lexer.py":456
 *                 return {'success':None,'results':None,'match':token_index,'msg':result['msg']}
 * 
 *         query_err=[]             # <<<<<<<<<<<<<<
 *         for index in range(0,len(tokens)):
 *             if index==token_index:
 */
  __pyx_t_4 = PyList_New(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_query_err = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "ddb/lexer/lexer.py":457
 * 
 *         query_err=[]
 *         for index in range(0,len(tokens)):             # <<<<<<<<<<<<<<
 *             if index==token_index:
 *                 query_err.append(" >>> ")
 */
  __pyx_t_7 = PyObject_Length(__pyx_v_tokens); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 457, __pyx_L1_error)
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_index = __pyx_t_9;

    /* "ddb/lexer/lexer.py":458
 *         query_err=[]
 *         for index in range(0,len(tokens)):
 *             if index==token_index:             # <<<<<<<<<<<<<<
 *                 query_err.append(" >>> ")
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 */
    __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_14 = PyObject_RichCompare(__pyx_t_4, __pyx_v_token_index, Py_EQ); __Pyx_XGOTREF(__pyx_t_14); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 458, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_14); if (unlikely(__pyx_t_13 < 0)) __PYX_ERR(0, 458, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    if (__pyx_t_13) {

      /* "ddb/lexer/lexer.py":459
 *         for index in range(0,len(tokens)):
 *             if index==token_index:
 *                 query_err.append(" >>> ")             # <<<<<<<<<<<<<<
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 *                 query_err.append(" <<< ")
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_query_err, __pyx_kp_s__25); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 459, __pyx_L1_error)

      /* "ddb/lexer/lexer.py":460
 *             if index==token_index:
 *                 query_err.append(" >>> ")
 *                 query_err.append('{0}'.format(tokens[index]['data']))             # <<<<<<<<<<<<<<
 *                 query_err.append(" <<< ")
 *             else:
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_tokens, __pyx_v_index, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_data); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_14 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_10);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_query_err, __pyx_t_14); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 460, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

      /* "ddb/lexer/lexer.py":461
 *                 query_err.append(" >>> ")
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 *                 query_err.append(" <<< ")             # <<<<<<<<<<<<<<
 *             else:
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 */
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_query_err, __pyx_kp_s__26); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 461, __pyx_L1_error)

      /* "ddb/lexer/lexer.py":458
 *         query_err=[]
 *         for index in range(0,len(tokens)):
 *             if index==token_index:             # <<<<<<<<<<<<<<
 *                 query_err.append(" >>> ")
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 */
      goto __pyx_L75;
    }

    /* "ddb/lexer/lexer.py":463
 *                 query_err.append(" <<< ")
 *             else:
 *                 query_err.append('{0}'.format(tokens[index]['data']))             # <<<<<<<<<<<<<<
 *         query_err.append("\n Syntax error near word {0}".format(token_index))
 *         err_msg=" ".join(query_err)
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_10 = __Pyx_GetItemInt(__pyx_v_tokens, __pyx_v_index, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_t_10, __pyx_n_s_data); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_10 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_4);
        if (likely(__pyx_t_10)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_10);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_4, function);
        }
      }
      __pyx_t_14 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_10, __pyx_t_2) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2);
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_query_err, __pyx_t_14); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 463, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    }
    __pyx_L75:;
  }

  /* "ddb/lexer/lexer.py":464
 *             else:
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 *         query_err.append("\n Syntax error near word {0}".format(token_index))             # <<<<<<<<<<<<<<
 *         err_msg=" ".join(query_err)
 *         self.info("FAILED MATCH")
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_Syntax_error_near_word_0, __pyx_n_s_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_14 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, __pyx_v_token_index) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_v_token_index);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_11 = __Pyx_PyList_Append(__pyx_v_query_err, __pyx_t_14); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(0, 464, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "ddb/lexer/lexer.py":465
 *                 query_err.append('{0}'.format(tokens[index]['data']))
 *         query_err.append("\n Syntax error near word {0}".format(token_index))
 *         err_msg=" ".join(query_err)             # <<<<<<<<<<<<<<
 *         self.info("FAILED MATCH")
 *         return {'success':None,'results':None,'match':token_index,'msg':err_msg}
 */
  __pyx_t_14 = __Pyx_PyString_Join(__pyx_kp_s__20, __pyx_v_query_err); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __pyx_v_err_msg = ((PyObject*)__pyx_t_14);
  __pyx_t_14 = 0;

  /* "ddb/lexer/lexer.py":466
 *         query_err.append("\n Syntax error near word {0}".format(token_index))
 *         err_msg=" ".join(query_err)
 *         self.info("FAILED MATCH")             # <<<<<<<<<<<<<<
 *         return {'success':None,'results':None,'match':token_index,'msg':err_msg}
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_14 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_2, __pyx_kp_s_FAILED_MATCH) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_s_FAILED_MATCH);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;

  /* "ddb/lexer/lexer.py":467
 *         err_msg=" ".join(query_err)
 *         self.info("FAILED MATCH")
 *         return {'success':None,'results':None,'match':token_index,'msg':err_msg}             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_14 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_14)) __PYX_ERR(0, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_14);
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_results, Py_None) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_match, __pyx_v_token_index) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_14, __pyx_n_s_msg, __pyx_v_err_msg) < 0) __PYX_ERR(0, 467, __pyx_L1_error)
  __pyx_r = __pyx_t_14;
  __pyx_t_14 = 0;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":232
 * 
 * 
 *     def test_syntax(self,command,tokens):             # <<<<<<<<<<<<<<
 *         query_object = {}
 *         token_index = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.test_syntax", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_query_object);
  __Pyx_XDECREF(__pyx_v_token_index);
  __Pyx_XDECREF(__pyx_v_segment_index);
  __Pyx_XDECREF(__pyx_v_query_mode);
  __Pyx_XDECREF(__pyx_v_curent_object);
  __Pyx_XDECREF(__pyx_v_segment);
  __Pyx_XDECREF(__pyx_v_token_list);
  __Pyx_XDECREF(__pyx_v_base_argument);
  __Pyx_XDECREF(__pyx_v_argument_index);
  __Pyx_XDECREF(__pyx_v_flags);
  __Pyx_XDECREF(__pyx_v_depends_on);
  __Pyx_XDECREF(__pyx_v_dependency_found);
  __Pyx_XDECREF(__pyx_v_arguments);
  __Pyx_XDECREF(__pyx_v_match);
  __Pyx_XDECREF(__pyx_v_partial);
  __Pyx_XDECREF(__pyx_v_signature_compare);
  __Pyx_XDECREF(__pyx_v_haystack);
  __Pyx_XDECREF(__pyx_v_signature);
  __Pyx_XDECREF(__pyx_v_var_name);
  __Pyx_XDECREF(__pyx_v_argument);
  __Pyx_XDECREF(__pyx_v_word);
  __Pyx_XDECREF(__pyx_v_computed);
  __Pyx_XDECREF(__pyx_v_jump);
  __Pyx_XDECREF(__pyx_v_tsi);
  __Pyx_XDECREF(__pyx_v_ts);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_query_err);
  __Pyx_XDECREF(__pyx_v_err_msg);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":474
 * 
 *     # this is crappy, I'm just breaking up a giant function. Will clean later...
 *     def validate(self,curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode):             # <<<<<<<<<<<<<<
 *         self.info(curent_object)
 *         # so we have run out of text to match and everything is good so far
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_11validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_11validate = {"validate", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_11validate, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_11validate(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_curent_object = 0;
  CYTHON_UNUSED PyObject *__pyx_v_tokens = 0;
  CYTHON_UNUSED PyObject *__pyx_v_token_index = 0;
  PyObject *__pyx_v_segment = 0;
  PyObject *__pyx_v_command = 0;
  PyObject *__pyx_v_segment_index = 0;
  PyObject *__pyx_v_query_object = 0;
  PyObject *__pyx_v_query_mode = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("validate (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_curent_object,&__pyx_n_s_tokens,&__pyx_n_s_token_index,&__pyx_n_s_segment,&__pyx_n_s_command,&__pyx_n_s_segment_index,&__pyx_n_s_query_object,&__pyx_n_s_query_mode,0};
    PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  9: values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_curent_object)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 1); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_tokens)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 2); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_token_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 3); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (likely((values[4] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_segment)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 4); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (likely((values[5] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_command)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 5); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (likely((values[6] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_segment_index)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 6); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (likely((values[7] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_query_object)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 7); __PYX_ERR(0, 474, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (likely((values[8] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_query_mode)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, 8); __PYX_ERR(0, 474, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "validate") < 0)) __PYX_ERR(0, 474, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 9) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
      values[5] = PyTuple_GET_ITEM(__pyx_args, 5);
      values[6] = PyTuple_GET_ITEM(__pyx_args, 6);
      values[7] = PyTuple_GET_ITEM(__pyx_args, 7);
      values[8] = PyTuple_GET_ITEM(__pyx_args, 8);
    }
    __pyx_v_self = values[0];
    __pyx_v_curent_object = values[1];
    __pyx_v_tokens = values[2];
    __pyx_v_token_index = values[3];
    __pyx_v_segment = values[4];
    __pyx_v_command = values[5];
    __pyx_v_segment_index = values[6];
    __pyx_v_query_object = values[7];
    __pyx_v_query_mode = values[8];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("validate", 1, 9, 9, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 474, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_10validate(__pyx_self, __pyx_v_self, __pyx_v_curent_object, __pyx_v_tokens, __pyx_v_token_index, __pyx_v_segment, __pyx_v_command, __pyx_v_segment_index, __pyx_v_query_object, __pyx_v_query_mode);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_10validate(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_curent_object, CYTHON_UNUSED PyObject *__pyx_v_tokens, CYTHON_UNUSED PyObject *__pyx_v_token_index, PyObject *__pyx_v_segment, PyObject *__pyx_v_command, PyObject *__pyx_v_segment_index, PyObject *__pyx_v_query_object, PyObject *__pyx_v_query_mode) {
  int __pyx_v_bad;
  PyObject *__pyx_v_t = NULL;
  PyObject *__pyx_v_msg = NULL;
  PyObject *__pyx_v_node = NULL;
  int __pyx_v_valid_function_name;
  int __pyx_v_is_function;
  PyObject *__pyx_v_f = NULL;
  PyObject *__pyx_v_argindex = NULL;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_sql_object = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *(*__pyx_t_8)(PyObject *);
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *(*__pyx_t_12)(PyObject *);
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  PyObject *(*__pyx_t_15)(PyObject *);
  PyObject *__pyx_t_16 = NULL;
  __Pyx_RefNannySetupContext("validate", 0);

  /* "ddb/lexer/lexer.py":475
 *     # this is crappy, I'm just breaking up a giant function. Will clean later...
 *     def validate(self,curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode):
 *         self.info(curent_object)             # <<<<<<<<<<<<<<
 *         # so we have run out of text to match and everything is good so far
 *         self.info("############################think its a match")
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_v_curent_object) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_curent_object);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":477
 *         self.info(curent_object)
 *         # so we have run out of text to match and everything is good so far
 *         self.info("############################think its a match")             # <<<<<<<<<<<<<<
 * 
 *         if 'arguments' not in curent_object and 'arguments' in segment:
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_kp_s_think_its_a_match) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s_think_its_a_match);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 477, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":479
 *         self.info("############################think its a match")
 * 
 *         if 'arguments' not in curent_object and 'arguments' in segment:             # <<<<<<<<<<<<<<
 *             self.info("Missing argument in last element")
 *             bad = True
 */
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_arguments, __pyx_v_curent_object, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 479, __pyx_L1_error)
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {
  } else {
    __pyx_t_4 = __pyx_t_6;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_6 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_arguments, __pyx_v_segment, Py_EQ)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 479, __pyx_L1_error)
  __pyx_t_5 = (__pyx_t_6 != 0);
  __pyx_t_4 = __pyx_t_5;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_4) {

    /* "ddb/lexer/lexer.py":480
 * 
 *         if 'arguments' not in curent_object and 'arguments' in segment:
 *             self.info("Missing argument in last element")             # <<<<<<<<<<<<<<
 *             bad = True
 *             return False
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_3, __pyx_kp_s_Missing_argument_in_last_element) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_s_Missing_argument_in_last_element);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 480, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":481
 *         if 'arguments' not in curent_object and 'arguments' in segment:
 *             self.info("Missing argument in last element")
 *             bad = True             # <<<<<<<<<<<<<<
 *             return False
 * 
 */
    __pyx_v_bad = 1;

    /* "ddb/lexer/lexer.py":482
 *             self.info("Missing argument in last element")
 *             bad = True
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         # lets make sure the rest are optional
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;

    /* "ddb/lexer/lexer.py":479
 *         self.info("############################think its a match")
 * 
 *         if 'arguments' not in curent_object and 'arguments' in segment:             # <<<<<<<<<<<<<<
 *             self.info("Missing argument in last element")
 *             bad = True
 */
  }

  /* "ddb/lexer/lexer.py":485
 * 
 *         # lets make sure the rest are optional
 *         if len(command['segments']) >= segment_index:             # <<<<<<<<<<<<<<
 *             self.info("still checking")
 *             bad = False
 */
  __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_1, __pyx_v_segment_index, Py_GE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 485, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_4) {

    /* "ddb/lexer/lexer.py":486
 *         # lets make sure the rest are optional
 *         if len(command['segments']) >= segment_index:
 *             self.info("still checking")             # <<<<<<<<<<<<<<
 *             bad = False
 *             for t in range(segment_index, len(command['segments'])):
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_3)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_3, __pyx_kp_s_still_checking) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_kp_s_still_checking);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 486, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":487
 *         if len(command['segments']) >= segment_index:
 *             self.info("still checking")
 *             bad = False             # <<<<<<<<<<<<<<
 *             for t in range(segment_index, len(command['segments'])):
 *                 if 'optional' not in command['segments'][t]:
 */
    __pyx_v_bad = 0;

    /* "ddb/lexer/lexer.py":488
 *             self.info("still checking")
 *             bad = False
 *             for t in range(segment_index, len(command['segments'])):             # <<<<<<<<<<<<<<
 *                 if 'optional' not in command['segments'][t]:
 *                     bad = True
 */
    __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyObject_Length(__pyx_t_2); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_segment_index);
    __Pyx_GIVEREF(__pyx_v_segment_index);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_segment_index);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_7 = 0;
      __pyx_t_8 = NULL;
    } else {
      __pyx_t_7 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 488, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 488, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (likely(!__pyx_t_8)) {
        if (likely(PyList_CheckExact(__pyx_t_1))) {
          if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 488, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        } else {
          if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_7); __Pyx_INCREF(__pyx_t_2); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 488, __pyx_L1_error)
          #else
          __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 488, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          #endif
        }
      } else {
        __pyx_t_2 = __pyx_t_8(__pyx_t_1);
        if (unlikely(!__pyx_t_2)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else __PYX_ERR(0, 488, __pyx_L1_error)
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":489
 *             bad = False
 *             for t in range(segment_index, len(command['segments'])):
 *                 if 'optional' not in command['segments'][t]:             # <<<<<<<<<<<<<<
 *                     bad = True
 *                     msg="Non optional components missing from query"
 */
      __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_2, __pyx_v_t); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_optional, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 489, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = (__pyx_t_4 != 0);
      if (__pyx_t_5) {

        /* "ddb/lexer/lexer.py":490
 *             for t in range(segment_index, len(command['segments'])):
 *                 if 'optional' not in command['segments'][t]:
 *                     bad = True             # <<<<<<<<<<<<<<
 *                     msg="Non optional components missing from query"
 *                     return {'success':None,'msg':msg}
 */
        __pyx_v_bad = 1;

        /* "ddb/lexer/lexer.py":491
 *                 if 'optional' not in command['segments'][t]:
 *                     bad = True
 *                     msg="Non optional components missing from query"             # <<<<<<<<<<<<<<
 *                     return {'success':None,'msg':msg}
 *                 else:
 */
        __Pyx_INCREF(__pyx_kp_s_Non_optional_components_missing);
        __pyx_v_msg = __pyx_kp_s_Non_optional_components_missing;

        /* "ddb/lexer/lexer.py":492
 *                     bad = True
 *                     msg="Non optional components missing from query"
 *                     return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 *                 else:
 *                     if not command['segments'][t]['optional']:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 492, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 492, __pyx_L1_error)
        if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 492, __pyx_L1_error)
        __pyx_r = __pyx_t_3;
        __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;

        /* "ddb/lexer/lexer.py":489
 *             bad = False
 *             for t in range(segment_index, len(command['segments'])):
 *                 if 'optional' not in command['segments'][t]:             # <<<<<<<<<<<<<<
 *                     bad = True
 *                     msg="Non optional components missing from query"
 */
      }

      /* "ddb/lexer/lexer.py":494
 *                     return {'success':None,'msg':msg}
 *                 else:
 *                     if not command['segments'][t]['optional']:             # <<<<<<<<<<<<<<
 *                         bad = True
 *                         msg="Non optional components missing from query"
 */
      /*else*/ {
        __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_v_command, __pyx_n_s_segments); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 494, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_v_t); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 494, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Dict_GetItem(__pyx_t_2, __pyx_n_s_optional); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 494, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 494, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_4 = ((!__pyx_t_5) != 0);
        if (__pyx_t_4) {

          /* "ddb/lexer/lexer.py":495
 *                 else:
 *                     if not command['segments'][t]['optional']:
 *                         bad = True             # <<<<<<<<<<<<<<
 *                         msg="Non optional components missing from query"
 *                         return {'success':None,'msg':msg}
 */
          __pyx_v_bad = 1;

          /* "ddb/lexer/lexer.py":496
 *                     if not command['segments'][t]['optional']:
 *                         bad = True
 *                         msg="Non optional components missing from query"             # <<<<<<<<<<<<<<
 *                         return {'success':None,'msg':msg}
 * 
 */
          __Pyx_INCREF(__pyx_kp_s_Non_optional_components_missing);
          __pyx_v_msg = __pyx_kp_s_Non_optional_components_missing;

          /* "ddb/lexer/lexer.py":497
 *                         bad = True
 *                         msg="Non optional components missing from query"
 *                         return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 * 
 * 
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 497, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 497, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 497, __pyx_L1_error)
          __pyx_r = __pyx_t_3;
          __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          goto __pyx_L0;

          /* "ddb/lexer/lexer.py":494
 *                     return {'success':None,'msg':msg}
 *                 else:
 *                     if not command['segments'][t]['optional']:             # <<<<<<<<<<<<<<
 *                         bad = True
 *                         msg="Non optional components missing from query"
 */
        }
      }

      /* "ddb/lexer/lexer.py":488
 *             self.info("still checking")
 *             bad = False
 *             for t in range(segment_index, len(command['segments'])):             # <<<<<<<<<<<<<<
 *                 if 'optional' not in command['segments'][t]:
 *                     bad = True
 */
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":500
 * 
 * 
 *             if True == bad:             # <<<<<<<<<<<<<<
 *                 msg="Not successful. required arguments missing"
 *                 self.info(msg)
 */
    __pyx_t_4 = ((1 == __pyx_v_bad) != 0);
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":501
 * 
 *             if True == bad:
 *                 msg="Not successful. required arguments missing"             # <<<<<<<<<<<<<<
 *                 self.info(msg)
 *                 return {'success':None,'msg':msg}
 */
      __Pyx_INCREF(__pyx_kp_s_Not_successful_required_argument);
      __pyx_v_msg = __pyx_kp_s_Not_successful_required_argument;

      /* "ddb/lexer/lexer.py":502
 *             if True == bad:
 *                 msg="Not successful. required arguments missing"
 *                 self.info(msg)             # <<<<<<<<<<<<<<
 *                 return {'success':None,'msg':msg}
 * 
 */
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_2, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_msg);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "ddb/lexer/lexer.py":503
 *                 msg="Not successful. required arguments missing"
 *                 self.info(msg)
 *                 return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 * 
 *         self.info("Query object", query_object)
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 503, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 503, __pyx_L1_error)
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":500
 * 
 * 
 *             if True == bad:             # <<<<<<<<<<<<<<
 *                 msg="Not successful. required arguments missing"
 *                 self.info(msg)
 */
    }

    /* "ddb/lexer/lexer.py":485
 * 
 *         # lets make sure the rest are optional
 *         if len(command['segments']) >= segment_index:             # <<<<<<<<<<<<<<
 *             self.info("still checking")
 *             bad = False
 */
  }

  /* "ddb/lexer/lexer.py":505
 *                 return {'success':None,'msg':msg}
 * 
 *         self.info("Query object", query_object)             # <<<<<<<<<<<<<<
 *         if query_mode == 'select':
 *             # check to make sure functions are valid
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = NULL;
  __pyx_t_9 = 0;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_9 = 1;
    }
  }
  #if CYTHON_FAST_PYCALL
  if (PyFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_s_Query_object, __pyx_v_query_object};
    __pyx_t_1 = __Pyx_PyFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  #if CYTHON_FAST_PYCCALL
  if (__Pyx_PyFastCFunction_Check(__pyx_t_3)) {
    PyObject *__pyx_temp[3] = {__pyx_t_2, __pyx_kp_s_Query_object, __pyx_v_query_object};
    __pyx_t_1 = __Pyx_PyCFunction_FastCall(__pyx_t_3, __pyx_temp+1-__pyx_t_9, 2+__pyx_t_9); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else
  #endif
  {
    __pyx_t_10 = PyTuple_New(2+__pyx_t_9); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    if (__pyx_t_2) {
      __Pyx_GIVEREF(__pyx_t_2); PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_2); __pyx_t_2 = NULL;
    }
    __Pyx_INCREF(__pyx_kp_s_Query_object);
    __Pyx_GIVEREF(__pyx_kp_s_Query_object);
    PyTuple_SET_ITEM(__pyx_t_10, 0+__pyx_t_9, __pyx_kp_s_Query_object);
    __Pyx_INCREF(__pyx_v_query_object);
    __Pyx_GIVEREF(__pyx_v_query_object);
    PyTuple_SET_ITEM(__pyx_t_10, 1+__pyx_t_9, __pyx_v_query_object);
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_10, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":506
 * 
 *         self.info("Query object", query_object)
 *         if query_mode == 'select':             # <<<<<<<<<<<<<<
 *             # check to make sure functions are valid
 *             self.info("Validating Select Functions")
 */
  __pyx_t_4 = (__Pyx_PyString_Equals(__pyx_v_query_mode, __pyx_n_s_select, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 506, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "ddb/lexer/lexer.py":508
 *         if query_mode == 'select':
 *             # check to make sure functions are valid
 *             self.info("Validating Select Functions")             # <<<<<<<<<<<<<<
 *             if 'columns' in query_object:
 *                 for node in query_object['columns']:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_10, __pyx_kp_s_Validating_Select_Functions) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_kp_s_Validating_Select_Functions);
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "ddb/lexer/lexer.py":509
 *             # check to make sure functions are valid
 *             self.info("Validating Select Functions")
 *             if 'columns' in query_object:             # <<<<<<<<<<<<<<
 *                 for node in query_object['columns']:
 *                     valid_function_name = False
 */
    __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_columns, __pyx_v_query_object, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 509, __pyx_L1_error)
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (__pyx_t_5) {

      /* "ddb/lexer/lexer.py":510
 *             self.info("Validating Select Functions")
 *             if 'columns' in query_object:
 *                 for node in query_object['columns']:             # <<<<<<<<<<<<<<
 *                     valid_function_name = False
 *                     is_function = False
 */
      __pyx_t_1 = __Pyx_PyObject_Dict_GetItem(__pyx_v_query_object, __pyx_n_s_columns); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (likely(PyList_CheckExact(__pyx_t_1)) || PyTuple_CheckExact(__pyx_t_1)) {
        __pyx_t_3 = __pyx_t_1; __Pyx_INCREF(__pyx_t_3); __pyx_t_7 = 0;
        __pyx_t_8 = NULL;
      } else {
        __pyx_t_7 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 510, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 510, __pyx_L1_error)
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (likely(!__pyx_t_8)) {
          if (likely(PyList_CheckExact(__pyx_t_3))) {
            if (__pyx_t_7 >= PyList_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 510, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          } else {
            if (__pyx_t_7 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
            #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_7); __Pyx_INCREF(__pyx_t_1); __pyx_t_7++; if (unlikely(0 < 0)) __PYX_ERR(0, 510, __pyx_L1_error)
            #else
            __pyx_t_1 = PySequence_ITEM(__pyx_t_3, __pyx_t_7); __pyx_t_7++; if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 510, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            #endif
          }
        } else {
          __pyx_t_1 = __pyx_t_8(__pyx_t_3);
          if (unlikely(!__pyx_t_1)) {
            PyObject* exc_type = PyErr_Occurred();
            if (exc_type) {
              if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
              else __PYX_ERR(0, 510, __pyx_L1_error)
            }
            break;
          }
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_node, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "ddb/lexer/lexer.py":511
 *             if 'columns' in query_object:
 *                 for node in query_object['columns']:
 *                     valid_function_name = False             # <<<<<<<<<<<<<<
 *                     is_function = False
 *                     if 'function' in node:
 */
        __pyx_v_valid_function_name = 0;

        /* "ddb/lexer/lexer.py":512
 *                 for node in query_object['columns']:
 *                     valid_function_name = False
 *                     is_function = False             # <<<<<<<<<<<<<<
 *                     if 'function' in node:
 *                         is_function = True
 */
        __pyx_v_is_function = 0;

        /* "ddb/lexer/lexer.py":513
 *                     valid_function_name = False
 *                     is_function = False
 *                     if 'function' in node:             # <<<<<<<<<<<<<<
 *                         is_function = True
 *                         self.info("It's a function!")
 */
        __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_function, __pyx_v_node, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 513, __pyx_L1_error)
        __pyx_t_4 = (__pyx_t_5 != 0);
        if (__pyx_t_4) {

          /* "ddb/lexer/lexer.py":514
 *                     is_function = False
 *                     if 'function' in node:
 *                         is_function = True             # <<<<<<<<<<<<<<
 *                         self.info("It's a function!")
 *                         for f in language['functions']:
 */
          __pyx_v_is_function = 1;

          /* "ddb/lexer/lexer.py":515
 *                     if 'function' in node:
 *                         is_function = True
 *                         self.info("It's a function!")             # <<<<<<<<<<<<<<
 *                         for f in language['functions']:
 *                             if f['name'] == node['function']:
 */
          __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 515, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __pyx_t_2 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
            __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
            if (likely(__pyx_t_2)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
              __Pyx_INCREF(__pyx_t_2);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_10, function);
            }
          }
          __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_2, __pyx_kp_s_It_s_a_function) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_kp_s_It_s_a_function);
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 515, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "ddb/lexer/lexer.py":516
 *                         is_function = True
 *                         self.info("It's a function!")
 *                         for f in language['functions']:             # <<<<<<<<<<<<<<
 *                             if f['name'] == node['function']:
 *                                 argindex = 1
 */
          __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_t_1, __pyx_n_s_functions); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 516, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_10);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (likely(PyList_CheckExact(__pyx_t_10)) || PyTuple_CheckExact(__pyx_t_10)) {
            __pyx_t_1 = __pyx_t_10; __Pyx_INCREF(__pyx_t_1); __pyx_t_11 = 0;
            __pyx_t_12 = NULL;
          } else {
            __pyx_t_11 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_10); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 516, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_1);
            __pyx_t_12 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_12)) __PYX_ERR(0, 516, __pyx_L1_error)
          }
          __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
          for (;;) {
            if (likely(!__pyx_t_12)) {
              if (likely(PyList_CheckExact(__pyx_t_1))) {
                if (__pyx_t_11 >= PyList_GET_SIZE(__pyx_t_1)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_10); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 516, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 516, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              } else {
                if (__pyx_t_11 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                __pyx_t_10 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_11); __Pyx_INCREF(__pyx_t_10); __pyx_t_11++; if (unlikely(0 < 0)) __PYX_ERR(0, 516, __pyx_L1_error)
                #else
                __pyx_t_10 = PySequence_ITEM(__pyx_t_1, __pyx_t_11); __pyx_t_11++; if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 516, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_10);
                #endif
              }
            } else {
              __pyx_t_10 = __pyx_t_12(__pyx_t_1);
              if (unlikely(!__pyx_t_10)) {
                PyObject* exc_type = PyErr_Occurred();
                if (exc_type) {
                  if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                  else __PYX_ERR(0, 516, __pyx_L1_error)
                }
                break;
              }
              __Pyx_GOTREF(__pyx_t_10);
            }
            __Pyx_XDECREF_SET(__pyx_v_f, __pyx_t_10);
            __pyx_t_10 = 0;

            /* "ddb/lexer/lexer.py":517
 *                         self.info("It's a function!")
 *                         for f in language['functions']:
 *                             if f['name'] == node['function']:             # <<<<<<<<<<<<<<
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:
 */
            __pyx_t_10 = __Pyx_PyObject_Dict_GetItem(__pyx_v_f, __pyx_n_s_name); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 517, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_10);
            __pyx_t_2 = __Pyx_PyObject_Dict_GetItem(__pyx_v_node, __pyx_n_s_function); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 517, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __pyx_t_13 = PyObject_RichCompare(__pyx_t_10, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_13); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 517, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 517, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            if (__pyx_t_4) {

              /* "ddb/lexer/lexer.py":518
 *                         for f in language['functions']:
 *                             if f['name'] == node['function']:
 *                                 argindex = 1             # <<<<<<<<<<<<<<
 *                                 if f['arguments'] is not None:
 *                                     for arg in f['arguments']:
 */
              __Pyx_INCREF(__pyx_int_1);
              __Pyx_XDECREF_SET(__pyx_v_argindex, __pyx_int_1);

              /* "ddb/lexer/lexer.py":519
 *                             if f['name'] == node['function']:
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:             # <<<<<<<<<<<<<<
 *                                     for arg in f['arguments']:
 *                                         if arg['required']:
 */
              __pyx_t_13 = __Pyx_PyObject_Dict_GetItem(__pyx_v_f, __pyx_n_s_arguments); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 519, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_4 = (__pyx_t_13 != Py_None);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __pyx_t_5 = (__pyx_t_4 != 0);
              if (__pyx_t_5) {

                /* "ddb/lexer/lexer.py":520
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:
 *                                     for arg in f['arguments']:             # <<<<<<<<<<<<<<
 *                                         if arg['required']:
 *                                             # if this argument key is not in the node dict
 */
                __pyx_t_13 = __Pyx_PyObject_Dict_GetItem(__pyx_v_f, __pyx_n_s_arguments); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 520, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_13);
                if (likely(PyList_CheckExact(__pyx_t_13)) || PyTuple_CheckExact(__pyx_t_13)) {
                  __pyx_t_2 = __pyx_t_13; __Pyx_INCREF(__pyx_t_2); __pyx_t_14 = 0;
                  __pyx_t_15 = NULL;
                } else {
                  __pyx_t_14 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_13); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 520, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_2);
                  __pyx_t_15 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_15)) __PYX_ERR(0, 520, __pyx_L1_error)
                }
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                for (;;) {
                  if (likely(!__pyx_t_15)) {
                    if (likely(PyList_CheckExact(__pyx_t_2))) {
                      if (__pyx_t_14 >= PyList_GET_SIZE(__pyx_t_2)) break;
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_13 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_14); __Pyx_INCREF(__pyx_t_13); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 520, __pyx_L1_error)
                      #else
                      __pyx_t_13 = PySequence_ITEM(__pyx_t_2, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 520, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_13);
                      #endif
                    } else {
                      if (__pyx_t_14 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
                      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                      __pyx_t_13 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_14); __Pyx_INCREF(__pyx_t_13); __pyx_t_14++; if (unlikely(0 < 0)) __PYX_ERR(0, 520, __pyx_L1_error)
                      #else
                      __pyx_t_13 = PySequence_ITEM(__pyx_t_2, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 520, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_13);
                      #endif
                    }
                  } else {
                    __pyx_t_13 = __pyx_t_15(__pyx_t_2);
                    if (unlikely(!__pyx_t_13)) {
                      PyObject* exc_type = PyErr_Occurred();
                      if (exc_type) {
                        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
                        else __PYX_ERR(0, 520, __pyx_L1_error)
                      }
                      break;
                    }
                    __Pyx_GOTREF(__pyx_t_13);
                  }
                  __Pyx_XDECREF_SET(__pyx_v_arg, __pyx_t_13);
                  __pyx_t_13 = 0;

                  /* "ddb/lexer/lexer.py":521
 *                                 if f['arguments'] is not None:
 *                                     for arg in f['arguments']:
 *                                         if arg['required']:             # <<<<<<<<<<<<<<
 *                                             # if this argument key is not in the node dict
 *                                             if 'argument{0}'.format(argindex) not in node:
 */
                  __pyx_t_13 = __Pyx_PyObject_Dict_GetItem(__pyx_v_arg, __pyx_n_s_required); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 521, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_13);
                  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_13); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 521, __pyx_L1_error)
                  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                  if (__pyx_t_5) {

                    /* "ddb/lexer/lexer.py":523
 *                                         if arg['required']:
 *                                             # if this argument key is not in the node dict
 *                                             if 'argument{0}'.format(argindex) not in node:             # <<<<<<<<<<<<<<
 *                                                 msg="Missing arguments"
 *                                                 self.info(msg)
 */
                    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_argument_0, __pyx_n_s_format); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 523, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_10);
                    __pyx_t_16 = NULL;
                    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
                      __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_10);
                      if (likely(__pyx_t_16)) {
                        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                        __Pyx_INCREF(__pyx_t_16);
                        __Pyx_INCREF(function);
                        __Pyx_DECREF_SET(__pyx_t_10, function);
                      }
                    }
                    __pyx_t_13 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_16, __pyx_v_argindex) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_argindex);
                    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                    if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 523, __pyx_L1_error)
                    __Pyx_GOTREF(__pyx_t_13);
                    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                    __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_t_13, __pyx_v_node, Py_NE)); if (unlikely(__pyx_t_5 < 0)) __PYX_ERR(0, 523, __pyx_L1_error)
                    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                    __pyx_t_4 = (__pyx_t_5 != 0);
                    if (__pyx_t_4) {

                      /* "ddb/lexer/lexer.py":524
 *                                             # if this argument key is not in the node dict
 *                                             if 'argument{0}'.format(argindex) not in node:
 *                                                 msg="Missing arguments"             # <<<<<<<<<<<<<<
 *                                                 self.info(msg)
 *                                                 return {'success':None,'msg':msg}
 */
                      __Pyx_INCREF(__pyx_kp_s_Missing_arguments);
                      __pyx_v_msg = __pyx_kp_s_Missing_arguments;

                      /* "ddb/lexer/lexer.py":525
 *                                             if 'argument{0}'.format(argindex) not in node:
 *                                                 msg="Missing arguments"
 *                                                 self.info(msg)             # <<<<<<<<<<<<<<
 *                                                 return {'success':None,'msg':msg}
 * 
 */
                      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 525, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_10);
                      __pyx_t_16 = NULL;
                      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_10))) {
                        __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_10);
                        if (likely(__pyx_t_16)) {
                          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_10);
                          __Pyx_INCREF(__pyx_t_16);
                          __Pyx_INCREF(function);
                          __Pyx_DECREF_SET(__pyx_t_10, function);
                        }
                      }
                      __pyx_t_13 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_10, __pyx_t_16, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_10, __pyx_v_msg);
                      __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                      if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 525, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_13);
                      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
                      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

                      /* "ddb/lexer/lexer.py":526
 *                                                 msg="Missing arguments"
 *                                                 self.info(msg)
 *                                                 return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 * 
 *                                         argindex += 1
 */
                      __Pyx_XDECREF(__pyx_r);
                      __pyx_t_13 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 526, __pyx_L1_error)
                      __Pyx_GOTREF(__pyx_t_13);
                      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 526, __pyx_L1_error)
                      if (PyDict_SetItem(__pyx_t_13, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 526, __pyx_L1_error)
                      __pyx_r = __pyx_t_13;
                      __pyx_t_13 = 0;
                      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
                      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                      goto __pyx_L0;

                      /* "ddb/lexer/lexer.py":523
 *                                         if arg['required']:
 *                                             # if this argument key is not in the node dict
 *                                             if 'argument{0}'.format(argindex) not in node:             # <<<<<<<<<<<<<<
 *                                                 msg="Missing arguments"
 *                                                 self.info(msg)
 */
                    }

                    /* "ddb/lexer/lexer.py":521
 *                                 if f['arguments'] is not None:
 *                                     for arg in f['arguments']:
 *                                         if arg['required']:             # <<<<<<<<<<<<<<
 *                                             # if this argument key is not in the node dict
 *                                             if 'argument{0}'.format(argindex) not in node:
 */
                  }

                  /* "ddb/lexer/lexer.py":528
 *                                                 return {'success':None,'msg':msg}
 * 
 *                                         argindex += 1             # <<<<<<<<<<<<<<
 * 
 *                                 else:
 */
                  __pyx_t_13 = __Pyx_PyInt_AddObjC(__pyx_v_argindex, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 528, __pyx_L1_error)
                  __Pyx_GOTREF(__pyx_t_13);
                  __Pyx_DECREF_SET(__pyx_v_argindex, __pyx_t_13);
                  __pyx_t_13 = 0;

                  /* "ddb/lexer/lexer.py":520
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:
 *                                     for arg in f['arguments']:             # <<<<<<<<<<<<<<
 *                                         if arg['required']:
 *                                             # if this argument key is not in the node dict
 */
                }
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":519
 *                             if f['name'] == node['function']:
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:             # <<<<<<<<<<<<<<
 *                                     for arg in f['arguments']:
 *                                         if arg['required']:
 */
                goto __pyx_L20;
              }

              /* "ddb/lexer/lexer.py":531
 * 
 *                                 else:
 *                                     argindex = 0             # <<<<<<<<<<<<<<
 *                                 if 'argument{0}'.format(argindex + 1) in node:
 *                                     msg="Too many arguments"
 */
              /*else*/ {
                __Pyx_INCREF(__pyx_int_0);
                __Pyx_DECREF_SET(__pyx_v_argindex, __pyx_int_0);
              }
              __pyx_L20:;

              /* "ddb/lexer/lexer.py":532
 *                                 else:
 *                                     argindex = 0
 *                                 if 'argument{0}'.format(argindex + 1) in node:             # <<<<<<<<<<<<<<
 *                                     msg="Too many arguments"
 *                                     self.info(msg)
 */
              __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_argument_0, __pyx_n_s_format); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 532, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_10 = __Pyx_PyInt_AddObjC(__pyx_v_argindex, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 532, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_10);
              __pyx_t_16 = NULL;
              if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
                __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_13);
                if (likely(__pyx_t_16)) {
                  PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                  __Pyx_INCREF(__pyx_t_16);
                  __Pyx_INCREF(function);
                  __Pyx_DECREF_SET(__pyx_t_13, function);
                }
              }
              __pyx_t_2 = (__pyx_t_16) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_16, __pyx_t_10) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_t_10);
              __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
              __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 532, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __pyx_t_4 = (__Pyx_PySequence_ContainsTF(__pyx_t_2, __pyx_v_node, Py_EQ)); if (unlikely(__pyx_t_4 < 0)) __PYX_ERR(0, 532, __pyx_L1_error)
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __pyx_t_5 = (__pyx_t_4 != 0);
              if (__pyx_t_5) {

                /* "ddb/lexer/lexer.py":533
 *                                     argindex = 0
 *                                 if 'argument{0}'.format(argindex + 1) in node:
 *                                     msg="Too many arguments"             # <<<<<<<<<<<<<<
 *                                     self.info(msg)
 *                                     return {'success':None,'msg':msg}
 */
                __Pyx_INCREF(__pyx_kp_s_Too_many_arguments);
                __pyx_v_msg = __pyx_kp_s_Too_many_arguments;

                /* "ddb/lexer/lexer.py":534
 *                                 if 'argument{0}'.format(argindex + 1) in node:
 *                                     msg="Too many arguments"
 *                                     self.info(msg)             # <<<<<<<<<<<<<<
 *                                     return {'success':None,'msg':msg}
 * 
 */
                __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 534, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_13);
                __pyx_t_10 = NULL;
                if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_13))) {
                  __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_13);
                  if (likely(__pyx_t_10)) {
                    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_13);
                    __Pyx_INCREF(__pyx_t_10);
                    __Pyx_INCREF(function);
                    __Pyx_DECREF_SET(__pyx_t_13, function);
                  }
                }
                __pyx_t_2 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_13, __pyx_t_10, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_13, __pyx_v_msg);
                __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 534, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

                /* "ddb/lexer/lexer.py":535
 *                                     msg="Too many arguments"
 *                                     self.info(msg)
 *                                     return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 * 
 *                             valid_function_name = True
 */
                __Pyx_XDECREF(__pyx_r);
                __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 535, __pyx_L1_error)
                __Pyx_GOTREF(__pyx_t_2);
                if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 535, __pyx_L1_error)
                if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 535, __pyx_L1_error)
                __pyx_r = __pyx_t_2;
                __pyx_t_2 = 0;
                __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                goto __pyx_L0;

                /* "ddb/lexer/lexer.py":532
 *                                 else:
 *                                     argindex = 0
 *                                 if 'argument{0}'.format(argindex + 1) in node:             # <<<<<<<<<<<<<<
 *                                     msg="Too many arguments"
 *                                     self.info(msg)
 */
              }

              /* "ddb/lexer/lexer.py":517
 *                         self.info("It's a function!")
 *                         for f in language['functions']:
 *                             if f['name'] == node['function']:             # <<<<<<<<<<<<<<
 *                                 argindex = 1
 *                                 if f['arguments'] is not None:
 */
            }

            /* "ddb/lexer/lexer.py":537
 *                                     return {'success':None,'msg':msg}
 * 
 *                             valid_function_name = True             # <<<<<<<<<<<<<<
 *                             break
 *                     if False == valid_function_name and True == is_function:
 */
            __pyx_v_valid_function_name = 1;

            /* "ddb/lexer/lexer.py":538
 * 
 *                             valid_function_name = True
 *                             break             # <<<<<<<<<<<<<<
 *                     if False == valid_function_name and True == is_function:
 *                         msg="'{0}' isn't a valid function".format(node['function'])
 */
            goto __pyx_L18_break;

            /* "ddb/lexer/lexer.py":516
 *                         is_function = True
 *                         self.info("It's a function!")
 *                         for f in language['functions']:             # <<<<<<<<<<<<<<
 *                             if f['name'] == node['function']:
 *                                 argindex = 1
 */
          }
          __pyx_L18_break:;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "ddb/lexer/lexer.py":513
 *                     valid_function_name = False
 *                     is_function = False
 *                     if 'function' in node:             # <<<<<<<<<<<<<<
 *                         is_function = True
 *                         self.info("It's a function!")
 */
        }

        /* "ddb/lexer/lexer.py":539
 *                             valid_function_name = True
 *                             break
 *                     if False == valid_function_name and True == is_function:             # <<<<<<<<<<<<<<
 *                         msg="'{0}' isn't a valid function".format(node['function'])
 *                         self.info(msg)
 */
        __pyx_t_4 = ((0 == __pyx_v_valid_function_name) != 0);
        if (__pyx_t_4) {
        } else {
          __pyx_t_5 = __pyx_t_4;
          goto __pyx_L27_bool_binop_done;
        }
        __pyx_t_4 = ((1 == __pyx_v_is_function) != 0);
        __pyx_t_5 = __pyx_t_4;
        __pyx_L27_bool_binop_done:;
        if (__pyx_t_5) {

          /* "ddb/lexer/lexer.py":540
 *                             break
 *                     if False == valid_function_name and True == is_function:
 *                         msg="'{0}' isn't a valid function".format(node['function'])             # <<<<<<<<<<<<<<
 *                         self.info(msg)
 *                         return {'success':None,'msg':msg}
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_isn_t_a_valid_function, __pyx_n_s_format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 540, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = __Pyx_PyObject_Dict_GetItem(__pyx_v_node, __pyx_n_s_function); if (unlikely(!__pyx_t_13)) __PYX_ERR(0, 540, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_10 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_10)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_10);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
            }
          }
          __pyx_t_1 = (__pyx_t_10) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_10, __pyx_t_13) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_13);
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 540, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_v_msg = __pyx_t_1;
          __pyx_t_1 = 0;

          /* "ddb/lexer/lexer.py":541
 *                     if False == valid_function_name and True == is_function:
 *                         msg="'{0}' isn't a valid function".format(node['function'])
 *                         self.info(msg)             # <<<<<<<<<<<<<<
 *                         return {'success':None,'msg':msg}
 *             else:
 */
          __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 541, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_13 = NULL;
          if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
            __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_2);
            if (likely(__pyx_t_13)) {
              PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
              __Pyx_INCREF(__pyx_t_13);
              __Pyx_INCREF(function);
              __Pyx_DECREF_SET(__pyx_t_2, function);
            }
          }
          __pyx_t_1 = (__pyx_t_13) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_13, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v_msg);
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 541, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

          /* "ddb/lexer/lexer.py":542
 *                         msg="'{0}' isn't a valid function".format(node['function'])
 *                         self.info(msg)
 *                         return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 *             else:
 *                 msg="No columns in select"
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_1 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 542, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 542, __pyx_L1_error)
          if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 542, __pyx_L1_error)
          __pyx_r = __pyx_t_1;
          __pyx_t_1 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L0;

          /* "ddb/lexer/lexer.py":539
 *                             valid_function_name = True
 *                             break
 *                     if False == valid_function_name and True == is_function:             # <<<<<<<<<<<<<<
 *                         msg="'{0}' isn't a valid function".format(node['function'])
 *                         self.info(msg)
 */
        }

        /* "ddb/lexer/lexer.py":510
 *             self.info("Validating Select Functions")
 *             if 'columns' in query_object:
 *                 for node in query_object['columns']:             # <<<<<<<<<<<<<<
 *                     valid_function_name = False
 *                     is_function = False
 */
      }
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "ddb/lexer/lexer.py":509
 *             # check to make sure functions are valid
 *             self.info("Validating Select Functions")
 *             if 'columns' in query_object:             # <<<<<<<<<<<<<<
 *                 for node in query_object['columns']:
 *                     valid_function_name = False
 */
      goto __pyx_L13;
    }

    /* "ddb/lexer/lexer.py":544
 *                         return {'success':None,'msg':msg}
 *             else:
 *                 msg="No columns in select"             # <<<<<<<<<<<<<<
 *                 self.info(msg)
 *                 return {'success':None,'msg':msg}
 */
    /*else*/ {
      __Pyx_INCREF(__pyx_kp_s_No_columns_in_select);
      __pyx_v_msg = __pyx_kp_s_No_columns_in_select;

      /* "ddb/lexer/lexer.py":545
 *             else:
 *                 msg="No columns in select"
 *                 self.info(msg)             # <<<<<<<<<<<<<<
 *                 return {'success':None,'msg':msg}
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_msg);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "ddb/lexer/lexer.py":546
 *                 msg="No columns in select"
 *                 self.info(msg)
 *                 return {'success':None,'msg':msg}             # <<<<<<<<<<<<<<
 * 
 *         self.info("SUCCESS")
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 546, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_success, Py_None) < 0) __PYX_ERR(0, 546, __pyx_L1_error)
      if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_msg, __pyx_v_msg) < 0) __PYX_ERR(0, 546, __pyx_L1_error)
      __pyx_r = __pyx_t_3;
      __pyx_t_3 = 0;
      goto __pyx_L0;
    }
    __pyx_L13:;

    /* "ddb/lexer/lexer.py":506
 * 
 *         self.info("Query object", query_object)
 *         if query_mode == 'select':             # <<<<<<<<<<<<<<
 *             # check to make sure functions are valid
 *             self.info("Validating Select Functions")
 */
  }

  /* "ddb/lexer/lexer.py":548
 *                 return {'success':None,'msg':msg}
 * 
 *         self.info("SUCCESS")             # <<<<<<<<<<<<<<
 *         #from pprint import pprint
 *         #pprint( sql_object)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_info); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_n_s_SUCCESS) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_n_s_SUCCESS);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ddb/lexer/lexer.py":551
 *         #from pprint import pprint
 *         #pprint( sql_object)
 *         sql_object = {'success':True,'mode': query_mode, 'meta': query_object}             # <<<<<<<<<<<<<<
 *         return sql_object
 * 
 */
  __pyx_t_3 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_success, Py_True) < 0) __PYX_ERR(0, 551, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_mode, __pyx_v_query_mode) < 0) __PYX_ERR(0, 551, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_meta, __pyx_v_query_object) < 0) __PYX_ERR(0, 551, __pyx_L1_error)
  __pyx_v_sql_object = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "ddb/lexer/lexer.py":552
 *         #pprint( sql_object)
 *         sql_object = {'success':True,'mode': query_mode, 'meta': query_object}
 *         return sql_object             # <<<<<<<<<<<<<<
 * 
 *     # expand columns...TODO: REMOVE AFTER MIGRATION
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_sql_object);
  __pyx_r = __pyx_v_sql_object;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":474
 * 
 *     # this is crappy, I'm just breaking up a giant function. Will clean later...
 *     def validate(self,curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode):             # <<<<<<<<<<<<<<
 *         self.info(curent_object)
 *         # so we have run out of text to match and everything is good so far
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.validate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_XDECREF(__pyx_v_node);
  __Pyx_XDECREF(__pyx_v_f);
  __Pyx_XDECREF(__pyx_v_argindex);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_sql_object);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":574
 *     ## support funcitons
 * 
 *     def get_sub_array(self, array, key=None):             # <<<<<<<<<<<<<<
 *         if None == key:
 *             if isinstance(array, str):
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_13get_sub_array(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_13get_sub_array = {"get_sub_array", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_13get_sub_array, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_13get_sub_array(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_array = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_array (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_array,&__pyx_n_s_key,0};
    PyObject* values[3] = {0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_array)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_sub_array", 0, 2, 3, 1); __PYX_ERR(0, 574, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_key);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_sub_array") < 0)) __PYX_ERR(0, 574, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_array = values[1];
    __pyx_v_key = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_array", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 574, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_sub_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_12get_sub_array(__pyx_self, __pyx_v_self, __pyx_v_array, __pyx_v_key);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_12get_sub_array(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_array, PyObject *__pyx_v_key) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __Pyx_RefNannySetupContext("get_sub_array", 0);

  /* "ddb/lexer/lexer.py":575
 * 
 *     def get_sub_array(self, array, key=None):
 *         if None == key:             # <<<<<<<<<<<<<<
 *             if isinstance(array, str):
 *                 return [array]
 */
  __pyx_t_1 = PyObject_RichCompare(Py_None, __pyx_v_key, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 575, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":576
 *     def get_sub_array(self, array, key=None):
 *         if None == key:
 *             if isinstance(array, str):             # <<<<<<<<<<<<<<
 *                 return [array]
 *             else:
 */
    __pyx_t_2 = PyString_Check(__pyx_v_array); 
    __pyx_t_3 = (__pyx_t_2 != 0);
    if (__pyx_t_3) {

      /* "ddb/lexer/lexer.py":577
 *         if None == key:
 *             if isinstance(array, str):
 *                 return [array]             # <<<<<<<<<<<<<<
 *             else:
 *                 return array
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_array);
      __Pyx_GIVEREF(__pyx_v_array);
      PyList_SET_ITEM(__pyx_t_1, 0, __pyx_v_array);
      __pyx_r = __pyx_t_1;
      __pyx_t_1 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":576
 *     def get_sub_array(self, array, key=None):
 *         if None == key:
 *             if isinstance(array, str):             # <<<<<<<<<<<<<<
 *                 return [array]
 *             else:
 */
    }

    /* "ddb/lexer/lexer.py":579
 *                 return [array]
 *             else:
 *                 return array             # <<<<<<<<<<<<<<
 *         if True == isinstance(array[key], list):
 *             return array[key]
 */
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_array);
      __pyx_r = __pyx_v_array;
      goto __pyx_L0;
    }

    /* "ddb/lexer/lexer.py":575
 * 
 *     def get_sub_array(self, array, key=None):
 *         if None == key:             # <<<<<<<<<<<<<<
 *             if isinstance(array, str):
 *                 return [array]
 */
  }

  /* "ddb/lexer/lexer.py":580
 *             else:
 *                 return array
 *         if True == isinstance(array[key], list):             # <<<<<<<<<<<<<<
 *             return array[key]
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_array, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 580, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyList_Check(__pyx_t_1); 
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = ((1 == __pyx_t_3) != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":581
 *                 return array
 *         if True == isinstance(array[key], list):
 *             return array[key]             # <<<<<<<<<<<<<<
 *         else:
 *             return [array[key]]
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_array, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 581, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "ddb/lexer/lexer.py":580
 *             else:
 *                 return array
 *         if True == isinstance(array[key], list):             # <<<<<<<<<<<<<<
 *             return array[key]
 *         else:
 */
  }

  /* "ddb/lexer/lexer.py":583
 *             return array[key]
 *         else:
 *             return [array[key]]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyObject_GetItem(__pyx_v_array, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = PyList_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_4, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "ddb/lexer/lexer.py":574
 *     ## support funcitons
 * 
 *     def get_sub_array(self, array, key=None):             # <<<<<<<<<<<<<<
 *         if None == key:
 *             if isinstance(array, str):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_sub_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":586
 * 
 * 
 *     def get_sub_array_sub_key(self, array, key):             # <<<<<<<<<<<<<<
 *         temp_array = []
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_15get_sub_array_sub_key(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_15get_sub_array_sub_key = {"get_sub_array_sub_key", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_15get_sub_array_sub_key, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_15get_sub_array_sub_key(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_array = 0;
  PyObject *__pyx_v_key = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sub_array_sub_key (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_array,&__pyx_n_s_key,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_array)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_sub_array_sub_key", 1, 3, 3, 1); __PYX_ERR(0, 586, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_key)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("get_sub_array_sub_key", 1, 3, 3, 2); __PYX_ERR(0, 586, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "get_sub_array_sub_key") < 0)) __PYX_ERR(0, 586, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_array = values[1];
    __pyx_v_key = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_sub_array_sub_key", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 586, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_sub_array_sub_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_14get_sub_array_sub_key(__pyx_self, __pyx_v_self, __pyx_v_array, __pyx_v_key);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_14get_sub_array_sub_key(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_array, PyObject *__pyx_v_key) {
  PyObject *__pyx_v_temp_array = NULL;
  PyObject *__pyx_v_item = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *(*__pyx_t_3)(PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  __Pyx_RefNannySetupContext("get_sub_array_sub_key", 0);

  /* "ddb/lexer/lexer.py":587
 * 
 *     def get_sub_array_sub_key(self, array, key):
 *         temp_array = []             # <<<<<<<<<<<<<<
 * 
 *         for item in array:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 587, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_temp_array = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":589
 *         temp_array = []
 * 
 *         for item in array:             # <<<<<<<<<<<<<<
 *             temp_array.append(item[key])
 * 
 */
  if (likely(PyList_CheckExact(__pyx_v_array)) || PyTuple_CheckExact(__pyx_v_array)) {
    __pyx_t_1 = __pyx_v_array; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
    __pyx_t_3 = NULL;
  } else {
    __pyx_t_2 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_v_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 589, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_3)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_2 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 589, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 589, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_4); __pyx_t_2++; if (unlikely(0 < 0)) __PYX_ERR(0, 589, __pyx_L1_error)
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 589, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_3(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 589, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "ddb/lexer/lexer.py":590
 * 
 *         for item in array:
 *             temp_array.append(item[key])             # <<<<<<<<<<<<<<
 * 
 *         return temp_array
 */
    __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_item, __pyx_v_key); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_temp_array, __pyx_t_4); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 590, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "ddb/lexer/lexer.py":589
 *         temp_array = []
 * 
 *         for item in array:             # <<<<<<<<<<<<<<
 *             temp_array.append(item[key])
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":592
 *             temp_array.append(item[key])
 * 
 *         return temp_array             # <<<<<<<<<<<<<<
 * 
 *     def single_array_match(self, needles, haystacks):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_temp_array);
  __pyx_r = __pyx_v_temp_array;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":586
 * 
 * 
 *     def get_sub_array_sub_key(self, array, key):             # <<<<<<<<<<<<<<
 *         temp_array = []
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.get_sub_array_sub_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_temp_array);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":594
 *         return temp_array
 * 
 *     def single_array_match(self, needles, haystacks):             # <<<<<<<<<<<<<<
 *         """ Match a single or array of strings with with another string or array of strings"""
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_17single_array_match(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_3ddb_5lexer_5lexer_5lexer_16single_array_match[] = " Match a single or array of strings with with another string or array of strings";
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_17single_array_match = {"single_array_match", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_17single_array_match, METH_VARARGS|METH_KEYWORDS, __pyx_doc_3ddb_5lexer_5lexer_5lexer_16single_array_match};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_17single_array_match(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_needles = 0;
  PyObject *__pyx_v_haystacks = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("single_array_match (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_needles,&__pyx_n_s_haystacks,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_needles)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("single_array_match", 1, 3, 3, 1); __PYX_ERR(0, 594, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_haystacks)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("single_array_match", 1, 3, 3, 2); __PYX_ERR(0, 594, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "single_array_match") < 0)) __PYX_ERR(0, 594, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
    }
    __pyx_v_self = values[0];
    __pyx_v_needles = values[1];
    __pyx_v_haystacks = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("single_array_match", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 594, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.single_array_match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_16single_array_match(__pyx_self, __pyx_v_self, __pyx_v_needles, __pyx_v_haystacks);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_16single_array_match(CYTHON_UNUSED PyObject *__pyx_self, CYTHON_UNUSED PyObject *__pyx_v_self, PyObject *__pyx_v_needles, PyObject *__pyx_v_haystacks) {
  PyObject *__pyx_v_temp_needles = NULL;
  PyObject *__pyx_v_temp_haystacks = NULL;
  PyObject *__pyx_v_index = NULL;
  PyObject *__pyx_v_needle = NULL;
  PyObject *__pyx_v_first_char = NULL;
  PyObject *__pyx_v_last_char = NULL;
  PyObject *__pyx_v_haystack = NULL;
  PyObject *__pyx_v_variable = NULL;
  PyObject *__pyx_v_index_of_colon = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  PyObject *__pyx_t_6 = NULL;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  __Pyx_RefNannySetupContext("single_array_match", 0);

  /* "ddb/lexer/lexer.py":598
 * 
 *         # make needels an array, with or without a sub key
 *         if isinstance(needles, str):             # <<<<<<<<<<<<<<
 *             temp_needles = [needles]
 *         else:
 */
  __pyx_t_1 = PyString_Check(__pyx_v_needles); 
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "ddb/lexer/lexer.py":599
 *         # make needels an array, with or without a sub key
 *         if isinstance(needles, str):
 *             temp_needles = [needles]             # <<<<<<<<<<<<<<
 *         else:
 *             temp_needles = needles
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 599, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_needles);
    __Pyx_GIVEREF(__pyx_v_needles);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_needles);
    __pyx_v_temp_needles = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":598
 * 
 *         # make needels an array, with or without a sub key
 *         if isinstance(needles, str):             # <<<<<<<<<<<<<<
 *             temp_needles = [needles]
 *         else:
 */
    goto __pyx_L3;
  }

  /* "ddb/lexer/lexer.py":601
 *             temp_needles = [needles]
 *         else:
 *             temp_needles = needles             # <<<<<<<<<<<<<<
 * 
 *         # make haystacks an array
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_needles);
    __pyx_v_temp_needles = __pyx_v_needles;
  }
  __pyx_L3:;

  /* "ddb/lexer/lexer.py":604
 * 
 *         # make haystacks an array
 *         if isinstance(haystacks, str):             # <<<<<<<<<<<<<<
 *             temp_haystacks = [haystacks]
 *         else:
 */
  __pyx_t_2 = PyString_Check(__pyx_v_haystacks); 
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "ddb/lexer/lexer.py":605
 *         # make haystacks an array
 *         if isinstance(haystacks, str):
 *             temp_haystacks = [haystacks]             # <<<<<<<<<<<<<<
 *         else:
 *             temp_haystacks = haystacks
 */
    __pyx_t_3 = PyList_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_haystacks);
    __Pyx_GIVEREF(__pyx_v_haystacks);
    PyList_SET_ITEM(__pyx_t_3, 0, __pyx_v_haystacks);
    __pyx_v_temp_haystacks = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "ddb/lexer/lexer.py":604
 * 
 *         # make haystacks an array
 *         if isinstance(haystacks, str):             # <<<<<<<<<<<<<<
 *             temp_haystacks = [haystacks]
 *         else:
 */
    goto __pyx_L4;
  }

  /* "ddb/lexer/lexer.py":607
 *             temp_haystacks = [haystacks]
 *         else:
 *             temp_haystacks = haystacks             # <<<<<<<<<<<<<<
 * 
 *         # now we have 2 plain array/lists to compare
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_v_haystacks);
    __pyx_v_temp_haystacks = __pyx_v_haystacks;
  }
  __pyx_L4:;

  /* "ddb/lexer/lexer.py":611
 *         # now we have 2 plain array/lists to compare
 * 
 *         index = 0             # <<<<<<<<<<<<<<
 * 
 *         for needle in temp_needles:
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_index = __pyx_int_0;

  /* "ddb/lexer/lexer.py":613
 *         index = 0
 * 
 *         for needle in temp_needles:             # <<<<<<<<<<<<<<
 *             first_char=needle[0]
 *             last_char=needle[-1]
 */
  if (likely(PyList_CheckExact(__pyx_v_temp_needles)) || PyTuple_CheckExact(__pyx_v_temp_needles)) {
    __pyx_t_3 = __pyx_v_temp_needles; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_v_temp_needles); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 613, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 613, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 613, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_6); __pyx_t_4++; if (unlikely(0 < 0)) __PYX_ERR(0, 613, __pyx_L1_error)
        #else
        __pyx_t_6 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 613, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
      }
    } else {
      __pyx_t_6 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(0, 613, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_XDECREF_SET(__pyx_v_needle, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "ddb/lexer/lexer.py":614
 * 
 *         for needle in temp_needles:
 *             first_char=needle[0]             # <<<<<<<<<<<<<<
 *             last_char=needle[-1]
 * 
 */
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_needle, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_first_char, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "ddb/lexer/lexer.py":615
 *         for needle in temp_needles:
 *             first_char=needle[0]
 *             last_char=needle[-1]             # <<<<<<<<<<<<<<
 * 
 *             # ran out of haystack to test. not a match
 */
    __pyx_t_6 = __Pyx_GetItemInt(__pyx_v_needle, -1L, long, 1, __Pyx_PyInt_From_long, 0, 1, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 615, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_last_char, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "ddb/lexer/lexer.py":618
 * 
 *             # ran out of haystack to test. not a match
 *             if index >= len(temp_haystacks):             # <<<<<<<<<<<<<<
 *                 return False
 *             haystack = temp_haystacks[index]
 */
    __pyx_t_7 = PyObject_Length(__pyx_v_temp_haystacks); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 618, __pyx_L1_error)
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_8 = PyObject_RichCompare(__pyx_v_index, __pyx_t_6, Py_GE); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 618, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_1) {

      /* "ddb/lexer/lexer.py":619
 *             # ran out of haystack to test. not a match
 *             if index >= len(temp_haystacks):
 *                 return False             # <<<<<<<<<<<<<<
 *             haystack = temp_haystacks[index]
 *             # not a match
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_False);
      __pyx_r = Py_False;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":618
 * 
 *             # ran out of haystack to test. not a match
 *             if index >= len(temp_haystacks):             # <<<<<<<<<<<<<<
 *                 return False
 *             haystack = temp_haystacks[index]
 */
    }

    /* "ddb/lexer/lexer.py":620
 *             if index >= len(temp_haystacks):
 *                 return False
 *             haystack = temp_haystacks[index]             # <<<<<<<<<<<<<<
 *             # not a match
 *             if first_char!='$':
 */
    __pyx_t_8 = __Pyx_PyObject_GetItem(__pyx_v_temp_haystacks, __pyx_v_index); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 620, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_XDECREF_SET(__pyx_v_haystack, __pyx_t_8);
    __pyx_t_8 = 0;

    /* "ddb/lexer/lexer.py":622
 *             haystack = temp_haystacks[index]
 *             # not a match
 *             if first_char!='$':             # <<<<<<<<<<<<<<
 *                 if first_char != '{' and last_char != '}':
 *                     if needle.lower() != haystack.lower():
 */
    __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_first_char, __pyx_kp_s__13, Py_NE)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 622, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "ddb/lexer/lexer.py":623
 *             # not a match
 *             if first_char!='$':
 *                 if first_char != '{' and last_char != '}':             # <<<<<<<<<<<<<<
 *                     if needle.lower() != haystack.lower():
 *                         return False
 */
      __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_first_char, __pyx_kp_s__11, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 623, __pyx_L1_error)
      if (__pyx_t_2) {
      } else {
        __pyx_t_1 = __pyx_t_2;
        goto __pyx_L10_bool_binop_done;
      }
      __pyx_t_2 = (__Pyx_PyString_Equals(__pyx_v_last_char, __pyx_kp_s__12, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 623, __pyx_L1_error)
      __pyx_t_1 = __pyx_t_2;
      __pyx_L10_bool_binop_done:;
      if (__pyx_t_1) {

        /* "ddb/lexer/lexer.py":624
 *             if first_char!='$':
 *                 if first_char != '{' and last_char != '}':
 *                     if needle.lower() != haystack.lower():             # <<<<<<<<<<<<<<
 *                         return False
 *             if needle[0]=='$':
 */
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_needle, __pyx_n_s_lower); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_9 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
          if (likely(__pyx_t_9)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
            __Pyx_INCREF(__pyx_t_9);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_6, function);
          }
        }
        __pyx_t_8 = (__pyx_t_9) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_9) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_v_haystack, __pyx_n_s_lower); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_10 = NULL;
        if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_9))) {
          __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_9);
          if (likely(__pyx_t_10)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_10);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_9, function);
          }
        }
        __pyx_t_6 = (__pyx_t_10) ? __Pyx_PyObject_CallOneArg(__pyx_t_9, __pyx_t_10) : __Pyx_PyObject_CallNoArg(__pyx_t_9);
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_9 = PyObject_RichCompare(__pyx_t_8, __pyx_t_6, Py_NE); __Pyx_XGOTREF(__pyx_t_9); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 624, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (__pyx_t_1) {

          /* "ddb/lexer/lexer.py":625
 *                 if first_char != '{' and last_char != '}':
 *                     if needle.lower() != haystack.lower():
 *                         return False             # <<<<<<<<<<<<<<
 *             if needle[0]=='$':
 *                 variable=needle[1:]
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_INCREF(Py_False);
          __pyx_r = Py_False;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L0;

          /* "ddb/lexer/lexer.py":624
 *             if first_char!='$':
 *                 if first_char != '{' and last_char != '}':
 *                     if needle.lower() != haystack.lower():             # <<<<<<<<<<<<<<
 *                         return False
 *             if needle[0]=='$':
 */
        }

        /* "ddb/lexer/lexer.py":623
 *             # not a match
 *             if first_char!='$':
 *                 if first_char != '{' and last_char != '}':             # <<<<<<<<<<<<<<
 *                     if needle.lower() != haystack.lower():
 *                         return False
 */
      }

      /* "ddb/lexer/lexer.py":622
 *             haystack = temp_haystacks[index]
 *             # not a match
 *             if first_char!='$':             # <<<<<<<<<<<<<<
 *                 if first_char != '{' and last_char != '}':
 *                     if needle.lower() != haystack.lower():
 */
    }

    /* "ddb/lexer/lexer.py":626
 *                     if needle.lower() != haystack.lower():
 *                         return False
 *             if needle[0]=='$':             # <<<<<<<<<<<<<<
 *                 variable=needle[1:]
 *                 index_of_colon=variable.find(':')
 */
    __pyx_t_9 = __Pyx_GetItemInt(__pyx_v_needle, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_t_9, __pyx_kp_s__13, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 626, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    if (__pyx_t_1) {

      /* "ddb/lexer/lexer.py":627
 *                         return False
 *             if needle[0]=='$':
 *                 variable=needle[1:]             # <<<<<<<<<<<<<<
 *                 index_of_colon=variable.find(':')
 *                 if index_of_colon!=-1:
 */
      __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_v_needle, 1, 0, NULL, NULL, &__pyx_slice__17, 1, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 627, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_XDECREF_SET(__pyx_v_variable, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "ddb/lexer/lexer.py":628
 *             if needle[0]=='$':
 *                 variable=needle[1:]
 *                 index_of_colon=variable.find(':')             # <<<<<<<<<<<<<<
 *                 if index_of_colon!=-1:
 *                     variable=variable[0:index_of_colon]
 */
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_variable, __pyx_n_s_find); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 628, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_8 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_6, function);
        }
      }
      __pyx_t_9 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_6, __pyx_t_8, __pyx_kp_s__18) : __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_kp_s__18);
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 628, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF_SET(__pyx_v_index_of_colon, __pyx_t_9);
      __pyx_t_9 = 0;

      /* "ddb/lexer/lexer.py":629
 *                 variable=needle[1:]
 *                 index_of_colon=variable.find(':')
 *                 if index_of_colon!=-1:             # <<<<<<<<<<<<<<
 *                     variable=variable[0:index_of_colon]
 * 
 */
      __pyx_t_9 = __Pyx_PyInt_NeObjC(__pyx_v_index_of_colon, __pyx_int_neg_1, -1L, 0); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 629, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 629, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (__pyx_t_1) {

        /* "ddb/lexer/lexer.py":630
 *                 index_of_colon=variable.find(':')
 *                 if index_of_colon!=-1:
 *                     variable=variable[0:index_of_colon]             # <<<<<<<<<<<<<<
 * 
 *             #    print(needle,haystack)
 */
        __pyx_t_9 = __Pyx_PyObject_GetSlice(__pyx_v_variable, 0, 0, NULL, &__pyx_v_index_of_colon, NULL, 1, 0, 1); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 630, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF_SET(__pyx_v_variable, __pyx_t_9);
        __pyx_t_9 = 0;

        /* "ddb/lexer/lexer.py":629
 *                 variable=needle[1:]
 *                 index_of_colon=variable.find(':')
 *                 if index_of_colon!=-1:             # <<<<<<<<<<<<<<
 *                     variable=variable[0:index_of_colon]
 * 
 */
      }

      /* "ddb/lexer/lexer.py":634
 *             #    print(needle,haystack)
 *             #    print(variable)
 *                 if variable in language:             # <<<<<<<<<<<<<<
 *                     if haystack not in language[variable]:
 *                         return False
 */
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_language); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 634, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_1 = (__Pyx_PySequence_ContainsTF(__pyx_v_variable, __pyx_t_9, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) __PYX_ERR(0, 634, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_2 = (__pyx_t_1 != 0);
      if (__pyx_t_2) {

        /* "ddb/lexer/lexer.py":635
 *             #    print(variable)
 *                 if variable in language:
 *                     if haystack not in language[variable]:             # <<<<<<<<<<<<<<
 *                         return False
 * 
 */
        __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_language); if (unlikely(!__pyx_t_9)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_9, __pyx_v_variable); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_v_haystack, __pyx_t_6, Py_NE)); if (unlikely(__pyx_t_2 < 0)) __PYX_ERR(0, 635, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_1 = (__pyx_t_2 != 0);
        if (__pyx_t_1) {

          /* "ddb/lexer/lexer.py":636
 *                 if variable in language:
 *                     if haystack not in language[variable]:
 *                         return False             # <<<<<<<<<<<<<<
 * 
 *             index += 1
 */
          __Pyx_XDECREF(__pyx_r);
          __Pyx_INCREF(Py_False);
          __pyx_r = Py_False;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          goto __pyx_L0;

          /* "ddb/lexer/lexer.py":635
 *             #    print(variable)
 *                 if variable in language:
 *                     if haystack not in language[variable]:             # <<<<<<<<<<<<<<
 *                         return False
 * 
 */
        }

        /* "ddb/lexer/lexer.py":634
 *             #    print(needle,haystack)
 *             #    print(variable)
 *                 if variable in language:             # <<<<<<<<<<<<<<
 *                     if haystack not in language[variable]:
 *                         return False
 */
      }

      /* "ddb/lexer/lexer.py":626
 *                     if needle.lower() != haystack.lower():
 *                         return False
 *             if needle[0]=='$':             # <<<<<<<<<<<<<<
 *                 variable=needle[1:]
 *                 index_of_colon=variable.find(':')
 */
    }

    /* "ddb/lexer/lexer.py":638
 *                         return False
 * 
 *             index += 1             # <<<<<<<<<<<<<<
 *         # if we got here it must match
 *         return True
 */
    __pyx_t_6 = __Pyx_PyInt_AddObjC(__pyx_v_index, __pyx_int_1, 1, 1, 0); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 638, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "ddb/lexer/lexer.py":613
 *         index = 0
 * 
 *         for needle in temp_needles:             # <<<<<<<<<<<<<<
 *             first_char=needle[0]
 *             last_char=needle[-1]
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ddb/lexer/lexer.py":640
 *             index += 1
 *         # if we got here it must match
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "ddb/lexer/lexer.py":594
 *         return temp_array
 * 
 *     def single_array_match(self, needles, haystacks):             # <<<<<<<<<<<<<<
 *         """ Match a single or array of strings with with another string or array of strings"""
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.single_array_match", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_temp_needles);
  __Pyx_XDECREF(__pyx_v_temp_haystacks);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XDECREF(__pyx_v_needle);
  __Pyx_XDECREF(__pyx_v_first_char);
  __Pyx_XDECREF(__pyx_v_last_char);
  __Pyx_XDECREF(__pyx_v_haystack);
  __Pyx_XDECREF(__pyx_v_variable);
  __Pyx_XDECREF(__pyx_v_index_of_colon);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "ddb/lexer/lexer.py":642
 *         return True
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):             # <<<<<<<<<<<<<<
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_19info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_3ddb_5lexer_5lexer_5lexer_19info = {"info", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_3ddb_5lexer_5lexer_5lexer_19info, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_3ddb_5lexer_5lexer_5lexer_19info(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_self = 0;
  PyObject *__pyx_v_msg = 0;
  PyObject *__pyx_v_arg1 = 0;
  PyObject *__pyx_v_arg2 = 0;
  PyObject *__pyx_v_arg3 = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("info (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_self,&__pyx_n_s_msg,&__pyx_n_s_arg1,&__pyx_n_s_arg2,&__pyx_n_s_arg3,0};
    PyObject* values[5] = {0,0,0,0,0};
    values[2] = ((PyObject *)((PyObject *)Py_None));
    values[3] = ((PyObject *)((PyObject *)Py_None));
    values[4] = ((PyObject *)((PyObject *)Py_None));
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_self)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_msg)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("info", 0, 2, 5, 1); __PYX_ERR(0, 642, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_arg1);
          if (value) { values[2] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_arg2);
          if (value) { values[3] = value; kw_args--; }
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_arg3);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "info") < 0)) __PYX_ERR(0, 642, __pyx_L3_error)
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_self = values[0];
    __pyx_v_msg = values[1];
    __pyx_v_arg1 = values[2];
    __pyx_v_arg2 = values[3];
    __pyx_v_arg3 = values[4];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("info", 0, 2, 5, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 642, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_3ddb_5lexer_5lexer_5lexer_18info(__pyx_self, __pyx_v_self, __pyx_v_msg, __pyx_v_arg1, __pyx_v_arg2, __pyx_v_arg3);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_3ddb_5lexer_5lexer_5lexer_18info(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_self, PyObject *__pyx_v_msg, PyObject *__pyx_v_arg1, PyObject *__pyx_v_arg2, PyObject *__pyx_v_arg3) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  __Pyx_RefNannySetupContext("info", 0);

  /* "ddb/lexer/lexer.py":643
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):
 *         if True == self.debug:             # <<<<<<<<<<<<<<
 *             if arg3 is None and arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self, __pyx_n_s_debug); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(Py_True, __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 643, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "ddb/lexer/lexer.py":644
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 */
    __pyx_t_4 = (__pyx_v_arg3 == Py_None);
    __pyx_t_5 = (__pyx_t_4 != 0);
    if (__pyx_t_5) {
    } else {
      __pyx_t_3 = __pyx_t_5;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_5 = (__pyx_v_arg2 == Py_None);
    __pyx_t_4 = (__pyx_t_5 != 0);
    __pyx_t_3 = __pyx_t_4;
    __pyx_L5_bool_binop_done:;
    if (__pyx_t_3) {

      /* "ddb/lexer/lexer.py":645
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))             # <<<<<<<<<<<<<<
 *                 return
 *             if arg3 is None:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_1_3, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_msg, __pyx_v_arg1};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_msg, __pyx_v_arg1};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_v_msg);
        __Pyx_GIVEREF(__pyx_v_msg);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_msg);
        __Pyx_INCREF(__pyx_v_arg1);
        __Pyx_GIVEREF(__pyx_v_arg1);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_arg1);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 645, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 645, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":646
 *             if arg3 is None and arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))
 *                 return             # <<<<<<<<<<<<<<
 *             if arg3 is None:
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":644
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 */
    }

    /* "ddb/lexer/lexer.py":647
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 *             if arg3 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 *                 return
 */
    __pyx_t_3 = (__pyx_v_arg3 == Py_None);
    __pyx_t_4 = (__pyx_t_3 != 0);
    if (__pyx_t_4) {

      /* "ddb/lexer/lexer.py":648
 *                 return
 *             if arg3 is None:
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))             # <<<<<<<<<<<<<<
 *                 return
 *             if arg2 is None:
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_1_2_2, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 648, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_8 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_8)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_8);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_msg, __pyx_v_arg1, __pyx_v_arg2};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[4] = {__pyx_t_8, __pyx_v_msg, __pyx_v_arg1, __pyx_v_arg2};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 3+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_6 = PyTuple_New(3+__pyx_t_7); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        if (__pyx_t_8) {
          __Pyx_GIVEREF(__pyx_t_8); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_8); __pyx_t_8 = NULL;
        }
        __Pyx_INCREF(__pyx_v_msg);
        __Pyx_GIVEREF(__pyx_v_msg);
        PyTuple_SET_ITEM(__pyx_t_6, 0+__pyx_t_7, __pyx_v_msg);
        __Pyx_INCREF(__pyx_v_arg1);
        __Pyx_GIVEREF(__pyx_v_arg1);
        PyTuple_SET_ITEM(__pyx_t_6, 1+__pyx_t_7, __pyx_v_arg1);
        __Pyx_INCREF(__pyx_v_arg2);
        __Pyx_GIVEREF(__pyx_v_arg2);
        PyTuple_SET_ITEM(__pyx_t_6, 2+__pyx_t_7, __pyx_v_arg2);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 648, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 648, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":649
 *             if arg3 is None:
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 *                 return             # <<<<<<<<<<<<<<
 *             if arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":647
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 *             if arg3 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 *                 return
 */
    }

    /* "ddb/lexer/lexer.py":650
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 *                 return
 *             if arg2 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 */
    __pyx_t_4 = (__pyx_v_arg2 == Py_None);
    __pyx_t_3 = (__pyx_t_4 != 0);
    if (__pyx_t_3) {

      /* "ddb/lexer/lexer.py":651
 *                 return
 *             if arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))             # <<<<<<<<<<<<<<
 *                 return
 * 
 */
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_1_3, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_6 = NULL;
      __pyx_t_7 = 0;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
          __pyx_t_7 = 1;
        }
      }
      #if CYTHON_FAST_PYCALL
      if (PyFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_msg, __pyx_v_arg1};
        __pyx_t_2 = __Pyx_PyFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      #if CYTHON_FAST_PYCCALL
      if (__Pyx_PyFastCFunction_Check(__pyx_t_1)) {
        PyObject *__pyx_temp[3] = {__pyx_t_6, __pyx_v_msg, __pyx_v_arg1};
        __pyx_t_2 = __Pyx_PyCFunction_FastCall(__pyx_t_1, __pyx_temp+1-__pyx_t_7, 2+__pyx_t_7); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_GOTREF(__pyx_t_2);
      } else
      #endif
      {
        __pyx_t_8 = PyTuple_New(2+__pyx_t_7); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        if (__pyx_t_6) {
          __Pyx_GIVEREF(__pyx_t_6); PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6); __pyx_t_6 = NULL;
        }
        __Pyx_INCREF(__pyx_v_msg);
        __Pyx_GIVEREF(__pyx_v_msg);
        PyTuple_SET_ITEM(__pyx_t_8, 0+__pyx_t_7, __pyx_v_msg);
        __Pyx_INCREF(__pyx_v_arg1);
        __Pyx_GIVEREF(__pyx_v_arg1);
        PyTuple_SET_ITEM(__pyx_t_8, 1+__pyx_t_7, __pyx_v_arg1);
        __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_8, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 651, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 651, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "ddb/lexer/lexer.py":652
 *             if arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))
 *                 return             # <<<<<<<<<<<<<<
 * 
 *             print("[{0}]".format(msg))
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_r = Py_None; __Pyx_INCREF(Py_None);
      goto __pyx_L0;

      /* "ddb/lexer/lexer.py":650
 *                 print("{0} {1} {2}".format(msg, arg1, arg2))
 *                 return
 *             if arg2 is None:             # <<<<<<<<<<<<<<
 *                 print("{0} {1}".format(msg, arg1))
 *                 return
 */
    }

    /* "ddb/lexer/lexer.py":654
 *                 return
 * 
 *             print("[{0}]".format(msg))             # <<<<<<<<<<<<<<
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_kp_s_0_2, __pyx_n_s_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_8 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_8)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_8, __pyx_v_msg) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_v_msg);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__Pyx_PrintOne(0, __pyx_t_2) < 0) __PYX_ERR(0, 654, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "ddb/lexer/lexer.py":643
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):
 *         if True == self.debug:             # <<<<<<<<<<<<<<
 *             if arg3 is None and arg2 is None:
 *                 print("{0} {1}".format(msg, arg1))
 */
  }

  /* "ddb/lexer/lexer.py":642
 *         return True
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):             # <<<<<<<<<<<<<<
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("ddb.lexer.lexer.lexer.info", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_lexer(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_lexer},
  {0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    "lexer",
    0, /* m_doc */
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    0, /* m_size */
  #else
    -1, /* m_size */
  #endif
    __pyx_methods /* m_methods */,
  #if CYTHON_PEP489_MULTI_PHASE_INIT
    __pyx_moduledef_slots, /* m_slots */
  #else
    NULL, /* m_reload */
  #endif
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_, __pyx_k_, sizeof(__pyx_k_), 0, 0, 1, 0},
  {&__pyx_kp_s_0, __pyx_k_0, sizeof(__pyx_k_0), 0, 0, 1, 0},
  {&__pyx_kp_s_0_1, __pyx_k_0_1, sizeof(__pyx_k_0_1), 0, 0, 1, 0},
  {&__pyx_kp_s_0_1_2, __pyx_k_0_1_2, sizeof(__pyx_k_0_1_2), 0, 0, 1, 0},
  {&__pyx_kp_s_0_1_2_2, __pyx_k_0_1_2_2, sizeof(__pyx_k_0_1_2_2), 0, 0, 1, 0},
  {&__pyx_kp_s_0_1_3, __pyx_k_0_1_3, sizeof(__pyx_k_0_1_3), 0, 0, 1, 0},
  {&__pyx_kp_s_0_2, __pyx_k_0_2, sizeof(__pyx_k_0_2), 0, 0, 1, 0},
  {&__pyx_kp_s_0_isn_t_a_valid_function, __pyx_k_0_isn_t_a_valid_function, sizeof(__pyx_k_0_isn_t_a_valid_function), 0, 0, 1, 0},
  {&__pyx_n_s_APPEND, __pyx_k_APPEND, sizeof(__pyx_k_APPEND), 0, 0, 1, 1},
  {&__pyx_kp_s_Adding, __pyx_k_Adding, sizeof(__pyx_k_Adding), 0, 0, 1, 0},
  {&__pyx_n_s_BaseException, __pyx_k_BaseException, sizeof(__pyx_k_BaseException), 0, 0, 1, 1},
  {&__pyx_kp_s_Best_Match, __pyx_k_Best_Match, sizeof(__pyx_k_Best_Match), 0, 0, 1, 0},
  {&__pyx_kp_s_Dependency_found, __pyx_k_Dependency_found, sizeof(__pyx_k_Dependency_found), 0, 0, 1, 0},
  {&__pyx_kp_s_Depends_on_key_0, __pyx_k_Depends_on_key_0, sizeof(__pyx_k_Depends_on_key_0), 0, 0, 1, 0},
  {&__pyx_kp_s_FAILED_MATCH, __pyx_k_FAILED_MATCH, sizeof(__pyx_k_FAILED_MATCH), 0, 0, 1, 0},
  {&__pyx_kp_s_Invalid_Syntax, __pyx_k_Invalid_Syntax, sizeof(__pyx_k_Invalid_Syntax), 0, 0, 1, 0},
  {&__pyx_kp_s_It_s_a_function, __pyx_k_It_s_a_function, sizeof(__pyx_k_It_s_a_function), 0, 0, 1, 0},
  {&__pyx_n_s_JUMP, __pyx_k_JUMP, sizeof(__pyx_k_JUMP), 0, 0, 1, 1},
  {&__pyx_kp_s_Jumping_from, __pyx_k_Jumping_from, sizeof(__pyx_k_Jumping_from), 0, 0, 1, 0},
  {&__pyx_n_s_Missing, __pyx_k_Missing, sizeof(__pyx_k_Missing), 0, 0, 1, 1},
  {&__pyx_kp_s_Missing_argument_in_last_element, __pyx_k_Missing_argument_in_last_element, sizeof(__pyx_k_Missing_argument_in_last_element), 0, 0, 1, 0},
  {&__pyx_kp_s_Missing_arguments, __pyx_k_Missing_arguments, sizeof(__pyx_k_Missing_arguments), 0, 0, 1, 0},
  {&__pyx_kp_s_NO_APPEND, __pyx_k_NO_APPEND, sizeof(__pyx_k_NO_APPEND), 0, 0, 1, 0},
  {&__pyx_kp_s_No_columns_in_select, __pyx_k_No_columns_in_select, sizeof(__pyx_k_No_columns_in_select), 0, 0, 1, 0},
  {&__pyx_kp_s_No_match, __pyx_k_No_match, sizeof(__pyx_k_No_match), 0, 0, 1, 0},
  {&__pyx_kp_s_Non_optional_components_missing, __pyx_k_Non_optional_components_missing, sizeof(__pyx_k_Non_optional_components_missing), 0, 0, 1, 0},
  {&__pyx_kp_s_Not_found_argument, __pyx_k_Not_found_argument, sizeof(__pyx_k_Not_found_argument), 0, 0, 1, 0},
  {&__pyx_kp_s_Not_successful_required_argument, __pyx_k_Not_successful_required_argument, sizeof(__pyx_k_Not_successful_required_argument), 0, 0, 1, 0},
  {&__pyx_kp_s_Number_of_arguments, __pyx_k_Number_of_arguments, sizeof(__pyx_k_Number_of_arguments), 0, 0, 1, 0},
  {&__pyx_kp_s_Object_Id, __pyx_k_Object_Id, sizeof(__pyx_k_Object_Id), 0, 0, 1, 0},
  {&__pyx_kp_s_QUERY_OBJECT, __pyx_k_QUERY_OBJECT, sizeof(__pyx_k_QUERY_OBJECT), 0, 0, 1, 0},
  {&__pyx_n_s_Queries, __pyx_k_Queries, sizeof(__pyx_k_Queries), 0, 0, 1, 1},
  {&__pyx_kp_s_Query_object, __pyx_k_Query_object, sizeof(__pyx_k_Query_object), 0, 0, 1, 0},
  {&__pyx_n_s_SUCCESS, __pyx_k_SUCCESS, sizeof(__pyx_k_SUCCESS), 0, 0, 1, 1},
  {&__pyx_kp_s_SUCCESSFULL_MATCH, __pyx_k_SUCCESSFULL_MATCH, sizeof(__pyx_k_SUCCESSFULL_MATCH), 0, 0, 1, 0},
  {&__pyx_kp_s_Syntax_error_near_word_0, __pyx_k_Syntax_error_near_word_0, sizeof(__pyx_k_Syntax_error_near_word_0), 0, 0, 1, 0},
  {&__pyx_kp_s_TESTING_0_1, __pyx_k_TESTING_0_1, sizeof(__pyx_k_TESTING_0_1), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_Id, __pyx_k_Token_Id, sizeof(__pyx_k_Token_Id), 0, 0, 1, 0},
  {&__pyx_kp_s_Token_Length, __pyx_k_Token_Length, sizeof(__pyx_k_Token_Length), 0, 0, 1, 0},
  {&__pyx_kp_s_Too_many_arguments, __pyx_k_Too_many_arguments, sizeof(__pyx_k_Too_many_arguments), 0, 0, 1, 0},
  {&__pyx_kp_s_Validating_Select_Functions, __pyx_k_Validating_Select_Functions, sizeof(__pyx_k_Validating_Select_Functions), 0, 0, 1, 0},
  {&__pyx_kp_s_Variable_Data_not_boolean, __pyx_k_Variable_Data_not_boolean, sizeof(__pyx_k_Variable_Data_not_boolean), 0, 0, 1, 0},
  {&__pyx_kp_s_Variable_data_not_an_integer_0, __pyx_k_Variable_data_not_an_integer_0, sizeof(__pyx_k_Variable_data_not_an_integer_0), 0, 0, 1, 0},
  {&__pyx_kp_s__11, __pyx_k__11, sizeof(__pyx_k__11), 0, 0, 1, 0},
  {&__pyx_kp_s__12, __pyx_k__12, sizeof(__pyx_k__12), 0, 0, 1, 0},
  {&__pyx_kp_s__13, __pyx_k__13, sizeof(__pyx_k__13), 0, 0, 1, 0},
  {&__pyx_kp_s__18, __pyx_k__18, sizeof(__pyx_k__18), 0, 0, 1, 0},
  {&__pyx_kp_s__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 0, 1, 0},
  {&__pyx_kp_s__20, __pyx_k__20, sizeof(__pyx_k__20), 0, 0, 1, 0},
  {&__pyx_kp_s__21, __pyx_k__21, sizeof(__pyx_k__21), 0, 0, 1, 0},
  {&__pyx_kp_s__22, __pyx_k__22, sizeof(__pyx_k__22), 0, 0, 1, 0},
  {&__pyx_kp_s__23, __pyx_k__23, sizeof(__pyx_k__23), 0, 0, 1, 0},
  {&__pyx_kp_s__24, __pyx_k__24, sizeof(__pyx_k__24), 0, 0, 1, 0},
  {&__pyx_kp_s__25, __pyx_k__25, sizeof(__pyx_k__25), 0, 0, 1, 0},
  {&__pyx_kp_s__26, __pyx_k__26, sizeof(__pyx_k__26), 0, 0, 1, 0},
  {&__pyx_kp_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 0},
  {&__pyx_kp_s__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 0, 1, 0},
  {&__pyx_kp_s__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 0, 1, 0},
  {&__pyx_kp_s__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 0, 1, 0},
  {&__pyx_kp_s__8, __pyx_k__8, sizeof(__pyx_k__8), 0, 0, 1, 0},
  {&__pyx_kp_s__9, __pyx_k__9, sizeof(__pyx_k__9), 0, 0, 1, 0},
  {&__pyx_n_s_append, __pyx_k_append, sizeof(__pyx_k_append), 0, 0, 1, 1},
  {&__pyx_n_s_arg, __pyx_k_arg, sizeof(__pyx_k_arg), 0, 0, 1, 1},
  {&__pyx_n_s_arg1, __pyx_k_arg1, sizeof(__pyx_k_arg1), 0, 0, 1, 1},
  {&__pyx_n_s_arg2, __pyx_k_arg2, sizeof(__pyx_k_arg2), 0, 0, 1, 1},
  {&__pyx_n_s_arg3, __pyx_k_arg3, sizeof(__pyx_k_arg3), 0, 0, 1, 1},
  {&__pyx_n_s_arg_key, __pyx_k_arg_key, sizeof(__pyx_k_arg_key), 0, 0, 1, 1},
  {&__pyx_n_s_argindex, __pyx_k_argindex, sizeof(__pyx_k_argindex), 0, 0, 1, 1},
  {&__pyx_n_s_argument, __pyx_k_argument, sizeof(__pyx_k_argument), 0, 0, 1, 1},
  {&__pyx_kp_s_argument_0, __pyx_k_argument_0, sizeof(__pyx_k_argument_0), 0, 0, 1, 0},
  {&__pyx_n_s_argument_index, __pyx_k_argument_index, sizeof(__pyx_k_argument_index), 0, 0, 1, 1},
  {&__pyx_n_s_arguments, __pyx_k_arguments, sizeof(__pyx_k_arguments), 0, 0, 1, 1},
  {&__pyx_n_s_array, __pyx_k_array, sizeof(__pyx_k_array), 0, 0, 1, 1},
  {&__pyx_kp_s_at_the_end, __pyx_k_at_the_end, sizeof(__pyx_k_at_the_end), 0, 0, 1, 0},
  {&__pyx_n_s_bad, __pyx_k_bad, sizeof(__pyx_k_bad), 0, 0, 1, 1},
  {&__pyx_n_s_base_argument, __pyx_k_base_argument, sizeof(__pyx_k_base_argument), 0, 0, 1, 1},
  {&__pyx_n_s_block, __pyx_k_block, sizeof(__pyx_k_block), 0, 0, 1, 1},
  {&__pyx_n_s_blocks, __pyx_k_blocks, sizeof(__pyx_k_blocks), 0, 0, 1, 1},
  {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
  {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
  {&__pyx_n_s_char, __pyx_k_char, sizeof(__pyx_k_char), 0, 0, 1, 1},
  {&__pyx_n_s_chomp, __pyx_k_chomp, sizeof(__pyx_k_chomp), 0, 0, 1, 1},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_columns, __pyx_k_columns, sizeof(__pyx_k_columns), 0, 0, 1, 1},
  {&__pyx_n_s_command, __pyx_k_command, sizeof(__pyx_k_command), 0, 0, 1, 1},
  {&__pyx_n_s_command_fragment, __pyx_k_command_fragment, sizeof(__pyx_k_command_fragment), 0, 0, 1, 1},
  {&__pyx_n_s_commands, __pyx_k_commands, sizeof(__pyx_k_commands), 0, 0, 1, 1},
  {&__pyx_n_s_computed, __pyx_k_computed, sizeof(__pyx_k_computed), 0, 0, 1, 1},
  {&__pyx_n_s_curent_block, __pyx_k_curent_block, sizeof(__pyx_k_curent_block), 0, 0, 1, 1},
  {&__pyx_n_s_curent_object, __pyx_k_curent_object, sizeof(__pyx_k_curent_object), 0, 0, 1, 1},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_db, __pyx_k_db, sizeof(__pyx_k_db), 0, 0, 1, 1},
  {&__pyx_n_s_ddb_lexer_lexer, __pyx_k_ddb_lexer_lexer, sizeof(__pyx_k_ddb_lexer_lexer), 0, 0, 1, 1},
  {&__pyx_kp_s_ddb_lexer_lexer_py, __pyx_k_ddb_lexer_lexer_py, sizeof(__pyx_k_ddb_lexer_lexer_py), 0, 0, 1, 0},
  {&__pyx_n_s_debug, __pyx_k_debug, sizeof(__pyx_k_debug), 0, 0, 1, 1},
  {&__pyx_n_s_definition, __pyx_k_definition, sizeof(__pyx_k_definition), 0, 0, 1, 1},
  {&__pyx_n_s_delimiter, __pyx_k_delimiter, sizeof(__pyx_k_delimiter), 0, 0, 1, 1},
  {&__pyx_n_s_dependency_found, __pyx_k_dependency_found, sizeof(__pyx_k_dependency_found), 0, 0, 1, 1},
  {&__pyx_n_s_depends_on, __pyx_k_depends_on, sizeof(__pyx_k_depends_on), 0, 0, 1, 1},
  {&__pyx_n_s_discard_whitespace, __pyx_k_discard_whitespace, sizeof(__pyx_k_discard_whitespace), 0, 0, 1, 1},
  {&__pyx_n_s_dispose, __pyx_k_dispose, sizeof(__pyx_k_dispose), 0, 0, 1, 1},
  {&__pyx_n_s_doc, __pyx_k_doc, sizeof(__pyx_k_doc), 0, 0, 1, 1},
  {&__pyx_n_s_end, __pyx_k_end, sizeof(__pyx_k_end), 0, 0, 1, 1},
  {&__pyx_n_s_err_msg, __pyx_k_err_msg, sizeof(__pyx_k_err_msg), 0, 0, 1, 1},
  {&__pyx_n_s_f, __pyx_k_f, sizeof(__pyx_k_f), 0, 0, 1, 1},
  {&__pyx_n_s_false, __pyx_k_false, sizeof(__pyx_k_false), 0, 0, 1, 1},
  {&__pyx_n_s_file, __pyx_k_file, sizeof(__pyx_k_file), 0, 0, 1, 1},
  {&__pyx_n_s_find, __pyx_k_find, sizeof(__pyx_k_find), 0, 0, 1, 1},
  {&__pyx_n_s_first_char, __pyx_k_first_char, sizeof(__pyx_k_first_char), 0, 0, 1, 1},
  {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
  {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
  {&__pyx_n_s_function, __pyx_k_function, sizeof(__pyx_k_function), 0, 0, 1, 1},
  {&__pyx_n_s_functions, __pyx_k_functions, sizeof(__pyx_k_functions), 0, 0, 1, 1},
  {&__pyx_n_s_get_argument, __pyx_k_get_argument, sizeof(__pyx_k_get_argument), 0, 0, 1, 1},
  {&__pyx_n_s_get_sub_array, __pyx_k_get_sub_array, sizeof(__pyx_k_get_sub_array), 0, 0, 1, 1},
  {&__pyx_n_s_get_sub_array_sub_key, __pyx_k_get_sub_array_sub_key, sizeof(__pyx_k_get_sub_array_sub_key), 0, 0, 1, 1},
  {&__pyx_n_s_haystack, __pyx_k_haystack, sizeof(__pyx_k_haystack), 0, 0, 1, 1},
  {&__pyx_n_s_haystacks, __pyx_k_haystacks, sizeof(__pyx_k_haystacks), 0, 0, 1, 1},
  {&__pyx_n_s_highest_match, __pyx_k_highest_match, sizeof(__pyx_k_highest_match), 0, 0, 1, 1},
  {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_in_argument, __pyx_k_in_argument, sizeof(__pyx_k_in_argument), 0, 0, 1, 1},
  {&__pyx_n_s_in_block, __pyx_k_in_block, sizeof(__pyx_k_in_block), 0, 0, 1, 1},
  {&__pyx_kp_s_in_list, __pyx_k_in_list, sizeof(__pyx_k_in_list), 0, 0, 1, 0},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_n_s_index_of_colon, __pyx_k_index_of_colon, sizeof(__pyx_k_index_of_colon), 0, 0, 1, 1},
  {&__pyx_n_s_info, __pyx_k_info, sizeof(__pyx_k_info), 0, 0, 1, 1},
  {&__pyx_n_s_init, __pyx_k_init, sizeof(__pyx_k_init), 0, 0, 1, 1},
  {&__pyx_n_s_int, __pyx_k_int, sizeof(__pyx_k_int), 0, 0, 1, 1},
  {&__pyx_n_s_internal, __pyx_k_internal, sizeof(__pyx_k_internal), 0, 0, 1, 1},
  {&__pyx_n_s_is_function, __pyx_k_is_function, sizeof(__pyx_k_is_function), 0, 0, 1, 1},
  {&__pyx_n_s_isspace, __pyx_k_isspace, sizeof(__pyx_k_isspace), 0, 0, 1, 1},
  {&__pyx_n_s_item, __pyx_k_item, sizeof(__pyx_k_item), 0, 0, 1, 1},
  {&__pyx_n_s_join, __pyx_k_join, sizeof(__pyx_k_join), 0, 0, 1, 1},
  {&__pyx_n_s_jump, __pyx_k_jump, sizeof(__pyx_k_jump), 0, 0, 1, 1},
  {&__pyx_n_s_keep_non_keywords, __pyx_k_keep_non_keywords, sizeof(__pyx_k_keep_non_keywords), 0, 0, 1, 1},
  {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
  {&__pyx_n_s_language, __pyx_k_language, sizeof(__pyx_k_language), 0, 0, 1, 1},
  {&__pyx_n_s_last_char, __pyx_k_last_char, sizeof(__pyx_k_last_char), 0, 0, 1, 1},
  {&__pyx_n_s_last_index, __pyx_k_last_index, sizeof(__pyx_k_last_index), 0, 0, 1, 1},
  {&__pyx_n_s_lexer, __pyx_k_lexer, sizeof(__pyx_k_lexer), 0, 0, 1, 1},
  {&__pyx_n_s_lexer___init, __pyx_k_lexer___init, sizeof(__pyx_k_lexer___init), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_flags, __pyx_k_lexer_flags, sizeof(__pyx_k_lexer_flags), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_flags___init, __pyx_k_lexer_flags___init, sizeof(__pyx_k_lexer_flags___init), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_get_argument, __pyx_k_lexer_get_argument, sizeof(__pyx_k_lexer_get_argument), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_get_sub_array, __pyx_k_lexer_get_sub_array, sizeof(__pyx_k_lexer_get_sub_array), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_get_sub_array_sub_key, __pyx_k_lexer_get_sub_array_sub_key, sizeof(__pyx_k_lexer_get_sub_array_sub_key), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_info, __pyx_k_lexer_info, sizeof(__pyx_k_lexer_info), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_parse, __pyx_k_lexer_parse, sizeof(__pyx_k_lexer_parse), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_single_array_match, __pyx_k_lexer_single_array_match, sizeof(__pyx_k_lexer_single_array_match), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_split, __pyx_k_lexer_split, sizeof(__pyx_k_lexer_split), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_test_syntax, __pyx_k_lexer_test_syntax, sizeof(__pyx_k_lexer_test_syntax), 0, 0, 1, 1},
  {&__pyx_n_s_lexer_validate, __pyx_k_lexer_validate, sizeof(__pyx_k_lexer_validate), 0, 0, 1, 1},
  {&__pyx_n_s_list_of_strings, __pyx_k_list_of_strings, sizeof(__pyx_k_list_of_strings), 0, 0, 1, 1},
  {&__pyx_kp_s_looking_ahead, __pyx_k_looking_ahead, sizeof(__pyx_k_looking_ahead), 0, 0, 1, 0},
  {&__pyx_n_s_lower, __pyx_k_lower, sizeof(__pyx_k_lower), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_match, __pyx_k_match, sizeof(__pyx_k_match), 0, 0, 1, 1},
  {&__pyx_n_s_match_len, __pyx_k_match_len, sizeof(__pyx_k_match_len), 0, 0, 1, 1},
  {&__pyx_n_s_meta, __pyx_k_meta, sizeof(__pyx_k_meta), 0, 0, 1, 1},
  {&__pyx_n_s_meta_type, __pyx_k_meta_type, sizeof(__pyx_k_meta_type), 0, 0, 1, 1},
  {&__pyx_n_s_metaclass, __pyx_k_metaclass, sizeof(__pyx_k_metaclass), 0, 0, 1, 1},
  {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
  {&__pyx_n_s_module, __pyx_k_module, sizeof(__pyx_k_module), 0, 0, 1, 1},
  {&__pyx_kp_s_more_list, __pyx_k_more_list, sizeof(__pyx_k_more_list), 0, 0, 1, 0},
  {&__pyx_n_s_msg, __pyx_k_msg, sizeof(__pyx_k_msg), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
  {&__pyx_n_s_needle, __pyx_k_needle, sizeof(__pyx_k_needle), 0, 0, 1, 1},
  {&__pyx_n_s_needles, __pyx_k_needles, sizeof(__pyx_k_needles), 0, 0, 1, 1},
  {&__pyx_n_s_no_keyword, __pyx_k_no_keyword, sizeof(__pyx_k_no_keyword), 0, 0, 1, 1},
  {&__pyx_n_s_node, __pyx_k_node, sizeof(__pyx_k_node), 0, 0, 1, 1},
  {&__pyx_kp_s_not_list, __pyx_k_not_list, sizeof(__pyx_k_not_list), 0, 0, 1, 0},
  {&__pyx_n_s_object_id, __pyx_k_object_id, sizeof(__pyx_k_object_id), 0, 0, 1, 1},
  {&__pyx_n_s_optional, __pyx_k_optional, sizeof(__pyx_k_optional), 0, 0, 1, 1},
  {&__pyx_n_s_parent, __pyx_k_parent, sizeof(__pyx_k_parent), 0, 0, 1, 1},
  {&__pyx_n_s_parse, __pyx_k_parse, sizeof(__pyx_k_parse), 0, 0, 1, 1},
  {&__pyx_n_s_parsed, __pyx_k_parsed, sizeof(__pyx_k_parsed), 0, 0, 1, 1},
  {&__pyx_n_s_partial, __pyx_k_partial, sizeof(__pyx_k_partial), 0, 0, 1, 1},
  {&__pyx_n_s_prepare, __pyx_k_prepare, sizeof(__pyx_k_prepare), 0, 0, 1, 1},
  {&__pyx_n_s_print, __pyx_k_print, sizeof(__pyx_k_print), 0, 0, 1, 1},
  {&__pyx_kp_s_print_not_in_list, __pyx_k_print_not_in_list, sizeof(__pyx_k_print_not_in_list), 0, 0, 1, 0},
  {&__pyx_n_s_q, __pyx_k_q, sizeof(__pyx_k_q), 0, 0, 1, 1},
  {&__pyx_n_s_qualname, __pyx_k_qualname, sizeof(__pyx_k_qualname), 0, 0, 1, 1},
  {&__pyx_n_s_query, __pyx_k_query, sizeof(__pyx_k_query), 0, 0, 1, 1},
  {&__pyx_n_s_query_err, __pyx_k_query_err, sizeof(__pyx_k_query_err), 0, 0, 1, 1},
  {&__pyx_n_s_query_mode, __pyx_k_query_mode, sizeof(__pyx_k_query_mode), 0, 0, 1, 1},
  {&__pyx_n_s_query_object, __pyx_k_query_object, sizeof(__pyx_k_query_object), 0, 0, 1, 1},
  {&__pyx_n_s_query_objects, __pyx_k_query_objects, sizeof(__pyx_k_query_objects), 0, 0, 1, 1},
  {&__pyx_n_s_querys, __pyx_k_querys, sizeof(__pyx_k_querys), 0, 0, 1, 1},
  {&__pyx_n_s_quote, __pyx_k_quote, sizeof(__pyx_k_quote), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_recent_match, __pyx_k_recent_match, sizeof(__pyx_k_recent_match), 0, 0, 1, 1},
  {&__pyx_n_s_required, __pyx_k_required, sizeof(__pyx_k_required), 0, 0, 1, 1},
  {&__pyx_n_s_res, __pyx_k_res, sizeof(__pyx_k_res), 0, 0, 1, 1},
  {&__pyx_n_s_result, __pyx_k_result, sizeof(__pyx_k_result), 0, 0, 1, 1},
  {&__pyx_n_s_results, __pyx_k_results, sizeof(__pyx_k_results), 0, 0, 1, 1},
  {&__pyx_n_s_segment, __pyx_k_segment, sizeof(__pyx_k_segment), 0, 0, 1, 1},
  {&__pyx_n_s_segment_index, __pyx_k_segment_index, sizeof(__pyx_k_segment_index), 0, 0, 1, 1},
  {&__pyx_n_s_segments, __pyx_k_segments, sizeof(__pyx_k_segments), 0, 0, 1, 1},
  {&__pyx_n_s_select, __pyx_k_select, sizeof(__pyx_k_select), 0, 0, 1, 1},
  {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
  {&__pyx_n_s_signature, __pyx_k_signature, sizeof(__pyx_k_signature), 0, 0, 1, 1},
  {&__pyx_n_s_signature_compare, __pyx_k_signature_compare, sizeof(__pyx_k_signature_compare), 0, 0, 1, 1},
  {&__pyx_n_s_single, __pyx_k_single, sizeof(__pyx_k_single), 0, 0, 1, 1},
  {&__pyx_n_s_single_array_match, __pyx_k_single_array_match, sizeof(__pyx_k_single_array_match), 0, 0, 1, 1},
  {&__pyx_n_s_slots, __pyx_k_slots, sizeof(__pyx_k_slots), 0, 0, 1, 1},
  {&__pyx_n_s_specs, __pyx_k_specs, sizeof(__pyx_k_specs), 0, 0, 1, 1},
  {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
  {&__pyx_n_s_sql_object, __pyx_k_sql_object, sizeof(__pyx_k_sql_object), 0, 0, 1, 1},
  {&__pyx_kp_s_still_checking, __pyx_k_still_checking, sizeof(__pyx_k_still_checking), 0, 0, 1, 0},
  {&__pyx_n_s_store_array, __pyx_k_store_array, sizeof(__pyx_k_store_array), 0, 0, 1, 1},
  {&__pyx_n_s_string, __pyx_k_string, sizeof(__pyx_k_string), 0, 0, 1, 1},
  {&__pyx_n_s_success, __pyx_k_success, sizeof(__pyx_k_success), 0, 0, 1, 1},
  {&__pyx_n_s_t, __pyx_k_t, sizeof(__pyx_k_t), 0, 0, 1, 1},
  {&__pyx_n_s_temp_array, __pyx_k_temp_array, sizeof(__pyx_k_temp_array), 0, 0, 1, 1},
  {&__pyx_n_s_temp_haystacks, __pyx_k_temp_haystacks, sizeof(__pyx_k_temp_haystacks), 0, 0, 1, 1},
  {&__pyx_n_s_temp_needles, __pyx_k_temp_needles, sizeof(__pyx_k_temp_needles), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_test_syntax, __pyx_k_test_syntax, sizeof(__pyx_k_test_syntax), 0, 0, 1, 1},
  {&__pyx_kp_s_think_its_a_match, __pyx_k_think_its_a_match, sizeof(__pyx_k_think_its_a_match), 0, 0, 1, 0},
  {&__pyx_n_s_token, __pyx_k_token, sizeof(__pyx_k_token), 0, 0, 1, 1},
  {&__pyx_n_s_token_index, __pyx_k_token_index, sizeof(__pyx_k_token_index), 0, 0, 1, 1},
  {&__pyx_n_s_token_length, __pyx_k_token_length, sizeof(__pyx_k_token_length), 0, 0, 1, 1},
  {&__pyx_n_s_token_list, __pyx_k_token_list, sizeof(__pyx_k_token_list), 0, 0, 1, 1},
  {&__pyx_n_s_tokenize, __pyx_k_tokenize, sizeof(__pyx_k_tokenize), 0, 0, 1, 1},
  {&__pyx_n_s_tokenizer, __pyx_k_tokenizer, sizeof(__pyx_k_tokenizer), 0, 0, 1, 1},
  {&__pyx_n_s_tokens, __pyx_k_tokens, sizeof(__pyx_k_tokens), 0, 0, 1, 1},
  {&__pyx_n_s_true, __pyx_k_true, sizeof(__pyx_k_true), 0, 0, 1, 1},
  {&__pyx_n_s_ts, __pyx_k_ts, sizeof(__pyx_k_ts), 0, 0, 1, 1},
  {&__pyx_n_s_tsi, __pyx_k_tsi, sizeof(__pyx_k_tsi), 0, 0, 1, 1},
  {&__pyx_n_s_type, __pyx_k_type, sizeof(__pyx_k_type), 0, 0, 1, 1},
  {&__pyx_n_s_valid_function_name, __pyx_k_valid_function_name, sizeof(__pyx_k_valid_function_name), 0, 0, 1, 1},
  {&__pyx_n_s_validate, __pyx_k_validate, sizeof(__pyx_k_validate), 0, 0, 1, 1},
  {&__pyx_n_s_value, __pyx_k_value, sizeof(__pyx_k_value), 0, 0, 1, 1},
  {&__pyx_n_s_var, __pyx_k_var, sizeof(__pyx_k_var), 0, 0, 1, 1},
  {&__pyx_n_s_var_name, __pyx_k_var_name, sizeof(__pyx_k_var_name), 0, 0, 1, 1},
  {&__pyx_n_s_variable, __pyx_k_variable, sizeof(__pyx_k_variable), 0, 0, 1, 1},
  {&__pyx_n_s_variable_data, __pyx_k_variable_data, sizeof(__pyx_k_variable_data), 0, 0, 1, 1},
  {&__pyx_kp_s_variable_data_length_exceeded_ty, __pyx_k_variable_data_length_exceeded_ty, sizeof(__pyx_k_variable_data_length_exceeded_ty), 0, 0, 1, 0},
  {&__pyx_n_s_variable_type, __pyx_k_variable_type, sizeof(__pyx_k_variable_type), 0, 0, 1, 1},
  {&__pyx_n_s_vars, __pyx_k_vars, sizeof(__pyx_k_vars), 0, 0, 1, 1},
  {&__pyx_n_s_w_index, __pyx_k_w_index, sizeof(__pyx_k_w_index), 0, 0, 1, 1},
  {&__pyx_n_s_word, __pyx_k_word, sizeof(__pyx_k_word), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_BaseException = __Pyx_GetBuiltinName(__pyx_n_s_BaseException); if (!__pyx_builtin_BaseException) __PYX_ERR(0, 132, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 241, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "ddb/lexer/lexer.py":66
 *         self.query_objects = []
 *         if  query==None:
 *             raise Exception("Invalid Syntax")             # <<<<<<<<<<<<<<
 * 
 *         #print query
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_Invalid_Syntax); if (unlikely(!__pyx_tuple__7)) __PYX_ERR(0, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "ddb/lexer/lexer.py":105
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 *         first_char=word[0:1]             # <<<<<<<<<<<<<<
 *         last_char=word[-1]
 *         #if first_char == '[' and last_char == ']':
 */
  __pyx_slice__10 = PySlice_New(__pyx_int_0, __pyx_int_1, Py_None); if (unlikely(!__pyx_slice__10)) __PYX_ERR(0, 105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__10);
  __Pyx_GIVEREF(__pyx_slice__10);

  /* "ddb/lexer/lexer.py":119
 * 
 *         if definition=='single':
 *             variable=word[1:-1]             # <<<<<<<<<<<<<<
 *             variable_type='string'
 *             if 'specs' in segment:
 */
  __pyx_slice__14 = PySlice_New(__pyx_int_1, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_slice__14)) __PYX_ERR(0, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__14);
  __Pyx_GIVEREF(__pyx_slice__14);

  /* "ddb/lexer/lexer.py":141
 *                     argument =False
 *                 else:
 *                     raise Exception("Variable Data not boolean")             # <<<<<<<<<<<<<<
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:
 */
  __pyx_tuple__15 = PyTuple_Pack(1, __pyx_kp_s_Variable_Data_not_boolean); if (unlikely(!__pyx_tuple__15)) __PYX_ERR(0, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);

  /* "ddb/lexer/lexer.py":144
 *             elif variable_type=='char':
 *                 if len(variable_data)!=1:
 *                     raise Exception("variable data length exceeded, type char")             # <<<<<<<<<<<<<<
 *                 argument =variable_data
 *             #default catch
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_s_variable_data_length_exceeded_ty); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(0, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "ddb/lexer/lexer.py":153
 *         elif definition=='internal':
 *             # here we map the possible approved calue to the keywrd or alternate, pre approved in matching function at end of file
 *             variable=word[1:]             # <<<<<<<<<<<<<<
 *             index_of_colon=variable.find(':')
 *             if index_of_colon!=-1:
 */
  __pyx_slice__17 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__17)) __PYX_ERR(0, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__17);
  __Pyx_GIVEREF(__pyx_slice__17);

  /* "ddb/lexer/lexer.py":167
 *                return {'key':word,'value':variable_data}
 * 
 *         raise Exception ("Not found argument")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__19 = PyTuple_Pack(1, __pyx_kp_s_Not_found_argument); if (unlikely(!__pyx_tuple__19)) __PYX_ERR(0, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__19);
  __Pyx_GIVEREF(__pyx_tuple__19);

  /* "ddb/lexer/lexer.py":10
 *     __slots__=['keep_non_keywords','debug','query_objects']
 * 
 *     def split(self,data,delimiter=';'):             # <<<<<<<<<<<<<<
 *         in_block    = None
 *         curent_block= None
 */
  __pyx_tuple__27 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_data, __pyx_n_s_delimiter, __pyx_n_s_in_block, __pyx_n_s_curent_block, __pyx_n_s_last_index, __pyx_n_s_index, __pyx_n_s_blocks, __pyx_n_s_list_of_strings, __pyx_n_s_c, __pyx_n_s_block); if (unlikely(!__pyx_tuple__27)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__27);
  __Pyx_GIVEREF(__pyx_tuple__27);
  __pyx_codeobj__28 = (PyObject*)__Pyx_PyCode_New(3, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__27, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_split, 10, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__28)) __PYX_ERR(0, 10, __pyx_L1_error)
  __pyx_tuple__29 = PyTuple_Pack(1, ((PyObject*)__pyx_kp_s_)); if (unlikely(!__pyx_tuple__29)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__29);
  __Pyx_GIVEREF(__pyx_tuple__29);

  /* "ddb/lexer/lexer.py":47
 * 
 * 
 *     def __init__(self, query, debug=None):             # <<<<<<<<<<<<<<
 *         #queries=self.split(query,';')
 *         #print "****"
 */
  __pyx_tuple__30 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_query, __pyx_n_s_debug, __pyx_n_s_querys, __pyx_n_s_q, __pyx_n_s_tokens, __pyx_n_s_token_length, __pyx_n_s_token, __pyx_n_s_parsed); if (unlikely(!__pyx_tuple__30)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__30);
  __Pyx_GIVEREF(__pyx_tuple__30);
  __pyx_codeobj__31 = (PyObject*)__Pyx_PyCode_New(3, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__30, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_init, 47, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__31)) __PYX_ERR(0, 47, __pyx_L1_error)
  __pyx_tuple__32 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__32)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__32);
  __Pyx_GIVEREF(__pyx_tuple__32);

  /* "ddb/lexer/lexer.py":102
 *             raise Exception("Invalid Syntax")
 * 
 *     def get_argument(self,word,segment,tokens,token_index,w_index):             # <<<<<<<<<<<<<<
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 */
  __pyx_tuple__33 = PyTuple_Pack(16, __pyx_n_s_self, __pyx_n_s_word, __pyx_n_s_segment, __pyx_n_s_tokens, __pyx_n_s_token_index, __pyx_n_s_w_index, __pyx_n_s_variable_data, __pyx_n_s_first_char, __pyx_n_s_last_char, __pyx_n_s_definition, __pyx_n_s_variable, __pyx_n_s_variable_type, __pyx_n_s_argument, __pyx_n_s_err_msg, __pyx_n_s_index_of_colon, __pyx_n_s_key); if (unlikely(!__pyx_tuple__33)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__33);
  __Pyx_GIVEREF(__pyx_tuple__33);
  __pyx_codeobj__34 = (PyObject*)__Pyx_PyCode_New(6, 0, 16, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__33, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_get_argument, 102, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__34)) __PYX_ERR(0, 102, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":170
 * 
 * 
 *     def parse(self, tokens):             # <<<<<<<<<<<<<<
 *         # SOME TODO!
 *         # loop through commands, return the first matching result
 */
  __pyx_tuple__35 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_tokens, __pyx_n_s_highest_match, __pyx_n_s_recent_match, __pyx_n_s_command, __pyx_n_s_res); if (unlikely(!__pyx_tuple__35)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__35);
  __Pyx_GIVEREF(__pyx_tuple__35);
  __pyx_codeobj__36 = (PyObject*)__Pyx_PyCode_New(2, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__35, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_parse, 170, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__36)) __PYX_ERR(0, 170, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":192
 * 
 * 
 *         def __init__(self,command_fragment):             # <<<<<<<<<<<<<<
 *             if 'dispose' in command_fragment:
 *                 self.dispose = command_fragment['dispose']
 */
  __pyx_tuple__37 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_command_fragment, __pyx_n_s_x); if (unlikely(!__pyx_tuple__37)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__37);
  __Pyx_GIVEREF(__pyx_tuple__37);
  __pyx_codeobj__38 = (PyObject*)__Pyx_PyCode_New(2, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__37, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_init, 192, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__38)) __PYX_ERR(0, 192, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":232
 * 
 * 
 *     def test_syntax(self,command,tokens):             # <<<<<<<<<<<<<<
 *         query_object = {}
 *         token_index = 0
 */
  __pyx_tuple__39 = PyTuple_Pack(36, __pyx_n_s_self, __pyx_n_s_command, __pyx_n_s_tokens, __pyx_n_s_query_object, __pyx_n_s_token_index, __pyx_n_s_segment_index, __pyx_n_s_query_mode, __pyx_n_s_curent_object, __pyx_n_s_segment, __pyx_n_s_token_list, __pyx_n_s_i, __pyx_n_s_base_argument, __pyx_n_s_in_argument, __pyx_n_s_argument_index, __pyx_n_s_flags, __pyx_n_s_depends_on, __pyx_n_s_dependency_found, __pyx_n_s_arguments, __pyx_n_s_match_len, __pyx_n_s_match, __pyx_n_s_partial, __pyx_n_s_signature_compare, __pyx_n_s_haystack, __pyx_n_s_signature, __pyx_n_s_var_name, __pyx_n_s_argument, __pyx_n_s_w_index, __pyx_n_s_word, __pyx_n_s_computed, __pyx_n_s_jump, __pyx_n_s_tsi, __pyx_n_s_ts, __pyx_n_s_result, __pyx_n_s_query_err, __pyx_n_s_index, __pyx_n_s_err_msg); if (unlikely(!__pyx_tuple__39)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__39);
  __Pyx_GIVEREF(__pyx_tuple__39);
  __pyx_codeobj__40 = (PyObject*)__Pyx_PyCode_New(3, 0, 36, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__39, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_test_syntax, 232, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__40)) __PYX_ERR(0, 232, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":474
 * 
 *     # this is crappy, I'm just breaking up a giant function. Will clean later...
 *     def validate(self,curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode):             # <<<<<<<<<<<<<<
 *         self.info(curent_object)
 *         # so we have run out of text to match and everything is good so far
 */
  __pyx_tuple__41 = PyTuple_Pack(19, __pyx_n_s_self, __pyx_n_s_curent_object, __pyx_n_s_tokens, __pyx_n_s_token_index, __pyx_n_s_segment, __pyx_n_s_command, __pyx_n_s_segment_index, __pyx_n_s_query_object, __pyx_n_s_query_mode, __pyx_n_s_bad, __pyx_n_s_t, __pyx_n_s_msg, __pyx_n_s_node, __pyx_n_s_valid_function_name, __pyx_n_s_is_function, __pyx_n_s_f, __pyx_n_s_argindex, __pyx_n_s_arg, __pyx_n_s_sql_object); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);
  __pyx_codeobj__42 = (PyObject*)__Pyx_PyCode_New(9, 0, 19, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__41, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_validate, 474, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__42)) __PYX_ERR(0, 474, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":574
 *     ## support funcitons
 * 
 *     def get_sub_array(self, array, key=None):             # <<<<<<<<<<<<<<
 *         if None == key:
 *             if isinstance(array, str):
 */
  __pyx_tuple__43 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_array, __pyx_n_s_key); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);
  __pyx_codeobj__44 = (PyObject*)__Pyx_PyCode_New(3, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__43, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_get_sub_array, 574, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__44)) __PYX_ERR(0, 574, __pyx_L1_error)
  __pyx_tuple__45 = PyTuple_Pack(1, ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__45)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__45);
  __Pyx_GIVEREF(__pyx_tuple__45);

  /* "ddb/lexer/lexer.py":586
 * 
 * 
 *     def get_sub_array_sub_key(self, array, key):             # <<<<<<<<<<<<<<
 *         temp_array = []
 * 
 */
  __pyx_tuple__46 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_array, __pyx_n_s_key, __pyx_n_s_temp_array, __pyx_n_s_item); if (unlikely(!__pyx_tuple__46)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__46);
  __Pyx_GIVEREF(__pyx_tuple__46);
  __pyx_codeobj__47 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__46, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_get_sub_array_sub_key, 586, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__47)) __PYX_ERR(0, 586, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":594
 *         return temp_array
 * 
 *     def single_array_match(self, needles, haystacks):             # <<<<<<<<<<<<<<
 *         """ Match a single or array of strings with with another string or array of strings"""
 * 
 */
  __pyx_tuple__48 = PyTuple_Pack(12, __pyx_n_s_self, __pyx_n_s_needles, __pyx_n_s_haystacks, __pyx_n_s_temp_needles, __pyx_n_s_temp_haystacks, __pyx_n_s_index, __pyx_n_s_needle, __pyx_n_s_first_char, __pyx_n_s_last_char, __pyx_n_s_haystack, __pyx_n_s_variable, __pyx_n_s_index_of_colon); if (unlikely(!__pyx_tuple__48)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__48);
  __Pyx_GIVEREF(__pyx_tuple__48);
  __pyx_codeobj__49 = (PyObject*)__Pyx_PyCode_New(3, 0, 12, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__48, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_single_array_match, 594, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__49)) __PYX_ERR(0, 594, __pyx_L1_error)

  /* "ddb/lexer/lexer.py":642
 *         return True
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):             # <<<<<<<<<<<<<<
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:
 */
  __pyx_tuple__50 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_msg, __pyx_n_s_arg1, __pyx_n_s_arg2, __pyx_n_s_arg3); if (unlikely(!__pyx_tuple__50)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__50);
  __Pyx_GIVEREF(__pyx_tuple__50);
  __pyx_codeobj__51 = (PyObject*)__Pyx_PyCode_New(5, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__50, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_ddb_lexer_lexer_py, __pyx_n_s_info, 642, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__51)) __PYX_ERR(0, 642, __pyx_L1_error)
  __pyx_tuple__52 = PyTuple_Pack(3, ((PyObject *)Py_None), ((PyObject *)Py_None), ((PyObject *)Py_None)); if (unlikely(!__pyx_tuple__52)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__52);
  __Pyx_GIVEREF(__pyx_tuple__52);
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 2, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#if PY_MAJOR_VERSION < 3
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC void
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#else
#ifdef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initlexer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initlexer(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_lexer(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_lexer(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_lexer(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'lexer' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_lexer(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 2, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 2, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("lexer", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 2, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 2, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_ddb__lexer__lexer) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 2, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "ddb.lexer.lexer")) {
      if (unlikely(PyDict_SetItemString(modules, "ddb.lexer.lexer", __pyx_m) < 0)) __PYX_ERR(0, 2, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) goto __pyx_L1_error;
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) goto __pyx_L1_error;
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  (void)__Pyx_modinit_type_init_code();
  (void)__Pyx_modinit_type_import_code();
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  #endif

  /* "ddb/lexer/lexer.py":2
 * 
 * from .language import language             # <<<<<<<<<<<<<<
 * from .tokenize import tokenizer
 * 
 */
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_language);
  __Pyx_GIVEREF(__pyx_n_s_language);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_language);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_language, __pyx_t_1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_language); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_language, __pyx_t_1) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":3
 * 
 * from .language import language
 * from .tokenize import tokenizer             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_tokenizer);
  __Pyx_GIVEREF(__pyx_n_s_tokenizer);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_tokenizer);
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_tokenize, __pyx_t_2, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_1, __pyx_n_s_tokenizer); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_tokenizer, __pyx_t_2) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":6
 * 
 * 
 * class lexer:             # <<<<<<<<<<<<<<
 * 
 *     __slots__=['keep_non_keywords','debug','query_objects']
 */
  __pyx_t_1 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_lexer, __pyx_n_s_lexer, (PyObject *) NULL, __pyx_n_s_ddb_lexer_lexer, (PyObject *) NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "ddb/lexer/lexer.py":8
 * class lexer:
 * 
 *     __slots__=['keep_non_keywords','debug','query_objects']             # <<<<<<<<<<<<<<
 * 
 *     def split(self,data,delimiter=';'):
 */
  __pyx_t_2 = PyList_New(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_keep_non_keywords);
  __Pyx_GIVEREF(__pyx_n_s_keep_non_keywords);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_keep_non_keywords);
  __Pyx_INCREF(__pyx_n_s_debug);
  __Pyx_GIVEREF(__pyx_n_s_debug);
  PyList_SET_ITEM(__pyx_t_2, 1, __pyx_n_s_debug);
  __Pyx_INCREF(__pyx_n_s_query_objects);
  __Pyx_GIVEREF(__pyx_n_s_query_objects);
  PyList_SET_ITEM(__pyx_t_2, 2, __pyx_n_s_query_objects);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_slots, __pyx_t_2) < 0) __PYX_ERR(0, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":10
 *     __slots__=['keep_non_keywords','debug','query_objects']
 * 
 *     def split(self,data,delimiter=';'):             # <<<<<<<<<<<<<<
 *         in_block    = None
 *         curent_block= None
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_1split, 0, __pyx_n_s_lexer_split, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__28)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__29);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_split, __pyx_t_2) < 0) __PYX_ERR(0, 10, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":47
 * 
 * 
 *     def __init__(self, query, debug=None):             # <<<<<<<<<<<<<<
 *         #queries=self.split(query,';')
 *         #print "****"
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_3__init__, 0, __pyx_n_s_lexer___init, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__31)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__32);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_init, __pyx_t_2) < 0) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":102
 *             raise Exception("Invalid Syntax")
 * 
 *     def get_argument(self,word,segment,tokens,token_index,w_index):             # <<<<<<<<<<<<<<
 *        # if we have definitions
 *         variable_data=tokens[token_index + w_index]['data']
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_5get_argument, 0, __pyx_n_s_lexer_get_argument, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__34)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_get_argument, __pyx_t_2) < 0) __PYX_ERR(0, 102, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":170
 * 
 * 
 *     def parse(self, tokens):             # <<<<<<<<<<<<<<
 *         # SOME TODO!
 *         # loop through commands, return the first matching result
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_7parse, 0, __pyx_n_s_lexer_parse, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__36)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_parse, __pyx_t_2) < 0) __PYX_ERR(0, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":188
 *         return recent_match
 *     # place holder for the status of a command fragment
 *     class flags:             # <<<<<<<<<<<<<<
 *         __slots__=['dispose','no_keyword','store_array','parent','meta_type','optional','object_id','arg_key']
 * 
 */
  __pyx_t_2 = __Pyx_Py3MetaclassPrepare((PyObject *) NULL, __pyx_empty_tuple, __pyx_n_s_flags, __pyx_n_s_lexer_flags, (PyObject *) NULL, __pyx_n_s_ddb_lexer_lexer, (PyObject *) NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "ddb/lexer/lexer.py":189
 *     # place holder for the status of a command fragment
 *     class flags:
 *         __slots__=['dispose','no_keyword','store_array','parent','meta_type','optional','object_id','arg_key']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = PyList_New(8); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_n_s_dispose);
  __Pyx_GIVEREF(__pyx_n_s_dispose);
  PyList_SET_ITEM(__pyx_t_3, 0, __pyx_n_s_dispose);
  __Pyx_INCREF(__pyx_n_s_no_keyword);
  __Pyx_GIVEREF(__pyx_n_s_no_keyword);
  PyList_SET_ITEM(__pyx_t_3, 1, __pyx_n_s_no_keyword);
  __Pyx_INCREF(__pyx_n_s_store_array);
  __Pyx_GIVEREF(__pyx_n_s_store_array);
  PyList_SET_ITEM(__pyx_t_3, 2, __pyx_n_s_store_array);
  __Pyx_INCREF(__pyx_n_s_parent);
  __Pyx_GIVEREF(__pyx_n_s_parent);
  PyList_SET_ITEM(__pyx_t_3, 3, __pyx_n_s_parent);
  __Pyx_INCREF(__pyx_n_s_meta_type);
  __Pyx_GIVEREF(__pyx_n_s_meta_type);
  PyList_SET_ITEM(__pyx_t_3, 4, __pyx_n_s_meta_type);
  __Pyx_INCREF(__pyx_n_s_optional);
  __Pyx_GIVEREF(__pyx_n_s_optional);
  PyList_SET_ITEM(__pyx_t_3, 5, __pyx_n_s_optional);
  __Pyx_INCREF(__pyx_n_s_object_id);
  __Pyx_GIVEREF(__pyx_n_s_object_id);
  PyList_SET_ITEM(__pyx_t_3, 6, __pyx_n_s_object_id);
  __Pyx_INCREF(__pyx_n_s_arg_key);
  __Pyx_GIVEREF(__pyx_n_s_arg_key);
  PyList_SET_ITEM(__pyx_t_3, 7, __pyx_n_s_arg_key);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_slots, __pyx_t_3) < 0) __PYX_ERR(0, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ddb/lexer/lexer.py":192
 * 
 * 
 *         def __init__(self,command_fragment):             # <<<<<<<<<<<<<<
 *             if 'dispose' in command_fragment:
 *                 self.dispose = command_fragment['dispose']
 */
  __pyx_t_3 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5flags_1__init__, 0, __pyx_n_s_lexer_flags___init, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__38)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_2, __pyx_n_s_init, __pyx_t_3) < 0) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "ddb/lexer/lexer.py":188
 *         return recent_match
 *     # place holder for the status of a command fragment
 *     class flags:             # <<<<<<<<<<<<<<
 *         __slots__=['dispose','no_keyword','store_array','parent','meta_type','optional','object_id','arg_key']
 * 
 */
  __pyx_t_3 = __Pyx_Py3ClassCreate(((PyObject*)&__Pyx_DefaultClassType), __pyx_n_s_flags, __pyx_empty_tuple, __pyx_t_2, NULL, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_flags, __pyx_t_3) < 0) __PYX_ERR(0, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":232
 * 
 * 
 *     def test_syntax(self,command,tokens):             # <<<<<<<<<<<<<<
 *         query_object = {}
 *         token_index = 0
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_9test_syntax, 0, __pyx_n_s_lexer_test_syntax, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__40)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_test_syntax, __pyx_t_2) < 0) __PYX_ERR(0, 232, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":474
 * 
 *     # this is crappy, I'm just breaking up a giant function. Will clean later...
 *     def validate(self,curent_object,tokens,token_index,segment,command,segment_index,query_object,query_mode):             # <<<<<<<<<<<<<<
 *         self.info(curent_object)
 *         # so we have run out of text to match and everything is good so far
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_11validate, 0, __pyx_n_s_lexer_validate, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__42)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_validate, __pyx_t_2) < 0) __PYX_ERR(0, 474, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":574
 *     ## support funcitons
 * 
 *     def get_sub_array(self, array, key=None):             # <<<<<<<<<<<<<<
 *         if None == key:
 *             if isinstance(array, str):
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_13get_sub_array, 0, __pyx_n_s_lexer_get_sub_array, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__44)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__45);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_get_sub_array, __pyx_t_2) < 0) __PYX_ERR(0, 574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":586
 * 
 * 
 *     def get_sub_array_sub_key(self, array, key):             # <<<<<<<<<<<<<<
 *         temp_array = []
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_15get_sub_array_sub_key, 0, __pyx_n_s_lexer_get_sub_array_sub_key, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__47)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_get_sub_array_sub_key, __pyx_t_2) < 0) __PYX_ERR(0, 586, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":594
 *         return temp_array
 * 
 *     def single_array_match(self, needles, haystacks):             # <<<<<<<<<<<<<<
 *         """ Match a single or array of strings with with another string or array of strings"""
 * 
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_17single_array_match, 0, __pyx_n_s_lexer_single_array_match, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__49)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_single_array_match, __pyx_t_2) < 0) __PYX_ERR(0, 594, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":642
 *         return True
 * 
 *     def info(self,msg, arg1=None, arg2=None, arg3=None):             # <<<<<<<<<<<<<<
 *         if True == self.debug:
 *             if arg3 is None and arg2 is None:
 */
  __pyx_t_2 = __Pyx_CyFunction_NewEx(&__pyx_mdef_3ddb_5lexer_5lexer_5lexer_19info, 0, __pyx_n_s_lexer_info, NULL, __pyx_n_s_ddb_lexer_lexer, __pyx_d, ((PyObject *)__pyx_codeobj__51)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_tuple__52);
  if (__Pyx_SetNameInClass(__pyx_t_1, __pyx_n_s_info, __pyx_t_2) < 0) __PYX_ERR(0, 642, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "ddb/lexer/lexer.py":6
 * 
 * 
 * class lexer:             # <<<<<<<<<<<<<<
 * 
 *     __slots__=['keep_non_keywords','debug','query_objects']
 */
  __pyx_t_2 = __Pyx_Py3ClassCreate(((PyObject*)&__Pyx_DefaultClassType), __pyx_n_s_lexer, __pyx_empty_tuple, __pyx_t_1, NULL, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_lexer, __pyx_t_2) < 0) __PYX_ERR(0, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "ddb/lexer/lexer.py":2
 * 
 * from .language import language             # <<<<<<<<<<<<<<
 * from .tokenize import tokenizer
 * 
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 2, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init ddb.lexer.lexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init ddb.lexer.lexer");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* DictGetItem */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_FALSE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_FALSE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal == 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a == (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* append */
static CYTHON_INLINE int __Pyx_PyObject_Append(PyObject* L, PyObject* x) {
    if (likely(PyList_CheckExact(L))) {
        if (unlikely(__Pyx_PyList_Append(L, x) < 0)) return -1;
    } else {
        PyObject* retval = __Pyx_PyObject_CallMethod1(L, __pyx_n_s_append, x);
        if (unlikely(!retval))
            return -1;
        Py_DECREF(retval);
    }
    return 0;
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_type == NULL || exc_info->exc_type == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    #endif
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* PyIntCompare */
static CYTHON_INLINE PyObject* __Pyx_PyInt_NeObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED long inplace) {
    if (op1 == op2) {
        Py_RETURN_FALSE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a != b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = Py_SIZE(op1);
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        if (intval == 0) {
            if (size != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
        } else if (intval < 0) {
            if (size >= 0)
                Py_RETURN_TRUE;
            intval = -intval;
            size = -size;
        } else {
            if (size <= 0)
                Py_RETURN_TRUE;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        if (unequal != 0) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
        if ((double)a != (double)b) Py_RETURN_TRUE; else Py_RETURN_FALSE;
    }
    return (
        PyObject_RichCompare(op1, op2, Py_NE));
}

/* StringJoin */
#if !CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyBytes_Join(PyObject* sep, PyObject* values) {
    return PyObject_CallMethodObjArgs(sep, __pyx_n_s_join, values, NULL);
}
#endif

/* None */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* FetchCommonType */
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CythonFunction */
#include <structmember.h>
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, CYTHON_UNUSED void *context)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, CYTHON_UNUSED void *context) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *context) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    return __Pyx_CyFunction_CallMethod(func, ((PyCFunctionObject*)func)->m_self, arg, kw);
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
        argc = PyTuple_GET_SIZE(args);
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CalculateMetaclass */
static PyObject *__Pyx_CalculateMetaclass(PyTypeObject *metaclass, PyObject *bases) {
    Py_ssize_t i, nbases = PyTuple_GET_SIZE(bases);
    for (i=0; i < nbases; i++) {
        PyTypeObject *tmptype;
        PyObject *tmp = PyTuple_GET_ITEM(bases, i);
        tmptype = Py_TYPE(tmp);
#if PY_MAJOR_VERSION < 3
        if (tmptype == &PyClass_Type)
            continue;
#endif
        if (!metaclass) {
            metaclass = tmptype;
            continue;
        }
        if (PyType_IsSubtype(metaclass, tmptype))
            continue;
        if (PyType_IsSubtype(tmptype, metaclass)) {
            metaclass = tmptype;
            continue;
        }
        PyErr_SetString(PyExc_TypeError,
                        "metaclass conflict: "
                        "the metaclass of a derived class "
                        "must be a (non-strict) subclass "
                        "of the metaclasses of all its bases");
        return NULL;
    }
    if (!metaclass) {
#if PY_MAJOR_VERSION < 3
        metaclass = &PyClass_Type;
#else
        metaclass = &PyType_Type;
#endif
    }
    Py_INCREF((PyObject*) metaclass);
    return (PyObject*) metaclass;
}

/* Py3ClassCreate */
static PyObject *__Pyx_Py3MetaclassPrepare(PyObject *metaclass, PyObject *bases, PyObject *name,
                                           PyObject *qualname, PyObject *mkw, PyObject *modname, PyObject *doc) {
    PyObject *ns;
    if (metaclass) {
        PyObject *prep = __Pyx_PyObject_GetAttrStr(metaclass, __pyx_n_s_prepare);
        if (prep) {
            PyObject *pargs = PyTuple_Pack(2, name, bases);
            if (unlikely(!pargs)) {
                Py_DECREF(prep);
                return NULL;
            }
            ns = PyObject_Call(prep, pargs, mkw);
            Py_DECREF(prep);
            Py_DECREF(pargs);
        } else {
            if (unlikely(!PyErr_ExceptionMatches(PyExc_AttributeError)))
                return NULL;
            PyErr_Clear();
            ns = PyDict_New();
        }
    } else {
        ns = PyDict_New();
    }
    if (unlikely(!ns))
        return NULL;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_module, modname) < 0)) goto bad;
    if (unlikely(PyObject_SetItem(ns, __pyx_n_s_qualname, qualname) < 0)) goto bad;
    if (unlikely(doc && PyObject_SetItem(ns, __pyx_n_s_doc, doc) < 0)) goto bad;
    return ns;
bad:
    Py_DECREF(ns);
    return NULL;
}
static PyObject *__Pyx_Py3ClassCreate(PyObject *metaclass, PyObject *name, PyObject *bases,
                                      PyObject *dict, PyObject *mkw,
                                      int calculate_metaclass, int allow_py2_metaclass) {
    PyObject *result, *margs;
    PyObject *owned_metaclass = NULL;
    if (allow_py2_metaclass) {
        owned_metaclass = PyObject_GetItem(dict, __pyx_n_s_metaclass);
        if (owned_metaclass) {
            metaclass = owned_metaclass;
        } else if (likely(PyErr_ExceptionMatches(PyExc_KeyError))) {
            PyErr_Clear();
        } else {
            return NULL;
        }
    }
    if (calculate_metaclass && (!metaclass || PyType_Check(metaclass))) {
        metaclass = __Pyx_CalculateMetaclass((PyTypeObject*) metaclass, bases);
        Py_XDECREF(owned_metaclass);
        if (unlikely(!metaclass))
            return NULL;
        owned_metaclass = metaclass;
    }
    margs = PyTuple_Pack(3, name, bases, dict);
    if (unlikely(!margs)) {
        result = NULL;
    } else {
        result = PyObject_Call(metaclass, margs, mkw);
        Py_DECREF(margs);
    }
    Py_XDECREF(owned_metaclass);
    return result;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* Print */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static PyObject *__Pyx_GetStdout(void) {
    PyObject *f = PySys_GetObject((char *)"stdout");
    if (!f) {
        PyErr_SetString(PyExc_RuntimeError, "lost sys.stdout");
    }
    return f;
}
static int __Pyx_Print(PyObject* f, PyObject *arg_tuple, int newline) {
    int i;
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    for (i=0; i < PyTuple_GET_SIZE(arg_tuple); i++) {
        PyObject* v;
        if (PyFile_SoftSpace(f, 1)) {
            if (PyFile_WriteString(" ", f) < 0)
                goto error;
        }
        v = PyTuple_GET_ITEM(arg_tuple, i);
        if (PyFile_WriteObject(v, f, Py_PRINT_RAW) < 0)
            goto error;
        if (PyString_Check(v)) {
            char *s = PyString_AsString(v);
            Py_ssize_t len = PyString_Size(v);
            if (len > 0) {
                switch (s[len-1]) {
                    case ' ': break;
                    case '\f': case '\r': case '\n': case '\t': case '\v':
                        PyFile_SoftSpace(f, 0);
                        break;
                    default:  break;
                }
            }
        }
    }
    if (newline) {
        if (PyFile_WriteString("\n", f) < 0)
            goto error;
        PyFile_SoftSpace(f, 0);
    }
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
}
#else
static int __Pyx_Print(PyObject* stream, PyObject *arg_tuple, int newline) {
    PyObject* kwargs = 0;
    PyObject* result = 0;
    PyObject* end_string;
    if (unlikely(!__pyx_print)) {
        __pyx_print = PyObject_GetAttr(__pyx_b, __pyx_n_s_print);
        if (!__pyx_print)
            return -1;
    }
    if (stream) {
        kwargs = PyDict_New();
        if (unlikely(!kwargs))
            return -1;
        if (unlikely(PyDict_SetItem(kwargs, __pyx_n_s_file, stream) < 0))
            goto bad;
        if (!newline) {
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                goto bad;
            if (PyDict_SetItem(kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                goto bad;
            }
            Py_DECREF(end_string);
        }
    } else if (!newline) {
        if (unlikely(!__pyx_print_kwargs)) {
            __pyx_print_kwargs = PyDict_New();
            if (unlikely(!__pyx_print_kwargs))
                return -1;
            end_string = PyUnicode_FromStringAndSize(" ", 1);
            if (unlikely(!end_string))
                return -1;
            if (PyDict_SetItem(__pyx_print_kwargs, __pyx_n_s_end, end_string) < 0) {
                Py_DECREF(end_string);
                return -1;
            }
            Py_DECREF(end_string);
        }
        kwargs = __pyx_print_kwargs;
    }
    result = PyObject_Call(__pyx_print, arg_tuple, kwargs);
    if (unlikely(kwargs) && (kwargs != __pyx_print_kwargs))
        Py_DECREF(kwargs);
    if (!result)
        return -1;
    Py_DECREF(result);
    return 0;
bad:
    if (kwargs != __pyx_print_kwargs)
        Py_XDECREF(kwargs);
    return -1;
}
#endif

/* PrintOne */
#if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION < 3
static int __Pyx_PrintOne(PyObject* f, PyObject *o) {
    if (!f) {
        if (!(f = __Pyx_GetStdout()))
            return -1;
    }
    Py_INCREF(f);
    if (PyFile_SoftSpace(f, 0)) {
        if (PyFile_WriteString(" ", f) < 0)
            goto error;
    }
    if (PyFile_WriteObject(o, f, Py_PRINT_RAW) < 0)
        goto error;
    if (PyFile_WriteString("\n", f) < 0)
        goto error;
    Py_DECREF(f);
    return 0;
error:
    Py_DECREF(f);
    return -1;
    /* the line below is just to avoid C compiler
     * warnings about unused functions */
    return __Pyx_Print(f, NULL, 0);
}
#else
static int __Pyx_PrintOne(PyObject* stream, PyObject *o) {
    int res;
    PyObject* arg_tuple = PyTuple_Pack(1, o);
    if (unlikely(!arg_tuple))
        return -1;
    res = __Pyx_Print(stream, arg_tuple, 1);
    Py_DECREF(arg_tuple);
    return res;
}
#endif

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
